<?php

namespace App\Exports;

use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithTitle;
use Maatwebsite\Excel\Concerns\WithStyles;
use Maatwebsite\Excel\Concerns\WithEvents;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use Maatwebsite\Excel\Events\AfterSheet;

use App\Models\Accounting;
use App\Models\Ledger;

class AccountGroupExport implements FromCollection, WithHeadings, WithTitle, WithStyles, WithEvents
{
    protected $groupId;
    protected $startDate;
    protected $endDate;
    protected $accountId;
    protected $drTotal;
    protected $crTotal;
        
    // Accept start and end dates in the constructor
    public function __construct($groupId, $startDate, $endDate, $accountId)
    {
        $this->groupId = $groupId;
        $this->startDate = $startDate;
        $this->endDate = $endDate;
        $this->accountId = $accountId;
        $this->drTotal = 0;
        $this->crTotal = 0;
    }
    
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $result = [];
        
        $ledgers = Ledger::where('ag_id',$this->groupId)->get();
        foreach($ledgers as $ledger){
            $dr_amount=$cr_amount=0;
            $data = Accounting::voucherBalance($ledger->ledger_id,$this->endDate,$this->accountId,0,$this->startDate);
            if($data['dr_amount'] > 0 || $data['cr_amount'] > 0){
                if($data['dr_amount'] > $data['cr_amount']){
                    $dr_amount = $data['dr_amount']-$data['cr_amount'];
                }
                if($data['dr_amount'] < $data['cr_amount']){
                    $cr_amount = $data['cr_amount']-$data['dr_amount'];
                }
                
                $this->drTotal += $dr_amount;
                $this->crTotal += $cr_amount;
                
                $result[] = ['particulars' => $ledger->ledger_name,'debit' => $dr_amount,'credit' => $cr_amount];
            }
        }
        
        return collect($result);
    }
    
    public function headings(): array
    {
        return [
            'Particulars',
            'Debit',
            'Credit',
        ];
    }
    
    public function title(): string
    {
        return 'Account Group Report';
    }
    
    public function styles(Worksheet $sheet)
    {
        return [];
    }
    
    public function registerEvents(): array
    {
        return [
            AfterSheet::class => function (AfterSheet $event) {
                $sheet = $event->sheet;
                
                $sheet->getColumnDimension('A')->setWidth(60);
                $sheet->getColumnDimension('B')->setWidth(30);
                $sheet->getColumnDimension('C')->setWidth(30);
                
                // Insert the title row before the column headings (row 1)
                $sheet->insertNewRowBefore(1, 1); // Insert a new row at position 1 for the title
                $sheet->setCellValue('A1', 'Account Group Report From '.date('d-m-Y',strtotime($this->startDate)).' To '.date('d-m-Y',strtotime($this->endDate)));
                $sheet->mergeCells('A1:C1');
                $sheet->getStyle('A1')->applyFromArray([
                    'font' => [
                        'bold' => true,
                        'size' => 14,
                    ],
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                        'vertical' => \PhpOffice\PhpSpreadsheet\Style\Alignment::VERTICAL_CENTER,
                    ]
                ]);
                
                $sheet->getStyle('A2:C2')->applyFromArray([
                    'font' => [
                        'bold' => true,
                        'size' => 12,
                    ],
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                        'vertical' => \PhpOffice\PhpSpreadsheet\Style\Alignment::VERTICAL_CENTER,
                    ],
                    'fill' => [
                        'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                        'startColor' => [
                            'rgb' => 'FFFF00',
                        ]
                    ]
                ]);
                
                $lastRow = $sheet->getHighestRow()+1;
                $sheet->setCellValue('A'.$lastRow, 'TOTAL');
                $sheet->setCellValue('B'.$lastRow, $this->drTotal);
                $sheet->setCellValue('C'.$lastRow, $this->crTotal);
                
                $sheet->getStyle('A2:C'.$lastRow)->applyFromArray([
                    'font' => [
                        'name' => 'Calibri',
                        'size' => 12,
                    ],
                    'borders' => [
                        'allBorders' => [
                            'borderStyle' => \PhpOffice\PhpSpreadsheet\Style\Border::BORDER_THIN,
                            'color' => ['argb' => '000000'],
                        ],
                    ],
                    'alignment' => [
                        'vertical' => \PhpOffice\PhpSpreadsheet\Style\Alignment::VERTICAL_CENTER,
                    ]
                ]);
                    
                $sheet->getRowDimension(1)->setRowHeight(25);
                $sheet->getRowDimension(2)->setRowHeight(20);
                
                $sheet->getStyle('B3:C'.$lastRow)->applyFromArray([
                    'numberFormat' => [
                        'formatCode' => '0.00',
                    ],
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_RIGHT,
                    ]
                ]);
                
                $sheet->getStyle('A'.$lastRow.':C'.$lastRow)->applyFromArray([
                    'font' => [
                        'bold' => true,
                    ]
                ]);
            }
        ];
    }
}
