<?php

namespace App\Exports;

use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;
use Maatwebsite\Excel\Concerns\WithTitle;
use Maatwebsite\Excel\Concerns\WithStyles;
use Maatwebsite\Excel\Concerns\WithEvents;
use PhpOffice\PhpSpreadsheet\Worksheet\Worksheet;
use Maatwebsite\Excel\Events\AfterSheet;

use App\Models\Voucher;
use App\Models\Accounting;
use App\Models\Ledger;
use App\Models\Financialyear;

class BalanceSheetExport implements FromCollection, WithHeadings, WithTitle, WithStyles, WithEvents
{
    protected $startDate;
    protected $endDate;
    protected $accountId;
    protected $pLoss;
    protected $lTotal;
    protected $aTotal;
        
    // Accept start and end dates in the constructor
    public function __construct($startDate, $endDate, $accountId)
    {
        $this->startDate = $startDate;
        $this->endDate = $endDate;
        $this->accountId = $accountId;
        $this->pLoss = 0;
        $this->lTotal = 0;
        $this->aTotal = 0;
    }
    
    /**
    * @return \Illuminate\Support\Collection
    */
    public function collection()
    {
        $open_bal = Accounting::openingBalance($this->endDate,$this->accountId);
            
        $liability_count = Accounting::getLedgers("liability")->count();
        $liabilities = Accounting::voucherAmount("liability",$this->accountId,$this->endDate,0,$liability_count);
            
        $asset_count = Accounting::getLedgers("asset")->count();
        $assets = Accounting::voucherAmount("asset",$this->accountId,$this->endDate,0,$asset_count);
            
        $expense_count = Accounting::getLedgers("expense")->count();
        $expenses = Accounting::profitLoss("expense",$this->accountId,$this->endDate,'',0,$expense_count);
            
        $income_count = Accounting::getLedgers("income")->count();
        $incomes = Accounting::profitLoss("income",$this->accountId,$this->endDate,'',0,$income_count);
        
        $total_expense=$total_income=0;
        foreach($expenses as $key => $value){
            $total_expense += $value['total_amount'];
        }
        
        foreach($incomes as $key => $value){
            $total_income += $value['total_amount'];
        }
        
        $profit_loss = $total_income-$total_expense;
        $this->pLoss = $profit_loss;
        
        $result = [];
        
        $larray = $iarray = [];
        foreach($liabilities as $liability){
            $this->lTotal += $liability['total_amount'];
            $larray[] = ['ledger_name' => $liability['ledger_name'], 'amount' => $liability['total_amount'] ];
        }
        
        if($profit_loss > 0){
            $this->lTotal += $profit_loss;
            $larray[] = [ 'ledger_name' => 'Profit & Loss A/c', 'amount' => $profit_loss ];
        }
        
        foreach($assets as $asset){
            $this->aTotal += $asset['total_amount'];
            $iarray[] = ['ledger_name' => $asset['ledger_name'], 'amount' => $asset['total_amount'] ];
        }
        
        if($profit_loss < 0){
            $this->aTotal += (-$profit_loss);
            $iarray[] = [ 'ledger_name' => 'Profit & Loss A/c', 'amount' => -$profit_loss ];
        }
        
        if($this->lTotal < $this->aTotal){
            $op_bal = $this->aTotal-$this->lTotal;
            $this->lTotal += $op_bal;
            $larray[] = [ 'ledger_name' => 'Difference In Opening Balance', 'amount' => $op_bal ];
        }
        
        if($this->lTotal > $this->aTotal){
            $op_bal = $this->lTotal-$this->aTotal;
            $this->aTotal += $op_bal;
            $iarray[] = [ 'ledger_name' => 'Difference In Opening Balance', 'amount' => $op_bal ];
        }
        
        
        $total_rows = max(count($larray), count($iarray));
        
        for ($i = 0; $i < $total_rows; $i++) {
            $liability_ledger_name = isset($larray[$i]) ? $larray[$i]['ledger_name'] : '';
            $liability_amount = isset($larray[$i]) ? $larray[$i]['amount'] : '';
            $asset_ledger_name = isset($iarray[$i]) ? $iarray[$i]['ledger_name'] : '';
            $asset_amount = isset($iarray[$i]) ? $iarray[$i]['amount'] : '';
              
            // Add the row to the result array
            $result[] = [
                $liability_ledger_name,  // Column A: Ledger Name (Liability)
                $liability_amount,       // Column B: Total Amount (Liability)
                $asset_ledger_name,   // Column C: Ledger Name (Asset)
                $asset_amount         // Column D: Total Amount (Asset)
            ];
        }
        
        return collect($result);
    }
    
    public function headings(): array
    {
        return [
            'Liability',
            'Amount',
            'Asset',
            'Amount',
        ];
    }
    
    public function title(): string
    {
        return 'Balance Sheet';
    }
    
    public function styles(Worksheet $sheet)
    {
        $sheet->getColumnDimension('A')->setWidth(50);
        $sheet->getColumnDimension('B')->setWidth(20);
        $sheet->getColumnDimension('C')->setWidth(50);
        $sheet->getColumnDimension('D')->setWidth(20);
            
        $sheet->getStyle('A1:D1')->applyFromArray([
            'font' => [
                'bold' => true,
                'size' => 12,
            ],
            'alignment' => [
                'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                'vertical' => \PhpOffice\PhpSpreadsheet\Style\Alignment::VERTICAL_CENTER,
            ],
            'fill' => [
                'fillType' => \PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID,
                'startColor' => [
                    'rgb' => 'FFFF00',
                ]
            ]
        ]);
        
        return [];
    }
    
    public function registerEvents(): array
    {
        return [
            AfterSheet::class => function (AfterSheet $event) {
                $sheet = $event->sheet;
                    
                // Insert the title row before the column headings (row 1)
                $sheet->insertNewRowBefore(1, 1); // Insert a new row at position 1 for the title
                $sheet->setCellValue('A1', 'Balance Sheet From '.date('d-m-Y',strtotime($this->startDate)).' To '.date('d-m-Y',strtotime($this->endDate)));
                $sheet->mergeCells('A1:D1');
                $sheet->getStyle('A1')->applyFromArray([
                    'font' => [
                        'bold' => true,
                        'size' => 14,
                    ],
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER,
                    ]
                ]);
                
                $lastRow = $sheet->getHighestRow()+1;
                $sheet->setCellValue('A'.$lastRow, 'TOTAL');
                $sheet->setCellValue('B'.$lastRow, $this->lTotal);
                $sheet->setCellValue('C'.$lastRow, 'TOTAL');
                $sheet->setCellValue('D'.$lastRow, $this->aTotal);
                
                $sheet->getStyle('A'.$lastRow.':D'.$lastRow)->applyFromArray([
                    'font' => [
                        'bold' => true,
                    ]
                ]);
                
                $sheet->getStyle('A2:D'.$lastRow)->applyFromArray([
                    'font' => [
                        'name' => 'Calibri',
                        'size' => 12,
                    ],
                    'borders' => [
                        'allBorders' => [
                            'borderStyle' => \PhpOffice\PhpSpreadsheet\Style\Border::BORDER_THIN,
                            'color' => ['argb' => '000000'],
                        ],
                    ],
                ]);
                    
                $sheet->getRowDimension(1)->setRowHeight(25);
                $sheet->getRowDimension(2)->setRowHeight(20);
                
                $sheet->getStyle('B3:B'.$lastRow)->applyFromArray([
                    'numberFormat' => [
                        'formatCode' => '0.00',
                    ],
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_RIGHT,
                    ]
                ]);
                
                $sheet->getStyle('D3:D'.$lastRow)->applyFromArray([
                    'numberFormat' => [
                        'formatCode' => '0.00',
                    ],
                    'alignment' => [
                        'horizontal' => \PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_RIGHT,
                    ]
                ]);
            }
        ];
    }
}
