<?php

namespace App\Http\Controllers\Accounts;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Ledger;
use App\Models\Accounttype;
use App\Models\AccountSetting;
use App\Models\AccountMainGroup;
use App\Models\AccountSubGroup;
use App\Models\Vouchertype;
use App\Models\Voucher;
use App\Models\MenuAccess;

class Settings extends Controller
{
    public function preference(){
        
        $ledgers = Ledger::all();
        $actypes = Accounttype::all();
        $acsettings = AccountSetting::all();
        
        return view('account.settings.preference',compact('ledgers','actypes','acsettings'));
    }
    
    public function preference_update(Request $request){
        
        $request->validate([
            'actype_id' => 'required|array',
            'ledger' => 'required|array',
        ]);
        
        foreach ($request->ledger as $key => $ledgerId) {
            $accountSetting = AccountSetting::where('ledger_id', $ledgerId)->first();
            if($accountSetting){
                $accountSetting->update([
                    'accounttype_id' => $request->actype_id[$key],
                ]);
            } 
        }
        
        if($accountSetting){
            $msgarray=array('message'=>'Account Setting Updated Successfully','alert-type'=>'success');
        }else{
            $msgarray=array('message'=>'Account Setting Could not be Updated','alert-type'=>'error');
        }
        return redirect()->route('accounts.preference')->with($msgarray);
    }
    
    public function actype(){
        
        $actypes = Accounttype::all();
        
        return view('account.settings.actype',compact('actypes'));
    }
    
    public function actype_update($actype){
        
        $update1 = Accounttype::whereNull('deleted_at')->update(['default1' => 0]);
        $update2 = Accounttype::find($actype)->update(['default1' => 1]);
        
        if($update1 && $update2){
            $msg_array = array('message'=>'Account Type Updated Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Account Type Could not be Updated !','alert-type'=>'error');
        }
        return redirect()->route('accounts.actype')->with($msg_array);
    }
    
    public function groups(){
        $maingroups = AccountMainGroup::all();
        $add=0;
        if(MenuAccess::have_access(576) == true){ $add=1; }
          
        return view('account.settings.groups',compact('maingroups','add'));
    }
    
    public function getGroups(Request $request){
        
        $col_order = [null,'subgroup','main_group','dc'];
        $total_data = AccountSubGroup::whereNull('deleted_at')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = AccountSubGroup::leftJoin('account_main_group','account_sub_group.acmaingrp_id','=','account_main_group.acmaingrp_id')->whereNull('account_sub_group.deleted_at');
            
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('account_sub_group.subgroup','like',$search.'%')->
                    orWhere('account_main_group.main_group','like','%'.$search.'%')->
                    orWhere('account_sub_group.dc','like','%'.$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('account_sub_group.*','account_main_group.main_group')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('account_sub_group.acsubgrp_id','ASC');
        }
        $acgroups = $query->get();
            
        $edit=$delete=0;
        if(MenuAccess::have_access(156) == true){ $edit=1; }
        if(MenuAccess::have_access(157) == true){ $delete=1; }
        
        $data = array();
        if($acgroups){
            $i=$start;
            foreach($acgroups as $acgroup){
                $row['sno'] = ++$i;
                $row['sgroup'] = $acgroup->subgroup;
                $row['mgroup'] = $acgroup->main_group;
                $row['dc'] = $acgroup->dc;
                
                $html="";
                if($edit==1){
                    $html .= '<a href="'.route('accounts.group.edit',encrypt($acgroup->acsubgrp_id)).'" title="Edit"><i class="icon-sm icon-pencil text-success"></i></a>&nbsp;&nbsp;&nbsp;';
                }
                if($delete==1){
                    $html .= '<a href="'.route('accounts.group.delete',encrypt($acgroup->acsubgrp_id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function group_save(Request $request){
         
        $validated = $request->validate([
                        'main_id' => 'required',
                        'subgroup' => 'required|unique:account_sub_group,subgroup',
                    ]);
        $accountmaingroup = AccountMainGroup::find($request->main_id);
        $success = AccountSubGroup::create([
            'acmaingrp_id' => $request->main_id,
            'subgroup' => $request->subgroup,
            'dc' => $accountmaingroup->dc,
        ]);
        if($success){
            $msg_array = array('message'=>'Account Group Created Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Account Group Could not be Created !','alert-type'=>'error');
        }
        return redirect()->route('accounts.groups')->with($msg_array); 
    }
    
    public function group_edit($sid){
        $maingroups = AccountMainGroup::all();
        $subgroup = AccountSubGroup::find(decrypt($sid));
        
        return view('account.settings.edit_group',compact('maingroups','subgroup'));
    }
    
    public function group_update(Request $request){
        
        $sub_id = decrypt($request->sub_id);
        $subgroup = AccountSubGroup::find($sub_id);
        
        $validated = $request->validate([
                        'main_id' => 'required',
                        'subgroup' => 'required|unique:account_sub_group,subgroup,'.$sub_id.',acsubgrp_id',
                    ]);
        $accountmaingroup = AccountMainGroup::find($request->main_id);
        $update = $subgroup->update([
            'acmaingrp_id' => $request->main_id,
            'subgroup' => $request->subgroup,
            'dc' => $accountmaingroup->dc,
        ]);
        
        if($update){
            $msg_array = array('message'=>'Account Group Updated Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Account Group Could not be Updated !','alert-type'=>'error');
        }
        return redirect()->route('accounts.groups')->with($msg_array);
    }
    
    public function group_delete($sid){
        $subgroup = AccountSubGroup::find(decrypt($sid));
        if($subgroup){
            $ledgers = Ledger::where('ag_id',decrypt($sid))->count();
            if($ledgers==0){
                $subgroup->delete();
                $msg_array = array('message'=>'Account Group Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Account Group Could not be Deleted !','alert-type'=>'error');
            }
        }
        
        return redirect()->route('accounts.groups')->with($msg_array);
    }
    
    public function vtypes(){
        $vtypes = Vouchertype::all();
        $add=0;
        if(MenuAccess::have_access(581) == true){ $add=1; }
          
        return view('account.settings.vtypes',compact('vtypes','add'));
    }
    
    public function vtype_save(Request $request){
         
        $validated = $request->validate([
                        'vocher_type' => 'required',
                        'vocher_type_name' => 'required|unique:vouchertypes,vtype_name',
                    ]);
            
        $success = Vouchertype::create([
            'vid' => $request->vocher_type,
            'vtype_name' => $request->vocher_type_name,
        ]);
        if($success){
            $msg_array = array('message'=>'Voucher Type Created Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Voucher Type Could not be Created !','alert-type'=>'error');
        }
        return redirect()->route('accounts.vtypes')->with($msg_array); 
    }
    
    public function vtype_edit($vid){
        $vtypes = Vouchertype::all();
        $vctype = Vouchertype::find(decrypt($vid));
        
        return view('account.settings.edit_vtype',compact('vtypes','vctype'));
    }
    
    public function vtype_update(Request $request){
        
        $vtype_id = decrypt($request->vtype_id);
        $vtype = Vouchertype::find($vtype_id);
        
        $validated = $request->validate([
                        'vocher_type' => 'required',
                        'vocher_type_name' => 'required|unique:vouchertypes,vtype_name,'.$vtype_id.',id',
                    ]);
            
        $update = $vtype->update([
            'vid' => $request->vocher_type,
            'vtype_name' => $request->vocher_type_name,
        ]);
        
        if($update){
            $msg_array = array('message'=>'Voucher Type Updated Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Voucher Type Could not be Updated !','alert-type'=>'error');
        }
        return redirect()->route('accounts.vtypes')->with($msg_array);
    }
    
    public function vtype_delete($vid){
        $vtype = Vouchertype::find(decrypt($vid));
        if($vtype){
            $vouchers = Voucher::where('vtype_id',decrypt($vid))->count();
            if($vouchers==0){
                $vtype->delete();
                $msg_array = array('message'=>'Voucher Type Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Voucher Type Could not be Deleted !','alert-type'=>'error');
            }
        }
        
        return redirect()->route('accounts.vtypes')->with($msg_array);
    }
}