<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\Course;
use App\Models\Semester;
use App\Models\Electives;
use App\Models\Student;

use App\Models\Specialisation;

class Courses extends Controller
{
    public function add(){
        return view('course.add');
    }
    
    public function save(Request $request){
        
        $validated = $request->validate([
            'course_name' => 'required|unique:courses,course_name',
            'course_code' =>'required|unique:courses,course_code',
        ]);
        
        $course = Course::create([
            'course_name' => $request->course_name,
            'course_code' =>$request->course_code,
        ]);
        
        if($course){
            $msg_array = array('message'=>'Course Added Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Course Could not be Added !','alert-type'=>'error');
        }
        return redirect()->route('course.add')->with($msg_array);
    }
    
    public function report(){
        
        $courses = Course::all();
        
        return view('course.report',compact('courses'));
    }
    
    public function edit($course_id){
        
        $course_det = Course::find(decrypt($course_id));
        
        return view('course.edit',compact(array('course_det')));
    }
    
    public function update(Request $request){
        
        $course_id = decrypt($request->course_id);
        $validated = $request->validate([
            'course_name' => 'required|unique:courses,course_name,'.$course_id.',course_id',
        ]);
        
        $course = Course::find($course_id);
        $course->update([
            'course_name' => $request->course_name
        ]);
        
        if($course){
            $msg_array = array('message'=>'Course Updated Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Course Could not be Updated !','alert-type'=>'error');
        }
        return redirect()->route('course')->with($msg_array);
    }
    
    public function delete($course_id){
        
        $course = Course::find(decrypt($course_id));
        
        if($course){
            if($course->semesters->count() == 0){
                $course->delete();
                $msg_array = array('message'=>'Course Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Course Could not be Deleted !','alert-type'=>'error');
            }
        }
        
        return redirect()->route('course')->with($msg_array);
    }
    
    
    
   public function specialisation()
   {
       
       $courses=Course::all();
       $special = Specialisation::all();
        
        return view('course.special',compact('special','courses'));
       
   }
    
    
        public function specialisation_save(Request $request){
        
        $validated = $request->validate([
            'specialisation' => 'required|unique:course_specialisation,specialisation',
        ]);
        
        $special = Specialisation::create([
            'course_id' => $request->course_id,
            'specialisation' => $request->specialisation,
        ]);
        
        if($special){
            $msg_array = array('message'=>' Added Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>' Could not be Added !','alert-type'=>'error');
        }
        return redirect()->route('specialisation')->with($msg_array);
    }

     public function specialisation_edit($sid){
        $courses=Course::all();
        $special = Specialisation::find(decrypt($sid));
        
        return view('course.specialedit',compact(array('special','courses')));
    }
   
    
    
       public function specialisation_update(Request $request){
        
        $specialtn_id = decrypt($request->specialtn_id);
        $validated = $request->validate([
            'specialisation' => 'required|unique:course_specialisation,specialisation,'.$specialtn_id.',specialtn_id',
        ]);
        
        $special = Specialisation::find($specialtn_id);
        $special->update([
            'course_id' => $request->course_id,
            'specialisation' => $request->specialisation,
        ]);
        
        if($special){
            $msg_array = array('message'=>' Updated Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>' Could not be Updated !','alert-type'=>'error');
        }
        return redirect()->route('specialisation')->with($msg_array);
    }
 
        public function specialisation_delete($sid){
        
        $special = Specialisation::find(decrypt($sid));
        
 if($special){
            if($special->count() > 0){
                $special->delete();
                $msg_array = array('message'=>'Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>' Could not be Deleted !','alert-type'=>'error');
            }
        }
        
        return redirect()->route('specialisation')->with($msg_array);
    }         
         

       public function addelectives(){
        
        $courses = Course::all();
        $sem=Semester::all();
        
        return view('course.addelectives',compact('courses','sem'));
    }
 
 public function get_elective(Request $request)
 {
    $crs_det = Course::find($request->cid);
    $sem_det = Semester::find($request->sid);
    $specialisation=Specialisation::where('course_id',$request->cid)->get();
    $elective=Electives::all();
    $student=Student::where('course_id',$request->cid)->orWhere('semester_id',$request->sid)->get();
//   echo $student;
    return view('course.addelectivesget',compact('crs_det','sem_det','specialisation','student'));
 }
    
    
public function addelectives_save(Request $request)
{
           $validated = $request->validate([
            'course_id' =>'required',
            'semester_id'=>'required',
        ]);
       $course_id=$request->course_id;
       $semester_id=$request->semester_id;
       
       $i=0;
       foreach($request->student_id as $stdnt)
       {
      
       
       
           $specialisation=$request->post("specialtn_id$stdnt");
           if($specialisation!=NULL)
           {
               
           
           $check=Electives::where('course_id',$course_id)->where('semester_id',$semester_id)->where('student_id',$stdnt)->first();
          if(!$check)
          {
              $addelectives=Electives::create([
                  'course_id'=>$course_id,
                  'semester_id'=>$semester_id,
                  'student_id'=>$stdnt,
                  'specialtn_id'=>$specialisation,
                  ]);
                  if($stdnt){ $i++; }
          }
          
           else
                {
                    $check->update(['specialtn_id' => $specialisation]);
                    $i++;
                }
           }
       }
       
      if($i>0){
            $msg_array = array('message'=>'Electives Added Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Electives Could not be Added !','alert-type'=>'error');
        }  
       return redirect()->route('addelectives')->with($msg_array);

}
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
}
