<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\UserType;
use App\Models\Semester;
use App\Models\Library\LibrarySubcategory;
use App\Models\Library\LibrarySublocation;
use App\Models\Library\LibraryMembership;
use App\Models\Library\LibraryBook;
use App\Models\Library\LibraryIssue;
use App\Models\Library\LibraryFine;
use App\Models\Library\LibraryRenewal;

class Ajax extends Controller
{
    public function counts(){
        
        $books = LibraryBook::whereNull('deleted_at')->count();
        $members = LibraryMembership::selectRaw('
                        SUM(CASE WHEN membership_type = 1 THEN 1 ELSE 0 END) as staff,
                        SUM(CASE WHEN membership_type = 2 THEN 1 ELSE 0 END) as student,
                        SUM(CASE WHEN membership_type = 3 THEN 1 ELSE 0 END) as other
                    ')->first();
        
        $data = array('0'=>$books,'1'=>$members->staff,'2'=>$members->student,'3'=>$members->other);
        echo json_encode($data);
    }
    
    public function designations(Request $request){
        
        $type = $request->get('staff_type');
        $designations = array();
        $query = UserType::whereNull('deleted_at');
        if($type!=''){
            $query->where('staftyp_id',$type);
        }
        $results = $query->get();
        
        foreach($results as $result){
            $designations[$result->type_id] = $result->type_name;
        }
        return json_encode($designations);
    }
    
    public function semesters(Request $request){
        
        $course = $request->get('course');
        $semesters = array();
        $query = Semester::whereNull('deleted_at');
        if($course!=''){
            $query->where('course_id',$course);
        }
        $results = $query->get();
        
        foreach($results as $result){
            $semesters[$result->semester_id] = $result->semester_name;
        }
        return json_encode($semesters);
    }
    
    public function subcategories(Request $request){
        
        $category = $request->get('category');
        $subcategories = array();
        $query = LibrarySubcategory::whereNull('deleted_at');
        if($category!=''){
            $query->where('category_id',$category);
        }
        $results = $query->get();
        
        foreach($results as $result){
            $subcategories[$result->id] = $result->name;
        }
        return json_encode($subcategories);
    }
    
    public function sublocations(Request $request){
        
        $location = $request->get('location');
        $sublocations = array();
        $query = LibrarySublocation::whereNull('deleted_at');
        if($location!=''){
            $query->where('location_id',$location);
        }
        $results = $query->get();
        
        foreach($results as $result){
            $sublocations[$result->id] = $result->name;
        }
        return json_encode($sublocations);
    }
    
    public function searchMembers(Request $request){
        
        $skey = $request->input('skey');
        $mtype = $request->input('mtype');
        $members = [];
        if($skey){
            $query = LibraryMembership::where('member_name', 'LIKE', "%$skey%")
                        ->where('status', 'Active');
            if($mtype && $mtype!=''){
                $query->where('membership_type',$mtype);
            }
            $members = $query->select('id', 'membership_no','member_name')
                        ->get();
        }
        
        return response()->json($members);
    }
    
    public function getMember(Request $request){
        $barcode = $request->input('barcode');
        $memberno = $request->input('memberno');
        $member = $request->input('member');
        
        $member_det = [];
        $query = LibraryMembership::query();
        if($barcode!=''){
            $query->where('barcode', $barcode);
        }else if($memberno!=''){
            $query->where('membership_no', $memberno);
        }else if($member!=''){
            $query->where('id', $member);
        }
        
        $member_det = $query->first();
        if($member_det){
            return response()->json([
                    'success' => true,
                    'message' => 'Member Found.',
                    'memberid' => $member_det->id
                ], 200);
        }else{
            return response()->json([
                    'success' => false,
                    'message' => 'membership not found.',
                ], 500);
        }
    }
    
    public function viewMember(Request $request){
        $mid = $request->input('mid');
        $member_det = LibraryMembership::find($mid);
        return view('library.issue.member',compact('member_det'));
    }
    
    public function searchBooks(Request $request){
        
        $skey = $request->input('skey');
        $books = [];
        if($skey){
            $books = LibraryBook::where('title', 'LIKE', "%$skey%")
                        ->where('status', 'Active')
                        ->select('id', 'book_no','title')
                        ->get();
        }
        
        return response()->json($books);
    }
    
    public function addBook(Request $request){
        $memberid = $request->input('memberid');
        $bookcode = $request->input('bookcode');
        $bookno = $request->input('bookno');
        $book = $request->input('book');
        
        $member = LibraryMembership::find($memberid);
        $book_det = [];
        $query = LibraryBook::query();
        if($bookcode!=''){
            $query->where('barcode', $bookcode);
        }else if($bookno!=''){
            $query->where('book_no', $bookno);
        }else if($book!=''){
            $query->where('id', $book);
        }
        
        $book_det = $query->first();
        
        if($member && $book_det){
            $duration = $member->membertype?->validity ?? 7;
            $duedate = date('Y-m-d',strtotime('+'.$duration.' days'));
            
            $issued = $book_det->issues()->whereIn('status',['Temporary','Issued'])->count();
            $bal = $book_det->copies-$issued;
            if($bal > 0){
                LibraryIssue::create([
                        'type_id' => $member->membership_type,
                        'member_id' => $member->id,
                        'book_id' => $book_det->id,
                        'issue_date' => date('Y-m-d'),
                        'due_date' => $duedate,
                    ]);
                    
                return response()->json([
                        'success' => true,
                        'status' => true,
                        'message' => 'Saved Successfully.',
                        'memberid' => $memberid,
                    ], 200);
            }else{
                return response()->json([
                        'success' => true,
                        'status' => false,
                        'message' => 'Book is not Available',
                    ], 200);
            }
        }else{
            return response()->json([
                    'success' => false,
                    'message' => 'Failed to save.',
                ], 500);
        }
    }
    
    public function viewBook(Request $request){
        $mid = $request->input('mid');
        $issuetemps = LibraryIssue::where('member_id',$mid)->where('status','Temporary')->get();
        if($issuetemps->count()>0){
            return view('library.issue.book',compact('issuetemps'));
        }
    }
    
    public function deleteIssue(Request $request){
        $tid = $request->input('tid');
        $issuetemp = LibraryIssue::find($tid);
        if($issuetemp){
            $mid = $issuetemp->member_id;
            $issuetemp->delete();
            return response()->json([
                    'success' => true,
                    'message' => 'Book Deleted.',
                    'memberid' => $mid
                ], 200);
        }else{
            return response()->json([
                    'success' => false,
                    'message' => 'Book not found.',
                ], 500);
        }
    }
    
    public function issueBooks(Request $request){
        $mid = $request->input('mid');
        if($mid){
            $member = LibraryMembership::find($mid);
            $duration = $member->membertype?->validity ?? 7;
            $duedate = date('Y-m-d',strtotime('+'.$duration.' days'));
            $update = LibraryIssue::where('member_id',$mid)->where('status','Temporary')->update(['issue_date' => date('Y-m-d'),'due_date' => $duedate,'status' => 'Issued']);
            if($update){
                return response()->json([
                    'success' => true,
                    'message' => 'Book Issued.',
                    'memberid' => $mid
                ], 200);
            }else{
                return response()->json([
                    'success' => false,
                    'message' => 'Book not Issued.',
                ], 500);
            }
        }else{
            return response()->json([
                    'success' => false,
                    'message' => 'Invalid Member.',
                ], 500);
        }
    }

    public function returnBooks(Request $request){
        $posted = $request->input('posted', []);
        if(!empty($posted)){
            $update = LibraryIssue::whereIn('id',$posted)->update(['status'=>'Returned','return_date'=>date('Y-m-d')]);
            if($update){
                foreach($posted as $post){
                    $issue = LibraryIssue::find($post);
                    $fine = $issue->fine_amount ?? 0;
                    if($fine > 0){
                        LibraryFine::create([
                                'issue_id' => $issue->id,
                                'date' => date('Y-m-d'),
                                'amount' => $fine
                            ]);
                    }
                }
                
                return response()->json([
                    'success' => true,
                    'message' => 'Books Returned.',
                ], 200);
            }else{
                return response()->json([
                    'success' => false,
                    'message' => 'Book not Issued.',
                ], 500);
            }
        }else{
            return response()->json([
                    'success' => false,
                    'message' => 'Invalid Member.',
                ], 500);
        }
    }

    public function renewBooks(Request $request){
        $mid = $request->input('mid');
        $posted = $request->input('posted', []);
        if($mid && !empty($posted)){
            $member = LibraryMembership::find($mid);
            $duration = $member->membertype?->validity ?? 7;
            $duedate = date('Y-m-d',strtotime('+'.$duration.' days'));
            
            $i=0;
            foreach($posted as $post){
                $issue = LibraryIssue::find($post);
                $old_due = $issue->due_date;
                if($issue->update(['due_date'=>$duedate])){
                    LibraryRenewal::create([
                            'issue_id' => $issue->id,
                            'past_date' => $old_due,
                            'cur_date' => date('Y-m-d'),
                            'new_date' => $duedate
                        ]);
                        
                    $i++;
                }
            }
            
            if($i>0){
                return response()->json([
                    'success' => true,
                    'message' => 'Books Renewed.',
                ], 200);
            }else{
                return response()->json([
                    'success' => false,
                    'message' => 'Book not Renewed.',
                ], 500);
            }
        }else{
            return response()->json([
                    'success' => false,
                    'message' => 'Invalid Member.',
                ], 500);
        }
    }
}
