<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Log;

use App\Models\Library\LibraryCategory;
use App\Models\MenuAccess;

class Categories extends Controller
{
    public function report(){
        try {
            return view('library.category.report');
        } catch (\Exception $e) {
            Log::error('Failed to fetch Categories: ' . $e->getMessage());
            return back()->withErrors('Failed to load Categories.');
        }
    }
    
    public function getData(Request $request){
        
        $col_order = ['code','name'];
        $total_data = LibraryCategory::whereNull('deleted_at')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = LibraryCategory::whereNull('deleted_at');
            
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('code','like','%'.$search.'%')->
                    orWhere('name','like',$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('*')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('library_categories.name','ASC');
        }
        
        $categories = $query->get();
        
        $edit = MenuAccess::have_access(80) ? 1:0;
        $delete = MenuAccess::have_access(79) ? 1:0;
        
        $data = array();
        if($categories){
            foreach($categories as $category){
                $row['code'] = $category->code;
                $row['name'] = $category->name;
                $html="";
                if($edit==1){
                    $html .= '<a href="'.route('library.category.edit',encrypt($category->id)).'" title="Edit"><i class="icon-sm icon-pencil text-success"></i></a>&nbsp;&nbsp;&nbsp;';
                }
                if($delete==1){
                    $html .= '<a href="'.route('library.category.delete',encrypt($category->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function save(Request $request){
        try {
            $validated = $request->validate([
                    'code' => 'required|unique:library_categories,code',
                    'name' => 'required|unique:library_categories,name'
                ]);
                
            $saved = LibraryCategory::create($validated);
            if($saved){
                $msg_array = array('message'=>'Book Category Created Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Category Could not be Created !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Category creation failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Book Category Could not be Created !','alert-type'=>'error');
        }
            
        return redirect()->route('library.category')->with($msg_array);
    }
    
    public function edit($cid){
        try {
            $category = LibraryCategory::findOrFail(decrypt($cid));
            return view('library.category.edit',compact('category'));
        } catch (ModelNotFoundException $e) {
            return redirect()->route('library.category')->withErrors('category not found.');
        } catch (\Exception $e) {
            Log::error('Error loading Categories for edit: ' . $e->getMessage());
            return back()->withErrors('Failed to load the category for editing.');
        }
    }
    
    public function update(Request $request, $id)
    {
        $cid = decrypt($id);
        try {
            $validated = $request->validate([
                'code' => 'required|unique:library_categories,code,'.$cid.',id',
                'name' => 'required|unique:library_categories,name,'.$cid.',id'
            ]);
                
            $category = LibraryCategory::findOrFail($cid);
            $category->update($validated);
            $msg_array = array('message'=>'Book Category Updated Successfully !','alert-type'=>'success');
        } catch (\Exception $e) {
            Log::error('Category update failed: '.$e->getMessage());
            $msg_array = array('message'=>'Book Category Could not be Updated !','alert-type'=>'error');
        }
        
        return redirect()->route('library.category')->with($msg_array);
    }
    
    public function delete($id)
    {
        $cid = decrypt($id);
        try {
            $category = LibraryCategory::findOrFail($cid);
            
            if($category->subcats->count() ==0){
                $category->delete();
                $msg_array = array('message'=>'Book Category Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Category Could not be Deleted !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Category deletion failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Book Category Could not be Deleted !','alert-type'=>'error');
        }
        
        return redirect()->route('library.category')->with($msg_array);
    }
}
