<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Library\LibraryIssue;
use App\Models\Library\LibraryMemberType;

class Issues extends Controller
{
    public function add(){
       
        return view('library.issue.add');
    }
    
    public function report(){
        $types = LibraryMemberType::all();
        
        return view('library.issue.report',compact('types'));
    }
    
    public function getData(Request $request){
            
        $colOrder = ['membership_no', 'member_name', 'title', 'author', 'issue_date', 'due_date', null, 'return_date', 'status'];
            
        $limit = $request->input('length', 10);
        $start = $request->input('start', 0);
        $orderIndex = $request->input('order.0.column', 0);
        $order = $colOrder[$orderIndex] ?? 'id';
        $dir = $request->input('order.0.dir', 'asc');
        
        $mtype = $request->get('mtype') ?? null;
        $member = $request->get('member') ?? null;
        $book = $request->get('book') ?? null;
        $status = $request->get('status') ?? null;
        $ifdate = $request->get('ifdate') ?? null;
        $itdate = $request->get('itdate') ?? null;
        $dfdate = $request->get('dfdate') ?? null;
        $dtdate = $request->get('dtdate') ?? null;
        $rfdate = $request->get('rfdate') ?? null;
        $rtdate = $request->get('rtdate') ?? null;
            
        // Base query
        $query = LibraryIssue::query()
            ->leftJoin('library_memberships', 'library_issues.member_id', '=', 'library_memberships.id')
            ->leftJoin('library_books', 'library_issues.book_id', '=', 'library_books.id')
            ->leftJoin('library_member_types', 'library_issues.type_id', '=', 'library_member_types.id')
            ->whereNull('library_issues.deleted_at');
            
        if($mtype){
            $query->where('library_issues.type_id',$mtype);
        }
        if($member){
            $query->where('library_issues.member_id',$member);
        }
        if($book){
            $query->where('library_issues.book_id',$book);
        }
        if($status){
            $query->where('library_issues.status',$status);
        }
        if($ifdate){
            $query->where('library_issues.issue_date','>=',$ifdate);
        }
        if($itdate){
            $query->where('library_issues.issue_date','<=',$itdate);
        }
        if($dfdate){
            $query->where('library_issues.due_date','>=',$dfdate);
        }
        if($dtdate){
            $query->where('library_issues.due_date','<=',$dtdate);
        }
        if($rfdate){
            $query->where('library_issues.return_date','>=',$rfdate);
        }
        if($rtdate){
            $query->where('library_issues.return_date','<=',$rtdate);
        }
        
            
        // Search box filtering
        if ($search = $request->input('search.value')) {
            $query->where(function ($qry) use ($search) {
                $qry->where('library_memberships.membership_no', 'like', "%$search%")
                    ->orWhere('library_memberships.member_name', 'like', "%$search%")
                    ->orWhere('library_books.title', 'like', "%$search%")
                    ->orWhere('library_books.author', 'like', "%$search%")
                    ->orWhere('library_issues.issue_date', 'like', "%$search%")
                    ->orWhere('library_issues.due_date', 'like', "%$search%")
                    ->orWhere('library_issues.return_date', 'like', "%$search%")
                    ->orWhere('library_issues.status', 'like', "%$search%");
            });
        }
            
        // Get total filtered count before applying pagination
        $totalFiltered = $query->count();
            
        // Select necessary columns and apply ordering, pagination
        $issues = $query->select(
                'library_issues.*',
                'library_memberships.membership_no',
                'library_memberships.member_name',
                'library_books.title',
                'library_books.author')
            ->orderBy($order, $dir)
            ->offset($start)
            ->limit($limit)
            ->get();
            
        // Prepare data for response
        $data = [];
        foreach ($issues as $issue) {
            $row = [
                'mno' => htmlspecialchars($issue->membership_no),
                'member' => htmlspecialchars($issue->member_name),
                'book' => htmlspecialchars($issue->title),
                'author' => htmlspecialchars($issue->author),
                'issue' => $issue->issue_date ? date('d/m/Y',strtotime($issue->issue_date)):'',
                'due' => $issue->due_date ? date('d/m/Y',strtotime($issue->due_date)):'',
                'fine' => $issue->fine_amount,
                'return' => $issue->return_date ? date('d/m/Y',strtotime($issue->return_date)):'',
                'status' => htmlspecialchars($issue->status)
            ];
            $data[] = $row;
        }
            
        // Return JSON response
        return response()->json([
            'draw' => intval($request->input('draw')),
            'recordsTotal' => LibraryIssue::whereNull('deleted_at')->count(),
            'recordsFiltered' => $totalFiltered,
            'data' => $data
        ]);
    }
}
