<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Log;

use App\Models\Library\LibraryLocation;
use App\Models\MenuAccess;

class Locations extends Controller
{
    public function report(){
        try {
            return view('library.location.report');
        } catch (\Exception $e) {
            Log::error('Failed to fetch Locations: ' . $e->getMessage());
            return back()->withErrors('Failed to load Locations.');
        }
    }
    
    public function getData(Request $request){
        
        $col_order = ['code','name'];
        $total_data = LibraryLocation::whereNull('deleted_at')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = LibraryLocation::whereNull('deleted_at');
            
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('code','like','%'.$search.'%')->
                    orWhere('name','like',$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('*')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('library_locations.name','ASC');
        }
        
        $locations = $query->get();
        
        $edit = MenuAccess::have_access(86) ? 1:0;
        $delete = MenuAccess::have_access(87) ? 1:0;
        
        $data = array();
        if($locations){
            foreach($locations as $location){
                $row['code'] = $location->code;
                $row['name'] = $location->name;
                $html="";
                if($edit==1){
                    $html .= '<a href="'.route('library.location.edit',encrypt($location->id)).'" title="Edit"><i class="icon-sm icon-pencil text-success"></i></a>&nbsp;&nbsp;&nbsp;';
                }
                if($delete==1){
                    $html .= '<a href="'.route('library.location.delete',encrypt($location->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function save(Request $request){
        try {
            $validated = $request->validate([
                    'code' => 'required|unique:library_locations,code',
                    'name' => 'required|unique:library_locations,name'
                ]);
                
            $saved = LibraryLocation::create($validated);
            if($saved){
                $msg_array = array('message'=>'Book Location Created Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Location Could not be Created !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Book Location creation failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Book Location Could not be Created !','alert-type'=>'error');
        }
            
        return redirect()->route('library.location')->with($msg_array);
    }
    
    public function edit($lid){
        try {
            $location = LibraryLocation::findOrFail(decrypt($lid));
            return view('library.location.edit',compact('location'));
        } catch (ModelNotFoundException $e) {
            return redirect()->route('library.location')->withErrors('location not found.');
        } catch (\Exception $e) {
            Log::error('Error loading Location for edit: '.$e->getMessage());
            return back()->withErrors('Failed to load the location for editing.');
        }
    }
    
    public function update(Request $request, $id)
    {
        $lid = decrypt($id);
        try {
            $validated = $request->validate([
                'code' => 'required|unique:library_locations,code,'.$lid.',id',
                'name' => 'required|unique:library_locations,name,'.$lid.',id'
            ]);
                
            $location = LibraryLocation::findOrFail($lid);
            $location->update($validated);
            $msg_array = array('message'=>'Book Location Updated Successfully !','alert-type'=>'success');
        } catch (\Exception $e) {
            Log::error('Book Location update failed: '.$e->getMessage());
            $msg_array = array('message'=>'Book Location Could not be Updated !','alert-type'=>'error');
        }
        
        return redirect()->route('library.location')->with($msg_array);
    }
    
    public function delete($id)
    {
        $lid = decrypt($id);
        try {
            $location = LibraryLocation::findOrFail($lid);
            
            if($location->sublocs->count()==0 && $location->books->count()==0){
                $location->delete();
                $msg_array = array('message'=>'Book Location Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Location Could not be Deleted !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Book Location deletion failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Book Location Could not be Deleted !','alert-type'=>'error');
        }
        
        return redirect()->route('library.location')->with($msg_array);
    }
}
