<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Log;

use App\Models\Library\LibraryMemberType;

class MemberTypes extends Controller
{
    public function report(){
        try {
            $types = LibraryMemberType::all();
            
            return view('library.membertype.report',compact('types'));
        } catch (\Exception $e) {
            Log::error('Failed to fetch Member Types: ' . $e->getMessage());
            return back()->withErrors('Failed to load Member Types.');
        }
    }
    
    public function edit($tid){
        try {
            $type = LibraryMemberType::findOrFail(decrypt($tid));
            return view('library.membertype.edit',compact('type'));
        } catch (ModelNotFoundException $e) {
            return redirect()->route('library.membertype')->withErrors('Member Type not found.');
        } catch (\Exception $e) {
            Log::error('Error loading Member Type for edit: '.$e->getMessage());
            return back()->withErrors('Failed to load the Member Type for editing.');
        }
    }
    
    public function update(Request $request, $id)
    {
        try {
            $validated = $request->validate([
                'books' => 'required|numeric',
                'validity' => 'required|numeric',
                'fine_amount' => 'required|numeric',
                'fine_per' => 'required|numeric',
                'fine_day' => 'required',
            ]);
                
            $type = LibraryMemberType::findOrFail(decrypt($id));
            $type->update($validated);
            $msg_array = array('message'=>'Member Type Updated Successfully !','alert-type'=>'success');
        } catch (\Exception $e) {
            Log::error('Member Type update failed: '.$e->getMessage());
            $msg_array = array('message'=>'Member Type Could not be Updated !','alert-type'=>'error');
        }
        
        return redirect()->route('library.membertype')->with($msg_array);
    }
}
