<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\File;

use App\Models\Library\LibraryMembership;
use App\Models\Stafftype;
use App\Models\User;
use App\Models\Course;
use App\Models\Acyear;
use App\Models\Student;
use App\Models\Library\LibraryMembersOther;
use App\Models\MenuAccess;

use Milon\Barcode\DNS1D;

class Memberships extends Controller
{
    protected $acyearId;
    
    public function __construct()
    {
        $acyear = Acyear::where('default1',1)->first();
        $this->acyearId = $acyear->ac_id;
    }
    
    public function staff(){
        try {
            $types = Stafftype::all();
            
            return view('library.membership.staff',compact('types'));
        } catch (\Exception $e) {
            Log::error('Failed to fetch Members: '.$e->getMessage());
            return back()->withErrors('Failed to load Members.');
        }
    }
    
    public function staff_ajax(Request $request){
        
        $col_order = ['membership_no','name','stype','designation','membership_date','mobile','status'];
        $total_data = LibraryMembership::where('membership_type',1)->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = LibraryMembership::join('users','library_memberships.membership_user','=','users.user_id')
                    ->leftJoin('staff_type','users.staftyp_id','=','staff_type.staftyp_id')
                    ->leftJoin('user_types','users.type_id','=','user_types.type_id')
                    ->where('library_memberships.membership_type',1);
        
        if($stype = $request->get('stype')) {
            $query->where('users.staftyp_id', $stype);
        }
        
        if($desig = $request->get('desig')) {
            $query->where('users.type_id', $desig);
        }
        
        if($status = $request->get('status')) {
            $query->where('library_memberships.status', $status);
        }
        
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('library_memberships.membership_no','like','%'.$search.'%')->
                    orWhere('users.name','like',$search.'%')->
                    orWhere('staff_type.type_name','like',$search.'%')->
                    orWhere('user_types.type_name','like',$search.'%')->
                    orWhere('users.mobile','like',$search.'%')->
                    orWhere('library_memberships.status','like',$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('library_memberships.*','users.name','users.mobile','staff_type.type_name as stype', 'user_types.type_name as designation')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('library_memberships.id','ASC');
        }
        
        $memberships = $query->get();
        
        $barcode = MenuAccess::have_access(674) ? 1:0;
        $delete = MenuAccess::have_access(659) ? 1:0;
        
        $data = array();
        if($memberships){
            foreach($memberships as $membership){
                $row['mno'] = $membership->membership_no;
                $row['name'] = $membership->name;
                $row['type'] = $membership->stype;
                $row['desig'] = $membership->designation;
                $row['date'] = date('d/m/Y',strtotime($membership->membership_date));
                $row['contact'] = $membership->mobile;
                $class = '';
                if($membership->status=='Active'){ $class = 'badge-success'; }
                else if($membership->status=='Inactive'){ $class = 'badge-danger'; }
                $row['status'] = '<a href="'.route('library.membership.update',encrypt($membership->id)).'" title="Click to Change Status"><div class="badge '.$class.'">'.$membership->status.'</div></a>';
                $html="";
                if($barcode==1){
                    $html .= '<a href="'.route('library.membership.barcode',encrypt($membership->id)).'" title="Barcode" target="_blank"><i class="icon-sm icon-frame text-dark"></i></a>&nbsp;&nbsp;&nbsp;';
                }
                if($delete==1){
                    $html .= '<a href="'.route('library.membership.delete',encrypt($membership->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function add_staff(){
        try {
            $types = Stafftype::all();
            
            return view('library.membership.add_staff',compact('types'));
        } catch (\Exception $e) {
            Log::error('Failed to fetch Members: '.$e->getMessage());
            return back()->withErrors('Failed to load Members.');
        }
    }
    
    public function staff_list_ajax(Request $request){
        
        $col_order = [null,'name','stype','designation','mobile'];
        $total_data = User::leftJoin('library_memberships', function($join) {
                        $join->on('users.user_id', '=', 'library_memberships.membership_user')
                             ->where('library_memberships.membership_type', '=', 1)
                             ->whereNull('library_memberships.deleted_at');
                    })
                    ->whereNull('library_memberships.membership_user')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = User::leftJoin('library_memberships', function($join) {
                        $join->on('users.user_id', '=', 'library_memberships.membership_user')
                             ->where('library_memberships.membership_type', '=', 1)
                             ->whereNull('library_memberships.deleted_at');
                    })
                    ->leftJoin('staff_type','users.staftyp_id','=','staff_type.staftyp_id')
                    ->leftJoin('user_types','users.type_id','=','user_types.type_id')
                    ->whereNull('library_memberships.membership_user');
        
        if($stype = $request->get('stype')) {
            $query->where('users.staftyp_id', $stype);
        }
        
        if($desig = $request->get('desig')) {
            $query->where('users.type_id', $desig);
        }
        
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('users.name','like','%'.$search.'%')->
                    orWhere('staff_type.type_name','like',$search.'%')->
                    orWhere('user_types.type_name','like',$search.'%')->
                    orWhere('users.mobile','like',$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('users.*','staff_type.type_name as stype', 'user_types.type_name as designation')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('users.user_id','ASC');
        }
        
        $users = $query->get();

        $data = array();
        if($users){
            foreach($users as $user){
                $row['check'] = '<input type="checkbox" class="checkSub" name="posted[]" value="'.$user->user_id.'">';
                $row['name'] = $user->name;
                $row['type'] = $user->stype;
                $row['desig'] = $user->designation;
                $row['contact'] = $user->mobile;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function save_staff(Request $request){
        try{
            $validated = $request->validate([
                    'date' => 'required|date',
                    'posted' => 'array|present'
                ]);
            
            $saved=0;
            $mno_max = LibraryMembership::max('membership_no');
            $mno = $mno_max ? ($mno_max+1):1000;
            
            foreach($validated['posted'] as $uid){
                $user = User::find($uid);
                $insert = LibraryMembership::create([
                            'membership_no' => $mno,
                            'membership_type' => 1,
                            'membership_user' => $uid,
                            'member_name' => $user->name,
                            'barcode' => $user->barcode,
                            'membership_date' => $validated['date']
                        ]);
                if($insert){
                    $mno++;
                    $saved++;
                }
            }
            
            if($saved > 0){
                $msg_array = array('message'=>'Membership Created Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Membership Could not be Created !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Membership creation failed: '.$e->getMessage());
            $msg_array = array('message'=>'Membership Could not be Created !','alert-type'=>'error');
        }
            
        return redirect()->route('library.membership.staff')->with($msg_array);
    }
    
    public function student(){
        try {
            $courses = Course::all();
            
            return view('library.membership.student',compact('courses'));
        } catch (\Exception $e) {
            Log::error('Failed to fetch Members: '.$e->getMessage());
            return back()->withErrors('Failed to load Members.');
        }
    }
    
    public function student_ajax(Request $request){
        
        $col_order = ['membership_no','name','course_name','semester_name','membership_date','mobile','status'];
        $total_data = LibraryMembership::join('promotes', function($join) {
                            $join->on('library_memberships.membership_user', '=', 'promotes.student_id')
                                 ->where('promotes.ac_id', $this->acyearId)
                                 ->whereNull('promotes.deleted_at');
                        })->
                        where('membership_type',2)->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = LibraryMembership::join('students','library_memberships.membership_user','=','students.student_id')
                    ->join('promotes', function($join) {
                        $join->on('students.student_id', '=', 'promotes.student_id')
                             ->where('promotes.ac_id', $this->acyearId);
                    })
                    ->leftJoin('courses','promotes.course_id','=','courses.course_id')
                    ->leftJoin('semesters','promotes.semester_id','=','semesters.semester_id')
                    ->where('library_memberships.membership_type',2);
        
        if($course = $request->get('course')) {
            $query->where('promotes.course_id', $course);
        }
        
        if($semester = $request->get('semester')) {
            $query->where('promotes.semester_id', $semester);
        }
        
        if($status = $request->get('status')) {
            $query->where('library_memberships.status', $status);
        }
        
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('library_memberships.membership_no','like','%'.$search.'%')->
                    orWhere('students.name','like',$search.'%')->
                    orWhere('courses.course_name','like',$search.'%')->
                    orWhere('semesters.semester_name','like',$search.'%')->
                    orWhere('students.mobile','like',$search.'%')->
                    orWhere('library_memberships.status','like',$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('library_memberships.*','students.name','students.mobile','courses.course_name', 'semesters.semester_name')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('library_memberships.id','ASC');
        }
        
        $memberships = $query->get();
        
        $barcode = MenuAccess::have_access(674) ? 1:0;
        $delete = MenuAccess::have_access(659) ? 1:0;
        
        $data = array();
        if($memberships){
            foreach($memberships as $membership){
                $row['mno'] = $membership->membership_no;
                $row['name'] = $membership->name;
                $row['course'] = $membership->course_name;
                $row['semester'] = $membership->semester_name;
                $row['date'] = date('d/m/Y',strtotime($membership->membership_date));
                $row['contact'] = $membership->mobile;
                $class = '';
                if($membership->status=='Active'){ $class = 'badge-success'; }
                else if($membership->status=='Inactive'){ $class = 'badge-danger'; }
                $row['status'] = '<a href="'.route('library.membership.update',encrypt($membership->id)).'" title="Click to Change Status"><div class="badge '.$class.'">'.$membership->status.'</div></a>';
                $html="";
                if($barcode==1){
                    $html .= '<a href="'.route('library.membership.barcode',encrypt($membership->id)).'" title="Barcode" target="_blank"><i class="icon-sm icon-frame text-dark"></i></a>&nbsp;&nbsp;&nbsp;';
                }
                if($delete==1){
                    $html .= '<a href="'.route('library.membership.delete',encrypt($membership->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function add_student(){
        try {
            $courses = Course::all();
            
            return view('library.membership.add_student',compact('courses'));
        } catch (\Exception $e) {
            Log::error('Failed to fetch Members: '.$e->getMessage());
            return back()->withErrors('Failed to load Members.');
        }
    }
    
    public function student_list_ajax(Request $request){
        
        $col_order = [null,'adno','name','course_name','semester_name','mobile'];
        $total_data = Student::join('promotes', function($join) {
                        $join->on('students.student_id', '=', 'promotes.student_id')
                             ->where('promotes.ac_id', $this->acyearId)
                             ->whereNull('promotes.deleted_at');
                    })
                    ->leftJoin('library_memberships', function($join) {
                        $join->on('students.student_id', '=', 'library_memberships.membership_user')
                             ->where('library_memberships.membership_type', '=', 2)
                             ->whereNull('library_memberships.deleted_at');
                    })
                    ->whereNull('library_memberships.membership_user')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = Student::join('promotes', function($join) {
                        $join->on('students.student_id', '=', 'promotes.student_id')
                             ->where('promotes.ac_id', $this->acyearId)
                             ->whereNull('promotes.deleted_at');
                    })
                    ->leftJoin('library_memberships', function($join) {
                        $join->on('students.student_id', '=', 'library_memberships.membership_user')
                             ->where('library_memberships.membership_type', '=', 2)
                             ->whereNull('library_memberships.deleted_at');
                    })
                    ->leftJoin('courses','promotes.course_id','=','courses.course_id')
                    ->leftJoin('semesters','promotes.semester_id','=','semesters.semester_id')
                    ->whereNull('library_memberships.membership_user');
        
        if($course = $request->get('course')) {
            $query->where('promotes.course_id', $course);
        }
        
        if($semester = $request->get('semester')) {
            $query->where('promotes.semester_id', $semester);
        }
        
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('students.adno','like','%'.$search.'%')->
                    orWhere('students.name','like',$search.'%')->
                    orWhere('courses.course_name','like',$search.'%')->
                    orWhere('semesters.semester_name','like',$search.'%')->
                    orWhere('students.mobile','like',$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('students.*','courses.course_name', 'semesters.semester_name')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('students.student_id','ASC');
        }
        
        $students = $query->get();

        $data = array();
        if($students){
            foreach($students as $student){
                $row['check'] = '<input type="checkbox" class="checkSub" name="posted[]" value="'.$student->student_id.'">';
                $row['adno'] = $student->adno;
                $row['name'] = $student->name;
                $row['course'] = $student->course_name;
                $row['semester'] = $student->semester_name;
                $row['contact'] = $student->mobile;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function save_student(Request $request){
        try{
            $validated = $request->validate([
                    'date' => 'required|date',
                    'posted' => 'array|present'
                ]);
            
            $saved=0;
            $mno_max = LibraryMembership::max('membership_no');
            $mno = $mno_max ? ($mno_max+1):1000;
            
            foreach($validated['posted'] as $uid){
                $student = Student::find($uid);
                $insert = LibraryMembership::create([
                            'membership_no' => $mno,
                            'membership_type' => 2,
                            'membership_user' => $uid,
                            'member_name' => $student->name,
                            'barcode' => $student->barcode,
                            'membership_date' => $validated['date']
                        ]);
                if($insert){
                    $mno++;
                    $saved++;
                }
            }
            
            if($saved > 0){
                $msg_array = array('message'=>'Membership Created Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Membership Could not be Created !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Membership creation failed: '.$e->getMessage());
            $msg_array = array('message'=>'Membership Could not be Created !','alert-type'=>'error');
        }
            
        return redirect()->route('library.membership.student')->with($msg_array);
    }
    
    public function others(){
        try {
            return view('library.membership.others');
        } catch (\Exception $e) {
            Log::error('Failed to fetch Members: '.$e->getMessage());
            return back()->withErrors('Failed to load Members.');
        }
    }
    
    public function others_ajax(Request $request){
        
        $col_order = ['membership_no','name','address','mobile','email','membership_date','status'];
        $total_data = LibraryMembership::where('membership_type',3)->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = LibraryMembership::join('library_members_others','library_memberships.membership_user','=','library_members_others.id')
                    ->where('library_memberships.membership_type',3);
                    
        if($status = $request->get('status')) {
            $query->where('library_memberships.status', $status);
        }
        
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('library_memberships.membership_no','like','%'.$search.'%')->
                    orWhere('library_members_others.name','like',$search.'%')->
                    orWhere('library_members_others.address','like',$search.'%')->
                    orWhere('library_members_others.mobile','like',$search.'%')->
                    orWhere('library_members_others.email','like',$search.'%')->
                    orWhere('library_memberships.status','like',$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('library_memberships.*','library_members_others.name','library_members_others.mobile','library_members_others.address', 'library_members_others.email')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('library_memberships.id','ASC');
        }
        
        $memberships = $query->get();
        
        $delete = MenuAccess::have_access(659) ? 1:0;
        
        $data = array();
        if($memberships){
            foreach($memberships as $membership){
                $row['mno'] = $membership->membership_no;
                $row['name'] = $membership->name;
                $row['address'] = $membership->address;
                $row['contact'] = $membership->mobile;
                $row['email'] = $membership->email;
                $row['date'] = date('d/m/Y',strtotime($membership->membership_date));
                $class = '';
                if($membership->status=='Active'){ $class = 'badge-success'; }
                else if($membership->status=='Inactive'){ $class = 'badge-danger'; }
                $row['status'] = '<a href="'.route('library.membership.update',encrypt($membership->id)).'" title="Click to Change Status"><div class="badge '.$class.'">'.$membership->status.'</div></a>';
                $html="";
                if($delete==1){
                    $html .= '<a href="'.route('library.membership.delete',encrypt($membership->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function add_others(){
        try {
            return view('library.membership.add_others');
        } catch (\Exception $e) {
            Log::error('Failed to fetch Members: '.$e->getMessage());
            return back()->withErrors('Failed to load Members.');
        }
    }
    
    public function save_others(Request $request){
        try{
            $validated = $request->validate([
                    'name' => 'required',
                    'address' => 'required',
                    'mobile' => 'required|numeric',
                    'email' => 'nullable|email',
                    'date' => 'required|date',
                ]);
                
            $sno_max = LibraryMembersOther::max('sno');
            $sno = $sno_max ? ($sno_max+1):1000;
            $validated['sno'] = $sno;
            $validated['barcode'] = '3'.rand(10000,99999).$sno;
            
            $mno_max = LibraryMembership::max('membership_no');
            $mno = $mno_max ? ($mno_max+1):1000;
            
            $saved = LibraryMembersOther::create($validated);
            if($saved){
                $insert = LibraryMembership::create([
                            'membership_no' => $mno,
                            'membership_type' => 3,
                            'membership_user' => $saved->id,
                            'member_name' => $validated['name'],
                            'barcode' => $validated['barcode'],
                            'membership_date' => $validated['date']
                        ]);
                $msg_array = array('message'=>'Membership Created Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Membership Could not be Created !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Membership creation failed: '.$e->getMessage());
            $msg_array = array('message'=>'Membership Could not be Created !','alert-type'=>'error');
        }
            
        return redirect()->route('library.membership.others')->with($msg_array);
    }
    
    public function update($mid)
    {
        try {
            $membership = LibraryMembership::findOrFail(decrypt($mid));
            $status = $membership->status;
            if($status == 'Active'){
                $new_status = 'Inactive';
            }else{
                $new_status = 'Active';
            }
            if($membership->update(['status'=>$new_status])){
                $msg_array = array('message'=>'Membership Status Updated Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Membership Status Could not be Updated !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Membership Status Updation failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Membership Status Could not be Updated !','alert-type'=>'error');
        }
        
        return redirect()->back()->with($msg_array);
    }
    
    public function delete($mid)
    {
        try {
            $membership = LibraryMembership::findOrFail(decrypt($mid));
            if($membership->issues->where('status','Issued')->count()==0){
                $membership->delete();
                $msg_array = array('message'=>'Membership Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Membership Could not be Deleted !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Membership deletion failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Membership Could not be Deleted !','alert-type'=>'error');
        }
        
        return redirect()->back()->with($msg_array);
    }
    
    public function barcode($mid){
        try {
            $membership = LibraryMembership::findOrFail(decrypt($mid));
            
            if($membership->membership_type==1){
                $barcodeDirectory = public_path('uploads/barcode/staff/');
            }else if($membership->membership_type==2){
                $barcodeDirectory = public_path('uploads/barcode/student/');
            }else if($membership->membership_type==3){
                $barcodeDirectory = public_path('uploads/barcode/other/');
            }
            
            $code = $membership->barcode;
            $barcodeFileName = $code.'.png';
            $barcodeFilePath = $barcodeDirectory.$barcodeFileName;
            
            if (!File::exists($barcodeFilePath)) {
                $barcode = new DNS1D();
                $barcode->setStorPath($barcodeDirectory);
                $barcode->getBarcodePNGPath($code, 'C39',1,40,array(0,0,0), true);
            }
            
            return view('library.membership.barcode',compact('code'));
        } catch (\Exception $e) {
            Log::error('Error loading Barcode for book: ' . $e->getMessage());
            return back()->withErrors('Failed to load the Barcode.');
        }
    }
    
}
