<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;

use Illuminate\Support\Facades\Log;

use App\Models\Library\LibraryCategory;
use App\Models\Library\LibrarySubcategory;
use App\Models\MenuAccess;

class Subcategories extends Controller
{
    public function report(){
        try {
            $categories = LibraryCategory::all();
            
            return view('library.subcategory.report',compact('categories'));
        }catch(\Exception $e){
            Log::error('Failed to fetch Sub Categories: '.$e->getMessage());
            return back()->withErrors('Failed to load Sub Categories.');
        }
    }
    
    public function getData(Request $request){
        
        $col_order = ['code','name','category'];
        $total_data = LibrarySubcategory::whereNull('deleted_at')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = LibrarySubcategory::join('library_categories','library_subcategories.category_id','=','library_categories.id');
            
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('library_subcategories.code','like','%'.$search.'%')->
                    orWhere('library_subcategories.name','like',$search.'%')->
                    orWhere('library_categories.name','like','%'.$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('library_subcategories.*','library_categories.name as category')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('library_subcategories.name','ASC');
        }
        
        $subcategories = $query->get();
        
        $edit = MenuAccess::have_access(82) ? 1:0;
        $delete = MenuAccess::have_access(83) ? 1:0;
        
        $data = array();
        if($subcategories){
            foreach($subcategories as $subcategory){
                $row['code'] = $subcategory->code;
                $row['name'] = $subcategory->name;
                $row['category'] = $subcategory->category;
                $html="";
                if($edit==1){
                    $html .= '<a href="'.route('library.subcategory.edit',encrypt($subcategory->id)).'" title="Edit"><i class="icon-sm icon-pencil text-success"></i></a>&nbsp;&nbsp;&nbsp;';
                }
                if($delete==1){
                    $html .= '<a href="'.route('library.subcategory.delete',encrypt($subcategory->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function save(Request $request){
        try {
            $validated = $request->validate([
                    'category' => 'required',
                    'code' => [
                        'required',
                        Rule::unique('library_subcategories', 'code')->where(function ($query) use ($request) {
                            return $query->where('category_id', $request->category);
                        }),
                    ],
                    'name' => [
                        'required',
                        Rule::unique('library_subcategories', 'name')->where(function ($query) use ($request) {
                            return $query->where('category_id', $request->category);
                        }),
                    ],
                ]);
                
            $data = [
                    'code' => $validated['code'],
                    'name' => $validated['name'],
                    'category_id' => $validated['category'],
                ];
                
            $saved = LibrarySubcategory::create($data);
            if($saved){
                $msg_array = array('message'=>'Book Sub Category Created Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Sub Category Could not be Created !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Sub Category creation failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Book Sub Category Could not be Created !','alert-type'=>'error');
        }
            
        return redirect()->route('library.subcategory')->with($msg_array);
    }
    
    public function edit($sid){
        try {
            $categories = LibraryCategory::all();
            $subcategory = LibrarySubcategory::findOrFail(decrypt($sid));
            return view('library.subcategory.edit',compact('categories','subcategory'));
        } catch (ModelNotFoundException $e) {
            return redirect()->route('library.subcategory')->withErrors('subcategory not found.');
        } catch (\Exception $e) {
            Log::error('Error loading Categories for edit: ' . $e->getMessage());
            return back()->withErrors('Failed to load the subcategory for editing.');
        }
    }
    
    public function update(Request $request, $id)
    {
        $sid = decrypt($id);
        try {
            $validated = $request->validate([
                'category' => 'required',
                'code' => [
                    'required',
                    Rule::unique('library_subcategories', 'code')
                        ->where(function ($query) use ($request) {
                            return $query->where('category_id', $request->category);
                        })
                        ->ignore($sid),
                ],
                'name' => [
                    'required',
                    Rule::unique('library_subcategories', 'name')
                        ->where(function ($query) use ($request) {
                            return $query->where('category_id', $request->category);
                        })
                        ->ignore($sid),
                ],
            ]);
            
            $data = [
                    'code' => $validated['code'],
                    'name' => $validated['name'],
                    'category_id' => $validated['category'],
                ];
                
            $subcategory = LibrarySubcategory::findOrFail($sid);
            $subcategory->update($data);
            
            $msg_array = array('message'=>'Book Sub Category Updated Successfully !','alert-type'=>'success');
        } catch (\Exception $e) {
            Log::error('Sub Category update failed: '.$e->getMessage());
            $msg_array = array('message'=>'Book Sub Category Could not be Updated !','alert-type'=>'error');
        }
        
        return redirect()->route('library.subcategory')->with($msg_array);
    }
    
    public function delete($id)
    {
        $sid = decrypt($id);
        try {
            $subcategory = LibrarySubcategory::findOrFail($sid);
            if($subcategory->books->count()==0){
                $subcategory->delete();
                $msg_array = array('message'=>'Book Sub Category Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Sub Category Could not be Deleted !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Book Sub Category deletion failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Book Category Could not be Deleted !','alert-type'=>'error');
        }
        
        return redirect()->route('library.subcategory')->with($msg_array);
    }
}
