<?php

namespace App\Http\Controllers\Library;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use Illuminate\Support\Facades\Log;

use App\Models\Library\LibraryLocation;
use App\Models\Library\LibrarySublocation;
use App\Models\MenuAccess;

class Sublocations extends Controller
{
    public function report(){
        try {
            $locations = LibraryLocation::all();
            
            return view('library.sublocation.report',compact('locations'));
        }catch(\Exception $e){
            Log::error('Failed to fetch Sub Locations: '.$e->getMessage());
            return back()->withErrors('Failed to load Sub Locations.');
        }
    }
    
    public function getData(Request $request){
        
        $col_order = ['code','name','location'];
        $total_data = LibrarySublocation::whereNull('deleted_at')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        
        $query = LibrarySublocation::join('library_locations','library_sublocations.location_id','=','library_locations.id');
            
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('library_sublocations.code','like','%'.$search.'%')->
                    orWhere('library_sublocations.name','like',$search.'%')->
                    orWhere('library_locations.name','like','%'.$search.'%');
            });
        }
        $total_filtered = $query->count();
        $query->select('library_sublocations.*','library_locations.name as location')->offset($start)->limit($limit);
        if($order && $dir){
            $query->orderBy($order,$dir);
        }else{
            $query->orderBy('library_sublocations.name','ASC');
        }
        
        $sublocations = $query->get();
        
        $edit = MenuAccess::have_access(89) ? 1:0;
        $delete = MenuAccess::have_access(90) ? 1:0;
        
        $data = array();
        if($sublocations){
            foreach($sublocations as $sublocation){
                $row['code'] = $sublocation->code;
                $row['name'] = $sublocation->name;
                $row['location'] = $sublocation->location;
                $html="";
                if($edit==1){
                    $html .= '<a href="'.route('library.sublocation.edit',encrypt($sublocation->id)).'" title="Edit"><i class="icon-sm icon-pencil text-success"></i></a>&nbsp;&nbsp;&nbsp;';
                }
                if($delete==1){
                    $html .= '<a href="'.route('library.sublocation.delete',encrypt($sublocation->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function save(Request $request){
        try {
            $validated = $request->validate([
                    'location' => 'required',
                    'code' => [
                        'required',
                        Rule::unique('library_sublocations', 'code')->where(function ($query) use ($request) {
                            return $query->where('location_id', $request->location);
                        }),
                    ],
                    'name' => [
                        'required',
                        Rule::unique('library_sublocations', 'name')->where(function ($query) use ($request) {
                            return $query->where('location_id', $request->location);
                        }),
                    ],
                ]);
                
            $data = [
                    'code' => $validated['code'],
                    'name' => $validated['name'],
                    'location_id' => $validated['location'],
                ];
                
            $saved = LibrarySublocation::create($data);
            if($saved){
                $msg_array = array('message'=>'Book Sub Location Created Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Sub Location Could not be Created !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Book Sub Location creation failed: ' . $e->getMessage());
            $msg_array = array('message'=>'Book Sub Location Could not be Created !','alert-type'=>'error');
        }
            
        return redirect()->route('library.sublocation')->with($msg_array);
    }
    
    public function edit($sid){
        try {
            $locations = LibraryLocation::all();
            $sublocation = LibrarySublocation::findOrFail(decrypt($sid));
            return view('library.sublocation.edit',compact('locations','sublocation'));
        } catch (ModelNotFoundException $e) {
            return redirect()->route('library.sublocation')->withErrors('sublocation not found.');
        } catch (\Exception $e) {
            Log::error('Error loading Sub Location for edit: ' . $e->getMessage());
            return back()->withErrors('Failed to load the Sub Location for editing.');
        }
    }
    
    public function update(Request $request, $id)
    {
        $sid = decrypt($id);
        try {
            $validated = $request->validate([
                'location' => 'required',
                'code' => [
                    'required',
                    Rule::unique('library_sublocations', 'code')
                        ->where(function ($query) use ($request) {
                            return $query->where('location_id', $request->location);
                        })
                        ->ignore($sid),
                ],
                'name' => [
                    'required',
                    Rule::unique('library_sublocations', 'name')
                        ->where(function ($query) use ($request) {
                            return $query->where('location_id', $request->location);
                        })
                        ->ignore($sid),
                ],
            ]);
            
            $data = [
                    'code' => $validated['code'],
                    'name' => $validated['name'],
                    'location_id' => $validated['location'],
                ];
                
            $sublocation = LibrarySublocation::findOrFail($sid);
            $sublocation->update($data);
            
            $msg_array = array('message'=>'Book Sub Location Updated Successfully !','alert-type'=>'success');
        } catch (\Exception $e) {
            Log::error('Sub Location update failed: '.$e->getMessage());
            $msg_array = array('message'=>'Book Sub Location Could not be Updated !','alert-type'=>'error');
        }
        
        return redirect()->route('library.sublocation')->with($msg_array);
    }
    
    public function delete($id)
    {
        $sid = decrypt($id);
        try {
            $sublocation = LibrarySublocation::findOrFail($sid);
            if($sublocation->books->count()==0){
                $sublocation->delete();
                $msg_array = array('message'=>'Book Sub Location Deleted Successfully !','alert-type'=>'success');
            }else{
                $msg_array = array('message'=>'Book Sub Location Could not be Deleted !','alert-type'=>'error');
            }
        } catch (\Exception $e) {
            Log::error('Book Sub Location deletion failed: '.$e->getMessage());
            $msg_array = array('message'=>'Book Sub Location Could not be Deleted !','alert-type'=>'error');
        }
        
        return redirect()->route('library.sublocation')->with($msg_array);
    }
}
