<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use Illuminate\Support\Facades\DB;

use App\Models\Otherfee;
use App\Models\Acyear;
use App\Models\FeeType;
use App\Models\Voucher;
use App\Models\Financialyear;
use App\Models\Accounttype;
use App\Models\Paymentmode;
use App\Models\MenuAccess;

class Otherfees extends Controller
{
    protected $accountId;
    protected $fyearId;
    protected $fsDate;
    protected $feDate;

    public function __construct()
    {
        $this->accountId = Accounttype::getDefaultAccountId();
        $this->fyearId = Financialyear::getDefaultFyearId($this->accountId);
        $fyear = Financialyear::find($this->fyearId);
        if ($fyear) {
            $this->fsDate = $fyear->sdate;
            $this->feDate = $fyear->edate;
        } else {
            // Handle missing Financial Year data gracefully
            abort(404, 'Financial Year not found');
        }
        
        $acyear = Acyear::where('default1',1)->first();
        if ($acyear) {
            $this->sDate = $acyear->sdate;
            $this->eDate = $acyear->edate;
        } else {
            // Handle missing Academic Year data gracefully
            abort(404, 'Academic Year not found');
        }
    }
    
    public function add()
    {
        $acyears = Acyear::all();
        $rec_no = Otherfee::max('receipt_no') + 1;
        $paymentmode = Paymentmode::all();
        $feetype = FeeType::all();
        
        return view('otherfees.add',compact('acyears','rec_no','paymentmode','feetype'));
    }
    
    public function save(Request $request)
    {
        $validated = $request->validate([
            'acyear' => 'required|exists:acyears,ac_id',
            'date' => "required|date|after_or_equal:$this->fsDate|before_or_equal:$this->feDate",
            'receipt_number' => 'required|numeric',
            'student_name' => 'required|string',
            'address' => 'nullable|string',
            'payment_mode' => 'required|exists:paymentmodes,mode_id',
            'types' => 'required|array',
            'amounts' => 'required|array',
            'remarks' => 'nullable|string',
        ]);
            
        $feetypeData = Feetype::pluck('ledger_id', 'type_id')->toArray();
            
        DB::beginTransaction();
            
        try {
            $rec_no = Otherfee::max('receipt_no') + 1;
            $fgroup_id = Otherfee::withTrashed()->max('group_id') + 1 ?? 1;
            $data = [
                'group_id' => $fgroup_id,
                'receipt_no' => $rec_no,
                'ac_id' => $validated['acyear'],
                'student_name' => $validated['student_name'],
                'address' => $validated['address'],
                'paid_date' => $validated['date'],
                'mode_id' => $validated['payment_mode'],
                'remarks' => $validated['remarks'],
                'account_id' => $this->accountId,
                'created_by' => auth()->user()->user_id,
            ];
                
            $i = 0; $vouchers = [];
            foreach ($validated['types'] as $key => $typeid) {
                $data['type_id'] = $typeid;
                $data['fee_amount'] = $validated['amounts'][$key];
                
                if($data['fee_amount'] != '' && $data['fee_amount'] > 0){
                    // Create the fee record in the database
                    Otherfee::create($data);
                    
                    $ledger_id = $feetypeData[$typeid] ?? null;
                    if($ledger_id){
                        if (isset($vouchers[$ledger_id])) {
                            $vouchers[$ledger_id] += $data['fee_amount'];
                        }else{
                            $vouchers[$ledger_id] = $data['fee_amount'];
                        }
                    }
                    print_r($data);
                    $i++;
                }
            }
            
            if($i>0){
                if(!empty($vouchers)){
                    $group_id = Voucher::withTrashed()->max('group_id') + 1 ?? 1;
                    $vno = Voucher::where('vtype_id', 2)
                          ->where('account_id', $this->accountId)
                          ->whereBetween('vdate', [$this->fsDate, $this->feDate])
                          ->max('vno') + 1 ?? 1;
                        
                    $vdata = [
                        'group_id' => $group_id,
                        'vtype_id' => 2,
                        'vno' => $vno,
                        'vdate' => $data['paid_date'],
                        'dr_ledger' => $data['mode_id'],
                        'table_name' => 'otherfees',
                        'table_group_id' => $fgroup_id,
                        'account_id' => $this->accountId,
                        'created_by' => auth()->user()->user_id
                    ];
                    
                    $k=1;
                    foreach($vouchers as $key => $value){
                        $vdata['vorder'] = $k;
                        $vdata['cr_ledger'] = $key;
                        $vdata['vamount'] = $value;
                        
                        $vsave = Voucher::create($vdata);
                        if($vsave){
                            $k++;
                        }
                    }
                }
            }
            
            DB::commit();
            
            echo "<script>window.open('".route('otherfee.print', encrypt($fgroup_id))."');</script>";
            return redirect()->route('otherfee')->with('success', 'Fee Paid Successfully!');
        } catch (\Exception $e) {
            DB::rollBack();
                
            \Log::error('Error saving payment: ' . $e->getMessage());
                
            return redirect()->route('otherfee')->with('error', 'An error occurred while processing the payment.');
        }
    }
    
    public function report()
    {
        $acyears = Acyear::all();
        return view('otherfees.report',compact('acyears'));
    }
    
    public function getData(Request $request){
        
        $col_order = [null,'receipt_no','paid_date','student_name','amount','mode_name','name'];
        $total_data = Otherfee::whereBetween('paid_date',[$this->sDate,$this->eDate])->where('account_id',$this->accountId)->whereNull('deleted_at')->groupBy('group_id')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')] ?? 'id';
        $dir = $request->input('order.0.dir') ?? 'asc';
        
        $query = Otherfee::leftJoin('paymentmodes','otherfees.mode_id','=','paymentmodes.mode_id')
                        ->leftJoin('users','otherfees.created_by','=','users.user_id')
                        ->where('otherfees.account_id', $this->accountId);
            
        $fdate = $request->get('fdate') ?: $this->sDate;
        $tdate = $request->get('tdate') ?: $this->eDate;
            
        // Input sanitization for dates
        $fdate = $this->validateDate($fdate) ? $fdate : $this->sDate;
        $tdate = $this->validateDate($tdate) ? $tdate : $this->eDate;
            
        $query->whereBetween('paid_date', [$fdate, $tdate]);
            
        if ($acid = $request->get('acyear')) {
            $query->where('otherfees.ac_id', $acid);
        }
            
        if ($search = $request->input('search.value')) {
            $query->where(function ($qry) use ($search) {
                $qry->where('receipt_no', 'like', '%' . $search . '%')
                    ->orWhere('paid_date', 'like', $search . '%')
                    ->orWhere('student_name', 'like', '%' . $search . '%')
                    ->orWhere('mode_name', 'like', '%' . $search . '%')
                    ->orWhere('name', 'like', '%' . $search . '%');
            });
        }
            
        $total_data = $query->count();
        $total_filtered = $total_data;
        
        $fees = $query->select('otherfees.*','paymentmodes.mode_name','users.name',DB::raw("SUM(otherfees.fee_amount) as amount"))
                        ->groupBy('group_id')
                        ->orderBy($order, $dir)
                        ->offset($request->input('start'))
                        ->limit($request->input('length'))
                        ->get();
            
        $cancel = MenuAccess::have_access(609) ? 1 : 0;
        $print = MenuAccess::have_access(190) ? 1 : 0;
            
        $data = $fees->map(function ($fee, $index) use ($cancel, $print, $request) {
            $row = [
                'sno' => $request->input('start') + $index + 1,
                'recno' => $fee->receipt_no,
                'date' => $fee->paid_date_formatted,
                'name' => $fee->student_name,
                'amount' => $fee->amount,
                'pmode' => $fee->mode_name,
                'collect' => $fee->name,
                'action' => $this->generateActionLinks($fee->group_id, $fee->status, $cancel, $print),
                'color' => $fee->status==0 ? '#ffd8d8':'',
            ];
            return $row;
        });
            
        return response()->json([
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data,
        ]);
    }
    
    private function validateDate($date, $format = 'Y-m-d')
    {
        $d = \DateTime::createFromFormat($format, $date);
        return $d && $d->format($format) === $date;
    }

    private function generateActionLinks($id, $status, $cancel, $print)
    {
        // Ensure id is sanitized before encrypting
        $encryptedId = encrypt($id);
        $html = '';
        
        if ($status==1) {
            // Generate Cancel Link if applicable
            if ($cancel) {
                $cancelUrl = route('otherfee.cancel', $encryptedId);
                $html .= '<a href="' . htmlspecialchars($cancelUrl, ENT_QUOTES, 'UTF-8') . '" title="Cancel" '
                        . 'onClick="return confirm(\'Are you sure you want to delete?\');">'
                        . '<i class="icon-sm icon-close text-danger"></i></a>&nbsp;&nbsp;&nbsp;';
            }
                
            // Generate Print Link if applicable
            if ($print) {
                $printUrl = route('otherfee.print', $encryptedId);
                $html .= '<a href="' . htmlspecialchars($printUrl, ENT_QUOTES, 'UTF-8') . '" title="Edit" target="_blank">'
                        . '<i class="icon-sm icon-printer text-dark"></i></a>';
            }
        }
            
        return $html;
    }
    
    public function cancel($fid){
        DB::beginTransaction();
            
        try {
            $group_id = decrypt($fid);
            $delete = Otherfee::where('group_id',$group_id)->update(['status'=>0]);
            if($delete){
                Voucher::where('table_name','otherfees')->where('table_group_id',$group_id)->delete();
            }
            
            DB::commit();
            
            return redirect()->route('otherfee.report')->with('success', 'Fee Canceled Successfully!');
        } catch (\Exception $e) {
            DB::rollBack();
                
            \Log::error('Error cancel payment: ' . $e->getMessage());
                
            return redirect()->route('otherfee.report')->with('error', 'An error occurred while cancel the payment.');
        }
    }
    
    public function print($fid){
        $group_id = decrypt($fid);
        $institution = instituteDetails();
        $otherfees = Otherfee::where('group_id',$group_id)->where('status',1)->get();
        
        return view('otherfees.print',compact('otherfees','institution'));
    }
}
