<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Models\AddBusTrans;
use App\Models\AddRouteTrans;
use App\Models\AddStopTrans;
use App\Models\Course;
use App\Models\Semester;
use App\Models\Student;
use App\Models\Acyear;
use App\Models\BusfacilityStudents;
use App\Models\UpdatedBusFeeStudent;
use App\Models\StudentTemporaryStop;
use App\Models\BusFineSetting;
use App\Models\BusFeeSetting;
use App\Models\Paymentmode;
use App\Models\BusFee;
use App\Models\Voucher;
use App\Models\Financialyear;
use App\Models\Accounttype;

use PDF;
use DB;

class Transportation extends Controller
{
    protected $accountId;
    protected $fyearId;
    protected $fsDate;
    protected $feDate;

    public function __construct()
    {
        $this->accountId = Accounttype::getDefaultAccountId();
        $this->fyearId = Financialyear::getDefaultFyearId($this->accountId);
        $fyear = Financialyear::find($this->fyearId);
        if ($fyear) {
            $this->fsDate = $fyear->sdate;
            $this->feDate = $fyear->edate;
        } else {
            // Handle missing Financial Year data gracefully
            abort(404, 'Financial Year not found');
        }
    }
    
    public function add_bus()
    {
        return view('transportation.add_bus');
    }

    public function add_bus_save(Request $request)
    {
        $validated = $request->validate([
            'dop' => 'required|date', 
            'bus_no' => 'required|unique:add_bus_trans,bus_no',
            'bus_model' => 'required|string|max:255', 
            'amount' => 'required|numeric|min:0',
            'manufacturer' => 'required|string|max:255',
            'dealer' => 'required|string|max:255',
            'chasis_no' => 'required|string|max:255', 
            'insurance_date' => 'required|date', 
            'insurance_vali' => 'required|date|after_or_equal:insurance_date',
        ]);
        
        DB::beginTransaction();
            
        try {
            AddBusTrans::create([
                'dop' => $validated['dop'],
                'bus_no' => $validated['bus_no'],
                'bus_model' => $validated['bus_model'],
                'amount' => $validated['amount'],
                'manufacturer' => $validated['manufacturer'],
                'dealer' => $validated['dealer'],
                'chasis_no' => $validated['chasis_no'],
                'insurance_date' => $validated['insurance_date'],
                'insurance_vali' => $validated['insurance_vali'],
            ]);
            
            DB::commit();
            
            return redirect()->route('trans.add.bus')->with('success', 'Bus Added Successfully!');
        } catch (\Exception $e) {
            DB::rollBack();
                
            \Log::error('Error saving bus details: ' . $e->getMessage());
                
            return redirect()->route('trans.add.bus')->with('error', 'An error occurred while saving bus details.');
        }
    }
    
    public function add_bus_view()
    {
        $addbus = AddBusTrans::all();
        return view('transportation.add_bus_view',compact('addbus'));
    }
    
    public function add_bus_edit($id)
    {
        $bus = AddBusTrans::find($id);
        return view('transportation.add_bus_edit',compact('bus'));
    }
    
    public function add_bus_update(Request $request)
    {
        $validated = $request->validate([
            'dop' => 'required|date', 
            'bus_no' => 'required|unique:add_bus_trans,bus_no',
            'bus_model' => 'required|string|max:255', 
            'amount' => 'required|numeric|min:0',
            'manufacturer' => 'required|string|max:255',
            'dealer' => 'required|string|max:255',
            'chasis_no' => 'required|string|max:255', 
            'insurance_date' => 'required|date', 
            'insurance_vali' => 'required|date|after_or_equal:insurance_date',
        ]);
        
        DB::beginTransaction();
            
        try {
        
        
        DB::commit();
            
            return redirect()->route('trans.add.bus')->with('success', 'Bus Updated Successfully!');
        } catch (\Exception $e) {
            DB::rollBack();
                
            \Log::error('Error updating bus details: ' . $e->getMessage());
                
            return redirect()->route('trans.add.bus')->with('error', 'An error occurred while updating bus details.');
        }
        
        
        $dop=$request->dop;
        $bus_no=$request->bus_no;
        $bus_model=$request->bus_model;
        $amount=$request->amount;
        $manufacturer=$request->manufacturer; 
        $dealer=$request->dealer; 
        $chasis_no=$request->chasis_no; 
        $insurance_date=$request->insurance_date;
        $insurance_vali=$request->insurance_vali; 
        
        $bus_id=$request->addbus_id;
        $bus_update=AddBusTrans::where('addbus_id',$bus_id)->first();
        $bus_update->update([
            'dop'=>$dop,
            'bus_no'=>$bus_no,
            'bus_model'=>$bus_model,
            'amount'=>$amount,
            'manufacturer'=>$manufacturer,
            'dealer'=>$dealer,
            'chasis_no'=>$chasis_no,
            'insurance_date'=>$insurance_date,
            'insurance_vali'=>$insurance_vali,
            ]);
            
            if($bus_update)
            {
                $msg_array=array('message'=>'Bus Details Updated Successfully!!!','success');
            }
            else
            {
                 $msg_array=array('message'=>'Bus Details Could not update!!!','error');
            }
            return redirect()->route('trans.view.bus')->with($msg_array); 
    }

public function add_bus_delete($id)
{
   
    $routeExists = AddRouteTrans::where('addbus_id', $id)->exists();
    
    if ($routeExists) {
     
        return redirect()->route('trans.view.bus')->with([
            'message' => 'Could not delete the bus. This bus is already added to the route.',
            'status' => 'error'
        ]);
    } else {
       
        $bus = AddBusTrans::where('addbus_id', $id)->first();
        
        if ($bus) {
            $bus->delete();
        
            return redirect()->route('trans.view.bus')->with([
                'message' => 'Bus Details Deleted Successfully!!!',
                'status' => 'success'
            ]);
        } else {
            
            return redirect()->route('trans.view.bus')->with([
                'message' => 'Bus Details could not be deleted. Bus not found.',
                'status' => 'error'
            ]);
        }
    }
}



    public function add_route()
    {
        $bus=AddBusTrans::all();
        
        return view('transportation.add_route',compact('bus'));
    }
    
   public function add_route_save(Request $request)
   {
       
       $validated = $request->validate([
    'route_name' => 'required|unique:add_route_trans,route_name',
    'route_code' => 'required|unique:add_route_trans,route_code',
        ]);
        
        $route_name=$request->route_name;
        $route_code=$request->route_code;
        $bus=$request->addbus_id ;
       $route=AddRouteTrans::create([
           'route_name'=>$route_name,
           'route_code'=>$route_code,
           'addbus_id'=>$bus,
           ]);
            if($route)
            {
                $msg_array=array('message'=>'Route Added Successfully!!!','success');
            }
            else
            {
                 $msg_array=array('message'=>'Route Could not Added!!!','error');
            }
             return redirect()->route('trans.add.route')->with($msg_array); 
   }

    public function add_route_view()
    {
        $route=AddRouteTrans::all();
        
        return view('transportation.add_route_view',compact('route'));

    }
    
    public function add_route_edit($id)
    {
        $route_id=AddRouteTrans::find($id);
        $route=AddRouteTrans::where('route_id',$id)->first();
        return view('transportation.add_route_edit',compact('route_id','route'));
    }
     public function add_route_delete($id)
    {
        $route=AddRouteTrans::where('route_id',$id)->first();
        if ($route) {
            $route->delete();
        
            return redirect()->route('trans.view.route')->with([
                'message' => 'Route Details Deleted Successfully!!!',
                'status' => 'success'
            ]);
        } else {
            
            return redirect()->route('trans.view.route')->with([
                'message' => 'Route Details could not be deleted. Bus not found.',
                'status' => 'error'
            ]);
        }
        
        
         
    }
    
   public function add_route_update(Request $request)
   {
        $validated = $request->validate([
    'route_name' => 'required|unique:add_route_trans,route_name',
    'route_code' => 'required|unique:add_route_trans,route_code',
        ]);
         $route_name=$request->route_name;
        $route_code=$request->route_code;
        $route_id=$request->route_id;
        $route=AddRouteTrans::where('route_id',$route_id)->first();
        $route->update([
            'route_name'=>$route_name,
           'route_code'=>$route_code,
            ]);
            
             if($route)
            {
                $msg_array=array('message'=>'Route Updated Successfully!!!','success');
            }
            else
            {
                 $msg_array=array('message'=>'Route Could not update!!!','error');
            }
             return redirect()->route('trans.view.route')->with($msg_array); 
   
            
   }
    
    public function add_stop()
    {
        $routes=AddRouteTrans::all();
        $stop=AddStopTrans::all();
         $stop_code = AddStopTrans::max('stop_code');
        $next_stop_no = $stop_code + 1;
        return view('transportation.add_stop',compact('routes','next_stop_no'));
    }
    
    public function add_stop_save(Request $request)
    {
          $validated = $request->validate([
    'route_id' => 'required',
    'addbus_id' => 'required',
    'stop_code'=> 'required|unique:add_stop_trans,stop_code',
     'stop_name'=> 'required',
      'fee'=> 'required',
        ]);
        $route_id=$request->route_id;
        $bus_id=$request->addbus_id;
         $stop_code=$request->stop_code;
          $stop_name=$request->stop_name;
        $fee=$request->fee ;
        $fromdate=$request->fromdate;
        
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;
        
        
       $stop=AddStopTrans::create([
           'route_id'=>$route_id,
            'addbus_id'=>$bus_id,
             'stop_code'=>$stop_code,
             'stop_name'=>$stop_name,
             'fee'=>$fee,
             'ac_id'=>$ac_id,
             'fromdate'=>$fromdate,
           ]);
            if($stop)
            {
                $msg_array=array('message'=>'Stop Added Successfully!!!','success');
            }
            else
            {
                 $msg_array=array('message'=>'Stop Could not Added!!!','error');
            }
                     return redirect()->route('trans.add.stop')->with($msg_array); 

        
    }
    
    public function view_stop()
    {
        $stop=AddStopTrans::all();
        return view('transportation.view_stop',compact('stop'));
    }
    public function view_edit_stop($id)
    {
        $routes=AddRouteTrans::all();
        $stop_id=AddStopTrans::find($id);
        $stop=AddStopTrans::where('stop_id',$id)->first();
        return view('transportation.view_edit_stop',compact('stop_id','stop','routes'));
        
    }
  public function add_stop_update(Request $request)
  {
      
        $validated = $request->validate([
        'route_id' => 'required',
        'addbus_id' => 'required',
        'stop_code'=> 'required|unique:add_stop_trans,stop_code',
        'stop_name'=> 'required',
        'fee'=> 'required',
        ]);
        $route_id=$request->route_id;
        $bus_id=$request->addbus_id;
        $stop_code=$request->stop_code;
        $stop_name=$request->stop_name;
        $fee=$request->fee ;
        $stop_id=$request->stop_id;
        $stop=AddStopTrans::find('stop_id',$stop_id);
       
        $stop->update([
             'route_id'=>$route_id,
            'addbus_id'=>$bus_id,
             'stop_code'=>$stop_code,
             'stop_name'=>$stop_name,
             'fee'=>$fee,
            ]);
            if($stop)
            {
                $msg_array=array('message'=>'Stop Updated Successfully!!!','success');
            }
            else
            {
                 $msg_array=array('message'=>'Stop Could not Update!!!','error');
            }
                     return redirect()->route('trans.view.stop')->with($msg_array); 

        
  }
  
  public function view_delete_stop($id)
  {
       $bus = AddStopTrans::where('stop_id', $id)->first();
     if ($bus) {
            $bus->delete();
        
            return redirect()->route('trans.view.stop')->with([
                'message' => 'Stop Details Deleted Successfully!!!',
                'status' => 'success'
            ]);
        } 
  }
  
  public function busfacility_add()
  {
      $courses=Course::all();
      return view('transportation.busfacility_add',compact('courses'));
  }
    
public function busfacility_add_get(Request $request)
{
    $course_id=Course::find($request->cid);
    $sem=Semester::find($request->sid);
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;
    $student=Student::join('promotes','promotes.student_id','=','students.student_id')
    ->where('promotes.course_id',$request->cid)
    ->where('promotes.semester_id',$request->sid)
    ->where('promotes.ac_id',$ac_id)
    ->select('students.*')
    ->get();
   $routes=AddRouteTrans::all();
   $addstustops=BusfacilityStudents::all();
   
    $existingBusFacilities = BusfacilityStudents::with(['student', 'route', 'stop'])
        ->whereIn('student_id', $student->pluck('student_id'))
        ->get();
   
    return view('transportation.busfacility_add_get',compact('course_id','sem','student','routes','existingBusFacilities','course_id','sem'));
}
public function busfacility_get_stop($route_id)
{
      $stop = array();
        $rows = AddStopTrans::where('route_id',$route_id)->get();
        foreach($rows as $row){
            $stop[$row->stop_id] = $row->stop_name;
        }
        return json_encode($stop);
    
  
   
}
    


 public function add_students_bus(Request $request)
{
    $validated = $request->validate([
        'student_id' => 'required|array',
        'route_id' => 'required|array',
        'stop_id' => 'required|array',
        'date' => 'required|array',
        'course_id' => 'required|integer', 
        'semester_id' => 'required|integer',
    ]);
$cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;
    foreach ($request->student_id as $index => $studentId) {
        $routeId = $request->route_id[$index];
        $stopId = $request->stop_id[$index];
        $date = $request->date[$index];

       
        $existingRecord = BusfacilityStudents::where('student_id', $studentId)
            ->where('route_id', $routeId)
            ->where('stop_id', $stopId)
            ->where('date', $date)
            ->first();

    
        if (empty($existingRecord) && !empty($routeId) && !empty($stopId) && !empty($date)) {
            BusfacilityStudents::create([
                'student_id' => $studentId,
                'route_id' => $routeId,
                'stop_id' => $stopId,
                'date' => $date,
                'course_id' => $request->course_id, 
                'semester_id' => $request->semester_id, 
                'ac_id'=>$ac_id,
                'status'=>'1',
            ]);
        }
    }

    return redirect()->route('trans.add.busfacility')
                     ->with('success', 'Bus facility added successfully.');
}
   
  public function busfacility_view()
  {
        $courses=Course::all();
        return view('transportation.busfacility_view',compact('courses'));
      
  }
  
  public function busfacility_view_get(Request $request)
  {
      $course_id=Course::find($request->cid);
      $sem=Semester::find($request->sid);
      $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
      $ac_id = $cur_acyear->ac_id;
      $busfacility=BusfacilityStudents::where('course_id',$request->cid)->where('semester_id',$request->sid)
      ->where('ac_id',$ac_id)
      ->get();
     $busTrans=BusfacilityStudents::join('add_stop_trans','busfacility_students.stop_id','=','add_stop_trans.stop_id')
     ->where('busfacility_students.course_id',$request->cid)
     ->where('busfacility_students.semester_id',$request->sid)
     ->where('busfacility_students.status','1')
     ->select('add_stop_trans.*','busfacility_students.*')
     ->get();
     
      
      
      return view('transportation.busfacility_view_get',compact('busTrans'));
      
      
  }
    public function busfacility_view_edit($id)
    {
     
     $id = BusfacilityStudents::find($id);
     
     $student_id = $id->student_id;
     $route_id=$id->route_id;
    $stop_id=$id->stop_id;
    
   $updated_fee=UpdatedBusFeeStudent::where('student_id',$student_id)->first();
     return view('transportation.busfacility_view_edit',compact('id','updated_fee','route_id','stop_id'));
     
     
    }
    public function busfacility_view_discontinue(Request $request)
    {
        $date=$request->discontinued_date;
        $id=$request->busfaci_stu_id;
       
        $busfacility=BusfacilityStudents::find($id);
        $busfacility->update([
            'status'=>'0',
            'discontinued_date'=>$date,
            ]);
            if($busfacility)
            {
               $msg_array=array('message'=>'Student has withdrawn from the bus service','success');
            }
           else
            {
               $msg_array=array('message'=>'Student Unable to withdraw from the bus service','error');
            }
        return redirect()->route('trans.view.busfacility')->with($msg_array);
    }
public function busfacility_view_updatefee(Request $request)
{
    $id=$request->busfaci_stu_id;
    $route_id=$request->route_id;
    $stop_id=$request->stop_id;
    $student=BusfacilityStudents::where('busfaci_stu_id',$id)
    ->select('student_id')
    ->first();
     $student_id = $student ? $student->student_id : null;
    
    $updatedfee=$request->updated_fee;
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;
      $existing_record = UpdatedBusFeeStudent::where('student_id', $student_id)->first();
     if ($existing_record) {
  
        $existing_record->update([
            'updated_fee' => $updatedfee,
        ]);

        $msg_array = ['message' => 'Student Fees Updated Successfully!!!', 'status' => 'success'];
    }
    else {
        
        $updated_bus_facility = UpdatedBusFeeStudent::create([
            'busfaci_stu_id' => $id,
            'student_id' => $student_id,
            'ac_id' => $ac_id,
            'updated_fee' => $updatedfee,
            'route_id'=>$route_id,
            'stop_id'=>$stop_id,
        ]);

        if ($updated_bus_facility) {
            $msg_array = ['message' => 'Student Fees Updated Successfully!!!', 'status' => 'success'];
        } else {
            $msg_array = ['message' => 'Student Fees Could not Update!!!', 'status' => 'error'];
        }
    }
    
   
    
       return redirect()->route('trans.view.busfacility')->with($msg_array);
    
}
    
    
  public function busfacility_discontinued()
  {
    //   $discontinued=BusfacilityStudents::where('status','0')->get();
      $discontinued=BusfacilityStudents::join('students','busfacility_students.student_id','=','students.student_id')
      ->join('courses','courses.course_id','=','students.course_id')
      ->join('add_route_trans','add_route_trans.route_id','=','busfacility_students.route_id')
      ->join('add_stop_trans','add_stop_trans.stop_id','=','busfacility_students.stop_id')
      ->where('busfacility_students.status','0')
      ->select('courses.course_name','students.name','students.adno','busfacility_students.discontinued_date','busfacility_students.date','add_route_trans.route_name','add_stop_trans.stop_name')
      ->get();
      return view('transportation.busfacility_discontinued',compact('discontinued'));
  }
    
 public function busfacility_discontinued_pdf()
 {
    $ins_det = instituteDetails();
    $discontinued=BusfacilityStudents::where('status','0')->get();
    $pdf = PDF::loadView('transportation.busfacility_discontinued_pdf',compact('discontinued','ins_det'));
               $pdf->setPaper('A4', 'portrait');
               return $pdf->download('DiscontinuedstudentList.pdf');
      
 }
 
 
 public function busfacility_temporary()
  {
        $courses=Course::all();
        $routes=AddRouteTrans::all();
        return view('transportation.busfacility_temporary',compact('courses','routes'));
      
  }    
    
   public function getroutestop($route_id)
   {
       $stop=array();
       $rows=AddStopTrans::where('route_id',$route_id)->get();
       foreach($rows as $row)
       {
            $stop[$row->stop_id] = $row->stop_name;
       }
        return json_encode($stop);
   }
    public function busfacility_temporary_save(request $request)
    {
         $validated = $request->validate([
    'course_id' => 'required', 
    'semester_id' => 'required',
    'student_id' => 'required',
      'route_id' => 'required',
      'stop_id' => 'required',
    
        ]);
        $crs_id=$request->course_id;
        $sem_id=$request->semester_id;
        $student_id=$request->student_id;
        $route_id=$request->route_id;
        $stop_id=$request->stop_id;
        $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
        $ac_id=$cur_acyear->ac_id;
        $exist=StudentTemporaryStop::where('course_id',$crs_id)->where('ac_id',$ac_id)->where('semester_id',$sem_id)
        ->where('student_id',$student_id)->exists();;
        if(!$exist)
        {
            StudentTemporaryStop::create([
           'ac_id'=>$ac_id,
           'course_id'=>$crs_id,
           'semester_id'=>$sem_id,
           'student_id'=>$student_id,
           'route_id'=>$route_id,
           'stop_id'=>$stop_id,
           ]);
    $msg_array = [
            'message' => 'Student temporary route and stop added successfully!',
            'status' => 'success'
        ];
        }
        
        else {
       
        $msg_array = [
            'message' => 'Student temporary route has already been set.',
            'status' => 'info'
        ];
    }
      
     return redirect()->route('trans.temporary.busfacility')->with($msg_array);
        
    }
public function busfacility_temporary_report()
{
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id=$cur_acyear->ac_id;
    $temporary_report=StudentTemporaryStop::join('students','student_temporary_stop_trans.student_id','=','students.student_id')
        ->join('promotes','promotes.student_id','=','students.student_id')
        ->join('courses','courses.course_id','=','promotes.course_id')
        ->join('semesters','semesters.semester_id','=','promotes.semester_id')
        ->join('add_route_trans','add_route_trans.route_id','=','student_temporary_stop_trans.route_id')
        ->join('add_stop_trans','add_stop_trans.stop_id','=','student_temporary_stop_trans.stop_id')
        ->select('courses.course_name','students.name','students.adno','student_temporary_stop_trans.*','add_route_trans.route_name','add_stop_trans.stop_name','semesters.semester_name')
        ->where('student_temporary_stop_trans.ac_id',$ac_id)->get();
    
    return view('transportation.busfacility_temporary_report',compact('temporary_report'));
    
}
public function get_tem_students(Request $request)
{
      
        $course_id=  $request->get('course');
        $sem_id=   $request->get('semester_id');
        $ac_id = getAcyear();
        $stud = array();
       
        $rows=BusfacilityStudents::join('students','students.student_id','=','busfacility_students.student_id')
            ->where('busfacility_students.course_id',$course_id)
            ->where('busfacility_students.semester_id',$sem_id)
            ->where('busfacility_students.ac_id',$ac_id)
            ->select('students.*')
            ->get();
       
        foreach($rows as $row){
            $stud[$row->student_id ] = $row->name;
        }
        return json_encode($stud);
}

public function trans_editstop_fee()
{
    $routes=AddRouteTrans::all();
    return view('transportation.trans_editstop_fee',compact('routes'));
}

public function trans_editstop_fee_get(Request $request)
{
    $route_id=AddRouteTrans::find($request->rid);
    $stop=AddStopTrans::where('route_id',$request->rid)->get();
    return view('transportation.trans_editstop_fee_get',compact('stop','route_id'));
}
public function trans_editstop_fee_update(Request $request)
{
    $stop_ids = $request->input('stop_id');
    $fees = $request->input('fee'); 
    $posted_stops = $request->input('posted'); 

    if ($posted_stops) {
        foreach ($posted_stops as $index => $stop_id) {
           
            $fee_index = array_search($stop_id, $stop_ids);

            if ($fee_index !== false) {
               
                $new_fee = $fees[$fee_index]; 
              
                AddStopTrans::where('stop_id', $stop_id)->update(['fee' => $new_fee]);
            }
        }
    }

  

    return redirect()->route('trans.editfee.stop')->with('success', 'Stop fees updated successfully.');
}
public function bus_fine_setting()
{
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id=$cur_acyear->ac_id;
    $busfine=BusFineSetting::where('ac_id',$ac_id)->get();
    return view('transportation.bus_fine_setting',compact('busfine'));
    
}




public function bus_fine_setting_save(Request $request)
{
    $validated=$request->validate([
        'fine_amount'=>'required',
         'fine_count'=>'required',
         'fine_per'=>'required',
        ]);
        $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
        $ac_id=$cur_acyear->ac_id;
        $fineamount=$request->fine_amount;
        $finecount=$request->fine_count;
        $fine_per=$request->fine_per;
        $exist=BusFineSetting::where('ac_id',$ac_id)->first();
        if(!$exist)
        {
             BusFineSetting::create([
            'fine_amount'=>$fineamount,
            'fine_count'=>$finecount,
            'fine_per'=>$fine_per,
            'ac_id'=>$ac_id,
            ]);
           $msg_array = ['message' => 'Bus Fine Added Successfully!!!', 'success' => true];  
        }
        else
        {
           $exist->update([
             'fine_amount'=>$fineamount,
            'fine_count'=>$finecount,
            'fine_per'=>$fine_per,
            
               ]); 
               $msg_array = ['message' => 'Bus Fine Updated Successfully!!!', 'success' => true];
        }
       
   
            return redirect()->route('trans.bus.fine')->with($msg_array);
}

// public function bus_fee_setting()
// {
//     $existingMonths = BusFeeSetting::pluck('month')->toArray();
//     return view('transportation.bus_fee_setting',compact('existingMonths'));
// }

public function bus_fee_setting()
{
     $months=array();
        $cur_acyear = Acyear::where('default1',1)->whereNull('deleted_at')->first();
        $start = strtotime($cur_acyear->sdate);
        $end = strtotime($cur_acyear->edate);
        
        while($start <= $end){
            $month = date('m',$start);
            $year = date('Y',$start);
            $status=$hmid=0;
            $hmonth = BusFeeSetting::where(array('ac_id'=>$cur_acyear->ac_id,'month'=>$month,'year'=>$year))->first();
            if($hmonth){ $status=1; $hmid=$hmonth->bfeesetting_id; }
            
            $months[] = array('month'=>$start,'status'=>$status,'hmid'=>$hmid);
            
            $start = strtotime('+1 month', $start);
        }
    
    
  
    return view('transportation.bus_fee_setting',compact('months','hmonth'));
}





// public function bus_fee_setting_save(Request $request)
// {
//     $request->validate([
//       'months' => 'required|array',
//       'dates' => 'required|array',
//     ]);
//     $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
//     $ac_id=$cur_acyear->ac_id;
// foreach ($request->months as $month) {
//       $monthName = explode('-', $month)[0];
//           $date = $request->dates[strtolower($monthName)];

     
//         BusFeeSetting::Create([
//             'month' => $monthName,
//             'date' => $date,
//             'ac_id'=>$ac_id,
            
//             ]);
              
        
//     } 
//     return redirect()->route('trans.bus.fee.setting');
// }
public function bus_fee_setting_save(Request $request)
{
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();

 
    $validated = $request->validate([
        'posted' => 'present|array',
        'dates' => 'present|array', 
    ]);

    $i = 0;
    foreach ($request->posted as $mid) {
      
        $date = isset($request->dates[$mid]) ? $request->dates[$mid] : null;

      
        $hmonth = BusFeeSetting::create([
            'ac_id' => $cur_acyear->ac_id,
            'month' => date('m', $mid),
            'year' => date('Y', $mid),
            'date' => $date,
        ]);

        if ($hmonth) {
            $i++;
        }
    }

    if ($i > 0) {
        $msg_array = [
            'message' => 'Bus Fee Payment Month Saved Successfully!',
            'alert-type' => 'success'
        ];
    } else {
        $msg_array = [
            'message' => 'Bus Fee Payment Month Could not be Saved!',
            'alert-type' => 'error'
        ];
    }

    return redirect()->route('trans.bus.fee.setting')->with($msg_array);
}






public function bus_fee_setting_report()
{
    $busfeesetting=BusFeeSetting::orderBy('date','ASC')->get();
    return view('transportation.bus_fee_setting_report',compact('busfeesetting'));
}
public function bus_fee_setting_edit($id)
{
    $busFeeSetting=BusFeeSetting::find($id);
    $existingMonths = BusFeeSetting::pluck('month')->toArray();
    return view('transportation.bus_fee_setting_edit',compact('busFeeSetting','existingMonths'));
}
public function bus_fee_setting_delete($id)
{
    $busFeeSetting=BusFeeSetting::find($id)->delete();
    return redirect()->route('trans.bus.fee.setting.report');
}
public function  bus_fee_setting_update(Request $request)
{

    $busfeesetting_id = $request->bfeesetting_id;
   
    $month = $request->months; 
    $date = $request->date;

    $busfee = BusFeeSetting::where('bfeesetting_id',$busfeesetting_id)->first();

    if ($busfee) {
        $updated = $busfee->update([
            'month' => $month[0],
            'date' => $date,
        ]);

        if ($updated) {
            $msg_array = ['message' => 'Student Fee Setting Updated Successfully!!!', 'status' => 'success'];
        } else {
            $msg_array = ['message' => 'Student Fee Setting Could not Update!!!', 'status' => 'error'];
        }
    } else {
        $msg_array = ['message' => 'Student Fee Setting Not Found!!!', 'status' => 'error'];
    }

   
        return redirect()->route('trans.bus.fee.setting.report')->with($msg_array);
       
}


public function bus_student_details()
{
    $routes=AddRouteTrans::all();
    return view('transportation.bus_student_details',compact('routes'));
}

public function bus_student_details_get(Request $request)
{
    
  
    $col_order = ['name', 'adno', 'mobile', 'course_name', 'semester_name', 'stop_name', 'fee'];
    $total_data = BusfacilityStudents::where('status', '1')->count();
    $limit = $request->input('length');
    $start = $request->input('start');
    $order = $col_order[$request->input('order.0.column')] ?? 'adno';
    $dir = $request->input('order.0.dir') ?? 'asc';
    
    $route = $request->get('route');
    
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;
    
    $query = BusfacilityStudents::join('students', 'students.student_id', '=', 'busfacility_students.student_id')
        ->join('promotes', 'promotes.student_id', '=', 'students.student_id')
        ->join('courses', 'courses.course_id', '=', 'promotes.course_id')
        ->join('semesters', 'semesters.semester_id', '=', 'promotes.semester_id')
        ->join('add_route_trans', 'add_route_trans.route_id', '=', 'busfacility_students.route_id')
        ->join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
        ->where('busfacility_students.ac_id', $ac_id)
        ->where('busfacility_students.route_id', $route)
        ->where('busfacility_students.status', '1');

    if (!empty($request->input('search.value'))) {
        $search = $request->input('search.value');
        $query->where(function ($qry) use ($search) {
            $qry->where('students.adno', 'like', '%' . $search . '%')
                ->orWhere('students.name', 'like', '%' . $search . '%')
                ->orWhere('students.mobile', 'like', '%' . $search . '%')
                ->orWhere('courses.course_name', 'like', '%' . $search . '%')
                ->orWhere('semesters.semester_name', 'like', '%' . $search . '%');
        });
    }

    $total_filtered = $query->count();
    $students = $query->select('students.*', 'courses.course_name', 'semesters.semester_name', 'busfacility_students.*', 'add_stop_trans.stop_name', 'add_stop_trans.fee')
        ->offset($start)->limit($limit)->orderBy($order, $dir)->get();

    $data = [];
    foreach ($students as $student) {
        $data[] = [
            'adno' => $student->adno,
            'name' => $student->name,
            'mobile' => $student->mobile,
            'course' => $student->course_name,
            'semester' => $student->semester_name,
            'stopname' => $student->stop_name,
            'fee' => $student->fee,
        ];
    }
    
    return response()->json([
        'draw' => intval($request->input('draw')),
        'recordsTotal' => intval($total_data),
        'recordsFiltered' => intval($total_filtered),
        'data' => $data,
    ]);
}
 
    public function bus_fee_payment()
    {
        $courses=Course::all();
        $routes=AddRouteTrans::all();
        $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
        $ac_id = $cur_acyear->ac_id;
        $students=Student::join('busfacility_students','busfacility_students.student_id','=','students.student_id')
        ->where('busfacility_students.ac_id',$ac_id)->get();
        $paymodes = Paymentmode::where('status',1)->get();
        return view('transportation.bus_fee_payment',compact('students','paymodes','courses'));
    }
      
    
public function bus_fee_payment_get(Request $request)
{
    
  
    $stud = Student::find($request->stud);
    $paymentmode = Paymentmode::find($request->pid);
    $date = $request->date;
     $routeType = 'permanent';

    // Check if the student has a temporary route type
    if ($stud && $stud->route_type === 'temporary') {
        $routeType = 'temporary';
    }
  
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;

  
    $receipt_no = BusFee::max('receipt_no');
    $next_rec_no = $receipt_no + 1;

 
    $busfeesetting = BusFeeSetting::where('ac_id', $ac_id)->get();
  
 
    $amount = BusfacilityStudents::join('students', 'students.student_id', '=', 'busfacility_students.student_id')
        ->join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
        ->where('busfacility_students.student_id', $request->stud)
        ->where('add_stop_trans.ac_id', $ac_id)
        ->select('add_stop_trans.fee')
        ->get();

  
    $fine = BusFineSetting::where('ac_id', $ac_id)->get();

  
    $individualfee = UpdatedBusFeeStudent::where('student_id', $request->stud)->get();

  
    $totalFees = BusfacilityStudents::join('students', 'students.student_id', '=', 'busfacility_students.student_id')
        ->join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
        ->where('busfacility_students.student_id', $request->stud)
        ->where('add_stop_trans.ac_id', $ac_id)
        ->select('add_stop_trans.fee as total_fee')
        ->get();

   
    $totaltemporaryFees = StudentTemporaryStop::join('students', 'students.student_id', '=', 'student_temporary_stop_trans.student_id')
        ->join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'student_temporary_stop_trans.stop_id')
        ->where('student_temporary_stop_trans.student_id', $request->stud)
        ->where('add_stop_trans.ac_id', $ac_id)
        ->select('add_stop_trans.fee as total_fee')
        ->get();
 $routeType = null;
    
    $existingPaymentsPermanent = BusFee::where('student_id', $request->stud)
        ->where('ac_id', $ac_id)
        ->where('route_type', 'permanent')
        ->get();

    $existingPaymentsTemporary = BusFee::where('student_id', $request->stud)
        ->where('ac_id', $ac_id)
        ->where('route_type', 'temporary')
        ->get();

   
    $totalPaidPermanent = [];
    $totalPaidTemporary = [];

   
    foreach ($existingPaymentsPermanent as $payment) {
        $totalPaidPermanent[$payment->month] = ($totalPaidPermanent[$payment->month] ?? 0) + $payment->fee_amount;
    }

   
    foreach ($existingPaymentsTemporary as $payment) {
        $totalPaidTemporary[$payment->month] = ($totalPaidTemporary[$payment->month] ?? 0) + $payment->fee_amount;
    }

   
    $currentAmountsPermanent = [];
    $currentAmountsTemporary = [];

   
    foreach ($busfeesetting as $feesetting) {
        $month = $feesetting->month;

      
        $totalFeePermanent = 0;
        $totalFeeTemporary = 0;

       
        if ($individualfee->isNotEmpty()) {
            $totalFeePermanent = $individualfee->first()->updated_fee ?? 0;
        } else {
            $totalFeePermanent = $amount->first()->fee ?? 0;
        }

       
        if ($totaltemporaryFees->isNotEmpty()) {
            $totalFeeTemporary = $totaltemporaryFees->first()->total_fee ?? 0;
        }

       
        $paidAmountPermanent = $totalPaidPermanent[$month] ?? 0;
        $paidAmountTemporary = $totalPaidTemporary[$month] ?? 0;

     
        if ($paidAmountPermanent >= $totalFeePermanent) {
            $currentAmountsPermanent[$month] = 'Paid';
        } elseif ($paidAmountPermanent > 0) {
            $remainingAmount = $totalFeePermanent - $paidAmountPermanent;
            $currentAmountsPermanent[$month] = $remainingAmount;
        } else {
            $currentAmountsPermanent[$month] = $totalFeePermanent;
        }

       
        if ($paidAmountTemporary >= $totalFeeTemporary) {
            $currentAmountsTemporary[$month] = 'Paid';
        } elseif ($paidAmountTemporary > 0) {
            $remainingAmount = $totalFeeTemporary - $paidAmountTemporary;
            $currentAmountsTemporary[$month] = $remainingAmount;
        } else {
            $currentAmountsTemporary[$month] = $totalFeeTemporary;
        }
        

        
        
        
    }


        return view('transportation.bus_fee_payment_get', compact(
            'ac_id',
            'stud',
            'date',
            'paymentmode',
            'next_rec_no',
            'busfeesetting',
            'amount',
            'individualfee',
            'fine',
            'totalFees',
            'totalPaidPermanent',
            'currentAmountsPermanent',
            'totaltemporaryFees',
            'totalPaidTemporary',
            'currentAmountsTemporary',
            'existingPaymentsPermanent',
            'existingPaymentsTemporary',
            'totalFeeTemporary',
            'totalFeePermanent',
            'routeType'
            
        ));
    }
        
    public function bus_fee_payment_save(Request $request){
        
       
        $validated = $request->validate([
            'posted' => 'required|array',
            'receipt_no' => 'required|string|max:255',
            'student_id' => 'required',
            'mode_id' => 'required',
            'amount' => 'required|array',
            'discount' => 'array', 
            'route_type' => 'required|array',
            'pdate' =>  "required|date|after_or_equal:$this->fsDate|before_or_equal:$this->feDate",
        ]);
            
        $posted = $validated['posted']; 
        $receiptNo = $validated['receipt_no'];
        $studentId = $validated['student_id'];
        $modeId = $validated['mode_id'];
        $paidDate = $validated['pdate']; 
        $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
        $ac_id = $cur_acyear->ac_id;
        
        DB::beginTransaction();
            
        try {
            $rec_no = BusFee::max('receipt_no') + 1 ?? 1;
            $group_id = BusFee::withTrashed()->max('group_id') + 1 ?? 1;
            
            $i=$total_amount=$total_discount=0;
            foreach ($validated['posted'] as $index => $feeId) {
                $feeSetting = BusFeeSetting::find($feeId);
                if ($feeSetting) {
                    $month = $feeSetting->month; 
                    $feeAmount = $request->amount[$feeId] ?? 0; 
                    $fineAmount = $this->calculateFine($feeSetting->date, $request->date);
                    $discountAmount = $request->discount[$feeId] ?? 0; 
                    $year = $feeSetting->year;
                    $routeType = $request->route_type[$feeId] ?? 'permanent';
                    
                    $insert = BusFee::create([
                        'group_id' => $group_id,
                        'receipt_no' => $rec_no,
                        'ac_id' => $ac_id,
                        'student_id' => $studentId,
                        'mode_id' => $modeId,
                        'month' => $month,
                        'year'=>$year,
                        'paid_date' => $paidDate,
                        'fine_amount' => $fineAmount, 
                        'fee_amount' => $feeAmount, 
                        'discount' => $discountAmount, 
                        'status' => 1, 
                        'route_type' => $routeType, 
                        'created_by' => auth()->id(),
                    ]);
                    
                    if($insert){
                        $total_amount += $feeAmount+$fineAmount;
                        $total_discount += $discountAmount;
                        $i++;
                    }
                }
            }
                
            if($i>0){
                if($total_amount>0){
                    $vgroup_id = Voucher::withTrashed()->max('group_id') + 1 ?? 1;
                    $vno = Voucher::where('vtype_id', 2)
                          ->where('account_id', $this->accountId)
                          ->whereBetween('vdate', [$this->fsDate, $this->feDate])
                          ->max('vno') + 1 ?? 1;
                        
                    $vdata = [
                            'group_id' => $vgroup_id,
                            'vtype_id' => 2,
                            'vno' => $vno,
                            'vorder' => 1,
                            'vdate' => $paidDate,
                            'dr_ledger' => $modeId,
                            'cr_ledger' => 9,
                            'vamount' => $total_amount,
                            'table_name' => 'bus_fees',
                            'table_group_id' => $group_id,
                            'account_id' => $this->accountId,
                            'created_by' => auth()->user()->user_id
                        ];
                    Voucher::create($vdata);
                }
                
                if($total_discount > 0){
                    $dgroup_id = Voucher::withTrashed()->max('group_id') + 1 ?? 1;
                    $dvno = Voucher::where('vtype_id', 1)
                          ->where('account_id', $this->accountId)
                          ->whereBetween('vdate', [$this->fsDate, $this->feDate])
                          ->max('vno') + 1 ?? 1;
                        
                    $dvdata = [
                        'group_id' => $dgroup_id,
                        'vtype_id' => 1,
                        'vno' => $dvno,
                        'vorder' => 1,
                        'vdate' => $paidDate,
                        'dr_ledger' => 13,
                        'cr_ledger' => $modeId,
                        'vamount' => $total_discount,
                        'table_name' => 'bus_fees',
                        'table_group_id' => $group_id,
                        'account_id' => $this->accountId,
                        'created_by' => auth()->user()->user_id
                    ];
                    
                    Voucher::create($dvdata);
                }
            }
            
            DB::commit();
         
            return redirect()->back()->with('success', 'Payment saved successfully!');
        } catch (\Exception $e) {
            DB::rollBack();
                
            \Log::error('Error saving payment: ' . $e->getMessage());
            return redirect()->back()->withErrors('Payment could not be processed.');
        }
    }
        
    private function calculateFine($feeDate, $paymentDate){
        $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
        $fineAmount = 0; 
        $dueDate = \Carbon\Carbon::parse($feeDate)->addMonth();
        
        if (\Carbon\Carbon::parse($paymentDate)->isAfter($dueDate)) {
            $fineSetting = BusFineSetting::where('ac_id', $cur_acyear->ac_id)->first(); 
            if ($fineSetting) {
                $fineAmount = $fineSetting->fine_amount; 
            }
        }
        
        return $fineAmount;
    }



   public function bus_routetype_fees(Request $request)
{
   
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;
    $studentId = $request->input('student_id');
    $routeType = $request->input('route_type');

    $totalPaidPermanent = BusFee::where('student_id', $studentId)
        ->where('ac_id', $ac_id)
        ->where('route_type', 'permanent')
        ->sum('fee_amount');

    $totalPaidTemporary = BusFee::where('student_id', $studentId)
        ->where('ac_id', $ac_id)
        ->where('route_type', 'temporary')
        ->sum('fee_amount');

    if ($routeType === 'permanent') {
        $routeFees = BusfacilityStudents::join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
            ->where('busfacility_students.student_id', $studentId)
            ->where('add_stop_trans.ac_id', $ac_id)
            ->select('add_stop_trans.fee')->first();

        return response()->json([
            'fee_amount' => $routeFees->fee ?? 0,
            'paid_amount' => $totalPaidPermanent,
            'fine_amount' => $routeFees->fine_amount ?? 0,
        ]);
    } else {
        $routeFees = StudentTemporaryStop::join('students', 'students.student_id', '=', 'student_temporary_stop_trans.student_id')
            ->join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'student_temporary_stop_trans.stop_id')
            ->where('student_temporary_stop_trans.student_id', $studentId)
            ->where('add_stop_trans.ac_id', $ac_id)
            ->select('add_stop_trans.fee')->first();

        return response()->json([
            'fee_amount' => $routeFees->fee ?? 0,
            'paid_amount' => $totalPaidTemporary,
            'fine_amount' => $routeFees->fine_amount ?? 0,
        ]);
    }


}
    
  public function busfee_report()
  {
       $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
       $ac_id = $cur_acyear->ac_id;
     
        $students=BusfacilityStudents::join('students','students.student_id','=','busfacility_students.student_id')
            ->where('busfacility_students.ac_id',$ac_id)
            ->select('students.*')
            ->get();
       
    
        
        return view('transportation.busfee_report',compact('students'));
  }
    
public function busfee_report_get(Request $request)
{
    $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
    $ac_id = $cur_acyear->ac_id;
     
    $student_id=Student::find($request->sid);
    $indiFee=UpdatedBusFeeStudent::join('students','students.student_id','=','updated_bus_fee_indi_student_trans.student_id')
        ->join('courses','students.course_id','=','courses.course_id')
        ->where('students.student_id',$request->sid)
        ->where('updated_bus_fee_indi_student_trans.ac_id',$ac_id)
        ->get();
    $fee=BusFee::join('students','students.student_id','=','bus_fees.student_id')
    ->where('bus_fees.student_id',$request->sid)
    ->where('bus_fees.ac_id',$ac_id)
   ->select(
       'bus_fees.*',
       'students.name',
       'students.adno',
        DB::raw('SUM(bus_fees.fee_amount) as total_fee'),
        DB::raw('SUM(bus_fees.fine_amount) as total_fine'),
        DB::raw('SUM(bus_fees.discount) as total_discount'),
        DB::raw('SUM(bus_fees.fee_amount) as total_fee_amount'),
        DB::raw('MAX(bus_fees.paid_date) as paid_date'),
        DB::raw('MAX(bus_fees.status) as status') 
    )
    ->groupBy('bus_fees.receipt_no') 
    ->get();
    return view('transportation.busfee_report_get',compact('fee','student_id','indiFee'));
}
    
 public function busfee_report_coursewise()
 {
     $courses=Course::all();
     return view('transportation.busfee_report_coursewise',compact('courses'));
 }
    
   public function busfee_report_coursewise_get(Request $request)
   {
       $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
       $ac_id = $cur_acyear->ac_id;
       $course=Course::find($request->cid);
    
       
     $Fees = BusFee::join('students', 'students.student_id', '=', 'bus_fees.student_id')
    ->join('courses', 'students.course_id', '=', 'courses.course_id')
    ->join('busfacility_students', 'busfacility_students.student_id', '=', 'bus_fees.student_id')
    ->join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
    ->where('students.course_id', $request->cid)
    ->where('bus_fees.ac_id', $ac_id)
    ->select(
        'courses.course_name',
        'students.name',
        'students.adno',
        'bus_fees.*',
        'add_stop_trans.*',
        DB::raw('SUM(add_stop_trans.fee) as total_fee'),
        DB::raw('SUM(bus_fees.fine_amount) as total_fine'),
        DB::raw('SUM(bus_fees.discount) as total_discount'),
        DB::raw('SUM(bus_fees.fee_amount) as total_fee_amount'),
        DB::raw('MAX(bus_fees.paid_date) as paid_date'),
        DB::raw('MAX(bus_fees.status) as status') 
    )
    ->groupBy('bus_fees.receipt_no','students.student_id') 
    ->get();

      
       $indiFee=UpdatedBusFeeStudent::join('students','students.student_id','=','updated_bus_fee_indi_student_trans.student_id')
        ->join('courses','students.course_id','=','courses.course_id')
        ->where('students.course_id',$request->cid)
        ->where('updated_bus_fee_indi_student_trans.ac_id',$ac_id)
        ->get();
        
    return view('transportation.busfee_report_coursewise_get',compact('Fees','indiFee'));
    
   }
    
    public function busfee_report_coursewise_print($id)
    {
        $ins_det = instituteDetails();
       
        $busFee = BusFee::findOrFail($id); 
      
       $Fees = BusFee::join('students', 'students.student_id', '=', 'bus_fees.student_id')
        ->where('bus_fees.receipt_no', $busFee->receipt_no) 
        ->where('students.student_id', $busFee->student_id)
        ->select(
            'students.name',
            'students.adno',
            'bus_fees.receipt_no',
            'bus_fees.month', 
            'bus_fees.paid_date', 
            'bus_fees.fee_amount', 
            DB::raw('SUM(bus_fees.fee_amount) as total_fee_amount'), 
            DB::raw('SUM(bus_fees.fine_amount) as total_fine'),
            DB::raw('SUM(bus_fees.discount) as total_discount') 
        )
        ->groupBy('bus_fees.month', 'students.student_id', 'bus_fees.receipt_no', 'bus_fees.paid_date') 
        ->orderBy('bus_fees.month') 
        ->get();

  
    $overallTotalFee = $Fees->sum('total_fee_amount');
    $grandTotalFine = $Fees->sum('total_fine');
    $grandTotalDiscount = $Fees->sum('total_discount');
       return view('transportation.busfee_report_coursewise_print',compact('ins_det','Fees','busFee','overallTotalFee','grandTotalFine','grandTotalDiscount'));
    }
    
  public function busfee_report_student_print($receipt_no)
  {
        $ins_det = instituteDetails();
        $busFee = BusFee::where('receipt_no', $receipt_no)->get();
         $overallTotalFee = $busFee->sum('fee_amount');
    $overallTotalFine = $busFee->sum('fine_amount');
    $overallTotalDiscount = $busFee->sum('discount');
        return view('transportation.busfee_report_student_print',compact('busFee','ins_det','overallTotalFee','overallTotalFine','overallTotalDiscount'));
  }
    public function busfee_course_cancel($receipt_no)
    {
        
        try {
      
        $busFees = BusFee::where('receipt_no', $receipt_no)->get();

       
        foreach ($busFees as $busFee) {
            $busFee->status = 0; 
            $busFee->save();
        }

        return response()->json(['success' => true]);
    } catch (\Exception $e) {
        return response()->json(['success' => false, 'error' => $e->getMessage()]);
    }
        
    }
    
   public function cancelledfeereport()
   {
     $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
     $ac_id = $cur_acyear->ac_id;   
     $Fees = BusFee::join('students', 'students.student_id', '=', 'bus_fees.student_id')
    ->join('courses', 'students.course_id', '=', 'courses.course_id')
    ->join('busfacility_students', 'busfacility_students.student_id', '=', 'bus_fees.student_id')
    ->join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
    ->where('bus_fees.ac_id', $ac_id)
    ->where('bus_fees.status','0')
    ->select(
        'courses.course_name',
        'students.name',
        'students.adno',
        'bus_fees.*',
        'add_stop_trans.*',
        DB::raw('SUM(add_stop_trans.fee) as total_fee'),
        DB::raw('SUM(bus_fees.fine_amount) as total_fine'),
        DB::raw('SUM(bus_fees.discount) as total_discount'),
        DB::raw('SUM(bus_fees.fee_amount) as total_fee_amount'),
        DB::raw('MAX(bus_fees.paid_date) as paid_date'),
        DB::raw('MAX(bus_fees.status) as status') 
    )
    ->groupBy('bus_fees.receipt_no','students.student_id') 
    ->get();
       return view('transportation.cancelledfeereport',compact('Fees'));

   }
   public function due_report()
   {
       $courses=Course::all();
        $months=array();
        $cur_acyear = Acyear::where('default1',1)->whereNull('deleted_at')->first();
        $start = strtotime($cur_acyear->sdate);
        $end = strtotime($cur_acyear->edate);
        
        while($start <= $end){
            $month = date('m',$start);
            $year = date('Y',$start);
            $status=$hmid=0;
            $hmonth = BusFeeSetting::where(array('ac_id'=>$cur_acyear->ac_id,'month'=>$month,'year'=>$year))->first();
            if($hmonth){ $status=1; $hmid=$hmonth->bfeesetting_id; }
            
            $months[] = array('month'=>$start,'status'=>$status,'hmid'=>$hmid);
            
            $start = strtotime('+1 month', $start);
        }
    
       return view('transportation.due_report',compact('courses','months'));
   }
   public function due_report_get(Request $request)
   {
     $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
     $ac_id = $cur_acyear->ac_id;   
     $cid=Course::find($request->cid);
     $sid=Semester::find($request->sid);
     $mid=$request->input('mid');
     $month=date('m',$mid);
     $year=date('Y',$mid);
     $did=$request->input('did');
     $students = Student::join('promotes','promotes.student_id','=','students.student_id')
     ->join('busfacility_students','busfacility_students.student_id','=','students.student_id')
                       ->where('promotes.course_id', $cid->course_id)
                       ->where('promotes.semester_id', $sid->semester_id)
                       ->where('promotes.ac_id',$ac_id)
                       ->get();
     
     
      $dueReports = [];
       foreach ($students as $student) {
            $hasSpecialFees = UpdatedBusFeeStudent::where('student_id', $student->student_id)->exists();
            $totalPaidFromBusFee = BusFee::where('student_id', $student->student_id)
        ->where('ac_id', $ac_id)
        ->where('month', $month)
        ->where('year', $year)
        ->sum('fee_amount');
          $expectedFeesFromAddStop = BusfacilityStudents::join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
        ->where('busfacility_students.student_id', $student->student_id)
        ->where('add_stop_trans.ac_id', $ac_id)
        ->sum('add_stop_trans.fee');
    $expectedFeesFromUpdatedBusFee = $hasSpecialFees ? UpdatedBusFeeStudent::where('student_id', $student->student_id)->sum('updated_fee') :0;
    $totalExpectedFees = $expectedFeesFromAddStop + $expectedFeesFromUpdatedBusFee;
    $totalPaid = $totalPaidFromBusFee;
    $dueAmount = $totalExpectedFees - $totalPaid; 
        if ($dueAmount > 0) {
        $dueReports[] = [
            'student' => $student,
            'expectedFees' => $totalExpectedFees,
            'totalPaid' => $totalPaid,
            'dueAmount' => $dueAmount,
            'updatedBusFee' => $expectedFeesFromUpdatedBusFee,
        ];
    } 
       }   
        
           
   
       
    return view('transportation.due_report_get', compact('dueReports'));
}

public function due_report_route()
{
    $routes=AddRouteTrans::all();
     $months=array();
        $cur_acyear = Acyear::where('default1',1)->whereNull('deleted_at')->first();
        $start = strtotime($cur_acyear->sdate);
        $end = strtotime($cur_acyear->edate);
        
        while($start <= $end){
            $month = date('m',$start);
            $year = date('Y',$start);
            $status=$hmid=0;
            $hmonth = BusFeeSetting::where(array('ac_id'=>$cur_acyear->ac_id,'month'=>$month,'year'=>$year))->first();
            if($hmonth){ $status=1; $hmid=$hmonth->bfeesetting_id; }
            
            $months[] = array('month'=>$start,'status'=>$status,'hmid'=>$hmid);
            
            $start = strtotime('+1 month', $start);
        }
    return view('transportation.due_report_route',compact('routes','months'));
}

public function due_report_route_get(Request $request)
{ 
    
    
     $cur_acyear = Acyear::where('default1', 1)->whereNull('deleted_at')->first();
     $ac_id = $cur_acyear->ac_id;   
     $rid=AddRouteTrans::find($request->rid);
     $mid=$request->input('mid');
     $month=date('m',$mid);
     $year=date('Y',$mid);
     
     $students = Student::join('promotes','promotes.student_id','=','students.student_id')
     ->join('busfacility_students','busfacility_students.student_id','=','students.student_id')
                       ->where('promotes.ac_id',$ac_id)
                       ->get();
     
     
      $dueReports = [];
       foreach ($students as $student) {
            $hasSpecialFees = UpdatedBusFeeStudent::where('student_id', $student->student_id)->where('route_id',$request->rid)->exists();
           
            $totalPaidFromBusFee = BusFee::where('student_id', $student->student_id)
        ->where('ac_id', $ac_id)
      ->where('month', $month)
        ->where('year', $year)
        ->sum('fee_amount');
          $expectedFeesFromAddStop = BusfacilityStudents::join('add_stop_trans', 'add_stop_trans.stop_id', '=', 'busfacility_students.stop_id')
        ->where('busfacility_students.student_id', $student->student_id)
         ->where('busfacility_students.route_id', $request->rid)
        ->where('add_stop_trans.ac_id', $ac_id)
        ->sum('add_stop_trans.fee');
    $expectedFeesFromUpdatedBusFee = $hasSpecialFees ? UpdatedBusFeeStudent::where('student_id', $student->student_id)->where('route_id',$request->rid)->sum('updated_fee') :0;
  
    $totalExpectedFees = $expectedFeesFromAddStop + $expectedFeesFromUpdatedBusFee;
    $totalPaid = $totalPaidFromBusFee;
    $dueAmount = $totalExpectedFees - $totalPaid; 
        if ($dueAmount > 0) {
        $dueReports[] = [
            'student' => $student,
            'expectedFees' => $totalExpectedFees,
            'totalPaid' => $totalPaid,
            'dueAmount' => $dueAmount,
            'updatedBusFee' => $expectedFeesFromUpdatedBusFee,
        ];
    } 
       }   
        
     
    return view('transportation.due_report_route_get', compact('dueReports'));

   
   
    
}



















}