<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\StaffSubject;
use App\Models\AddTutorial;
use App\Models\Course;

use Illuminate\Support\Facades\Auth;

class Tutorial extends Controller
{
    public function tutorial_add()
    {
        $userId = Auth::id();
        $staff_type = auth()->user()->type_id;
        if($staff_type == '12')
        {
            $staffsubject = StaffSubject::join('users','users.user_id','=','staff_subject.user_id')
                                ->join('courses','courses.course_id','=','staff_subject.course_id')
                                ->where('staff_subject.user_id',$userId)
                                ->get();
        }else{
            $staffsubject=Course::all();
        }
        
        return view('tutorial.tutorial_add',compact('staffsubject'));
    }

    public function tutorial_save(Request $request)
    {
        $validated = $request->validate([
            'course_id'=>'required',
            'semester_id'=>'required',
            'subject_id'=>'required',
            'title'=>'required',
            'content'=>'required',
            'file' => 'required|mimes:pdf,doc,docx,jpg,jpeg,png|max:5120',
        ]);
            
        $filename="";
        if($request->hasFile('file')){
            $file = $request->file;
            $ext = $file->extension();
            $filename = 'attachment_'.time().'.'.$ext;
            $file->storeAs('staff/tutorial',$filename);
        }
        
        $tutorial = AddTutorial::create([
            'course_id' => $validated['course_id'],
            'semester_id' => $validated['semester_id'],
            'subject_id' => $validated['subject_id'],
            'user_id' => Auth::id(),
            'title' => $validated['title'],
            'content' => $validated['content'],
            'file' => $filename,
        ]);
            
        if($tutorial){
            $msg_array = ['message' => 'Tutorial added successfully!', 'alert-type' => 'success'];
        }else{
            $msg_array = ['message' => 'The tutorial could not be added.', 'alert-type' => 'error'];
        }
        
        return redirect()->route('tutorial')->with($msg_array);
    }
        
    public function tutorial_view()
    {
        $userId = Auth::id();
        $tutorials = AddTutorial::where('user_id',$userId)->get();
            
        return view('tutorial.tutorial_view',compact('tutorials','userId'));
    }
    
    public function tutorial_delete($id)
    {
        $tutorial = AddTutorial::find($id);
        if($tutorial->delete()){
            $msg_array = ['message' => 'Tutorial Deleted Successfully.', 'alert-type' => 'success'];
        }else{
            $msg_array = ['message' => 'Tutorial could not be Deleted.', 'alert-type' => 'error'];
        }
            
        return redirect()->route('tutorial.view')->with($msg_array);
    }
        
}