<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;

use App\Models\User;
use App\Models\UserType;
use App\Models\Menu;
use App\Models\MenuAccess;
use App\Models\Acyear;
use App\Models\Student;
use App\Models\Course;
use App\Models\Fee;
use App\Models\HostelPayment;
use App\Models\Stafftype;
use App\Models\Community;
use App\Models\StaffQualiDet;
use App\Models\Promote;
use App\Models\StudentOtherFees;
use App\Models\Department;
use Carbon\Carbon;
use Image;

class Users extends Controller
{
    public function index(){
        if(auth()->check()){
             return redirect()->route('home');
        }else{
            return view('users.login');
        }
    }
    
    public function login(){
        $input = ['email' => request('email'),'password' => request('password'),'status'=>1];
        if(auth()->attempt($input,true)){
            Cache::flush();
            return redirect()->route('home');
        }else{
            return redirect()->route('login')->with('message','Invalid Credentials or User Blocked !');
        }
    }
    
    public function logout(){
        auth()->logout();
        Cache::flush();
        return redirect()->route('login');
    }
    
    public function home(){
        $user=User::all();
        return view('users.home',compact('user'));
    }
    
    public function profile(){
        
        return view('users.profile');
    }
    
    public function change_password(){
        
        return view('users.password');
    }
    
    public function save_password(Request $request){
        $validated = $request->validate([
                'current' => 'required',
                'password' => 'required|string|min:8|confirmed',
            ]);
            
        $user = auth()->user();
        if (!Hash::check($request->current, $user->password)) {
            return redirect()->back()->with(['message'=>'Current password is incorrect !','alert-type'=>'error']);
        }
        
        $user->password = bcrypt($request->password);
        $user->save();
        
        Auth::logoutOtherDevices($request->current);
            
        return redirect()->back()->with('success', 'Password updated successfully!');
    }
    
    public function update_pass(){
        $user = User::find(5);
        
        $user->update(['password' => bcrypt('Brennenteacher#24')]);
    }
    
    public function usertype(){
        $stafftype = Stafftype::all();
        $utypes = UserType::whereNull('deleted_at')->get();
        return view('users.usertype',compact('utypes','stafftype'));
        
    }
    
    public function usertype_save(Request $request){
        $validated = $request->validate([
            'type_name' => 'required|unique:user_types,type_name',
            
        ]);
        
        $utype = UserType::create([
            'type_name' => $request->type_name,
             'staftyp_id' => $request->staftyp_id,
        ]);
        
        if($utype){
            $msg_array = array('message'=>'User Type Added Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'User Type Could not be Added !','alert-type'=>'error');
        }
        return redirect()->route('usertype')->with($msg_array);
    }
    
    public function usertype_delete($utid){
        $utype = UserType::find(decrypt($utid));
        $users = User::where('type_id',decrypt($utid))->whereNull('deleted_at')->count();
        if($users==0){
            if($utype){
                if($utype->count() > 0){
                    $utype->delete();
                    $msg_array = array('message'=>'User Type Deleted Successfully !','alert-type'=>'success');
                }else{
                    $msg_array = array('message'=>'User Type Could not be Deleted !','alert-type'=>'error');
                }
            }
        }else{
            $msg_array = array('message'=>'User Exist, Type Could not be Deleted !','alert-type'=>'error');
        }
        
        return redirect()->route('usertype')->with($msg_array);
    }
    
    public function user(){
        $stafftyp=Stafftype::all();
        $community=Community::all();
        $staff_max = User::max('employee_id_num');
        $employee_id_num = $staff_max + 1;
        $utypes = UserType::whereNull('deleted_at')->get();
        $prev_no = User::whereNull('deleted_at')->latest()->first();
        $users = User::whereNull('deleted_at')->get();
        $dept=Department::all();
        
        return view('users.user',compact('utypes','users','stafftyp','community','employee_id_num','prev_no','dept'));
    }
    
    public function user_save(Request $request){
       
        $validated = $request->validate([
            'type_id' => 'required',
             'staftyp_id'=>'required',
            'name' => 'required',
            'working_type'=>'required',
            'father_guardian'=>'required',
            'dob'=>'required|date',
            'age'=>'required',
            'gender'=>'required',
            'dateof_join'=>'required|date',
            'address'=>'required',
            'mobile' => 'nullable|numeric',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|confirmed',
            'qualification' => 'required',
            'image'=>'nullable|max:5120|mimes:jpeg,png,jpg',
            'qualificationloop.*' => 'required',
            'institute.*' => 'required',
            'uni_board.*' => 'required',
            'mark_grade.*' => 'required',
            'passotyr.*' => 'required',
            'qualificationloop' => 'required|array',
            'institute' => 'required|array',
            'uni_board' => 'required|array',
            'mark_grade' => 'required|array',
            'passotyr' => 'required|array',
        ]);
        
        if($request->hasFile('image')){
            $ext = $request->image->extension();
            $image = 'image_'.time().'.'.$ext;
            
            Image::make($request->image)->resize(500,500)->save('public/uploads/staff/photo/'.$image);
        }
        
        $status=0;
        if($request->status){ $status=1; }
        $barcode = '1'.rand(10000,99999).$request->employee_id_num;
        
        $user = User::create([
            'type_id' => $request->type_id,
            'staftyp_id'=>$request->staftyp_id,
            'employee_id_num'=>$request->employee_id_num,
            'working_type'=>$request->working_type,
            'name' => $request->name,
            'lname' => $request->lname,
            'father_guardian' => $request->father_guardian,
            'dob' => $request->dob,
            'age' => $request->age,
            'gender' => $request->gender,
            'community_id' => $request->community_id,
            'blood_group' => $request->blood_group,
            'phy_handi' => $request->phy_handi,
            'phyhandi_det' => $request->phyhandi_det,
            'mobile' => $request->mobile,
            'email' => $request->email,
            'mother_tongue' => $request->mother_tongue,
            'address' => $request->address,
            'nationality' => $request->nationality,
            'state' => $request->state,
            'qualification' => $request->qualification,
            'experience' => $request->experience,
            'dateof_join' => $request->dateof_join,
            'net_qualified' => $request->net_qualified,
            'doing_research' => $request->doing_research,
            'biodata' =>$request->biodata,
            'image' =>$request->image,
            'password' => bcrypt($request->password),
            'dept_id'=>$request->dept_id,
            'status' => $status,
        ]);
        
        if($user){
            foreach($validated['qualificationloop'] as $key => $code){
                $qualidet = StaffQualiDet::Create([
                    'user_id' => $user->user_id,
                    'qualificationloop' => $code,
                    'institute' => $validated['institute'][$key],
                    'uni_board' => $validated['uni_board'][$key],
                    'mark_grade' => $validated['mark_grade'][$key],
                    'passotyr' => $validated['passotyr'][$key],
                ]);
            }
        }
        
        if($user){
            $msg_array = array('message'=>'User Added Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'User Could not be Added !','alert-type'=>'error');
        }
        return redirect()->route('user')->with($msg_array);
    }
    
    public function user_delete($uid){
        $user = User::find(decrypt($uid));
        if($user){
            $user->delete();
            $msg_array = array('message'=>'User Deleted Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'User Could not be Deleted !','alert-type'=>'error');
        }
        
        return redirect()->route('user')->with($msg_array);
    }
    
    public function user_edit($uid){
        $utypes = UserType::whereNull('deleted_at')->get();
        $user = User::find(decrypt($uid));
        return view('users.user_edit',compact('utypes','user'));
    }
    
    public function user_update(Request $request){
        $user_id = decrypt($request->user_id);
        $validated = $request->validate([
            'type_id' => 'required',
            'name' => 'required',
            'mobile' => 'nullable|numeric',
            'email' => 'required|email|unique:users,email,'.$user_id.',user_id',
            'password' => 'required|confirmed'
        ]);
        
        $status=0;
        if($request->status){ $status=1; }
        $user = User::find($user_id);
        $user->update([
            'type_id' => $request->type_id,
            'name' => $request->name,
            'mobile' => $request->mobile,
            'email' => $request->email,
            'password' => bcrypt($request->password),
            'status' => $status
        ]);
        
        if($user){
            $msg_array = array('message'=>'User Added Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'User Could not be Added !','alert-type'=>'error');
        }
        return redirect()->route('user')->with($msg_array);
    }
    
    public function previlage(){
        $utypes = UserType::whereNull('deleted_at')->get();
        return view('users.previlage',compact('utypes'));
    }
    
    public function get_previlage(Request $request)
    {
        // Validate incoming request
        $validated = $request->validate([
            'type_id' => 'required'
        ]);
        
        $type_id = $request->type_id;
        
        // Retrieve admin menus using eager loading for submenus
        $menus = Menu::where('menu_parent', 0)
            //->where('menu_type', 'dashboard')
            //->whereIn('menu_category', ['admin', 'accounts'])
            ->where('status', 1)
            ->orderBy('menu_order', 'ASC')
            ->with(['submenus' => function ($query) {
                $query->where('status', 1)->orderBy('menu_order', 'ASC');
            }])
            ->get()
            ->map(function ($parent_menu) {
                return [
                    'menu_id' => $parent_menu->menu_id,
                    'menu_name' => $parent_menu->menu_name,
                    'menu_category' => $parent_menu->menu_category,
                    'menu_type' => $parent_menu->menu_type,
                    'sub_menus' => $this->getSubMenuTree($parent_menu->submenus)
                ];
            });
        
        // Retrieve settings menus using eager loading for submenus
    /*    $settings_menus = Menu::where('menu_parent', 0)
            ->where('menu_type', 'settings')
            ->where('status', 1)
            ->orderBy('menu_order', 'ASC')
            ->with(['submenus' => function ($query) {
                $query->where('status', 1)->orderBy('menu_order', 'ASC');
            }])
            ->get()
            ->map(function ($setting_parent_menu) {
                return [
                    'menu_id' => $setting_parent_menu->menu_id,
                    'menu_name' => $setting_parent_menu->menu_name,
                    'sub_menus' => $this->getSubMenuTree($setting_parent_menu->submenus)
                ];
            });*/
    
        // Get access menus for the given user type
        $access = MenuAccess::where('type_id', $type_id)->whereNull('deleted_at')->pluck('menu_id')->toArray();
        
        // Retrieve user types
        $utypes = UserType::whereNull('deleted_at')->get();
        
        // Return the view with necessary data
        return view('users.get_previlage', compact('utypes', 'type_id', 'menus', 'access'));
    }
    
    // Helper function to recursively build the menu tree
    private function getSubMenuTree($submenus)
    {
        return $submenus->map(function ($submenu) {
            // Recursively call getSubMenuTree for each submenu if it has submenus
            return [
                'menu_id' => $submenu->menu_id,
                'menu_name' => $submenu->menu_name,
                'sub_menus' => $this->getSubMenuTree($submenu->submenus)
            ];
        });
    }
    
    public function save_previlage(Request $request){
        $validated = $request->validate([
            'utype' => 'required',
            'menulist' => 'present|array'
        ]);
        
        $type_id = decrypt($request->utype);
        $delete = MenuAccess::where('type_id',$type_id)->delete();
        
        $i=0;
        foreach($request->menulist as $menu_id){
            $access = MenuAccess::create([
                'type_id' => $type_id,
                'menu_id' => $menu_id
            ]);
            if($access){ $i++; }
        }
        if($i>0){
            $msg_array = array('message'=>'User Previlage Updated Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'User Previlage Could not be Updated !','alert-type'=>'error');
        }
        return redirect()->route('previlage')->with($msg_array);
    }
    
    public function test(){
        
        return view('users.test');
    }
   
    public function acyear_default()
    {
        $acyears =Acyear::all();
        return view('layouts.template',compact('acyears'));
    
    }
    
    
}
