<?php

namespace App\Imports;

use Illuminate\Support\Collection;
use Maatwebsite\Excel\Concerns\ToCollection;
use Maatwebsite\Excel\Concerns\WithHeadingRow;
use Illuminate\Support\Facades\Log;
use App\Models\Library\{LibraryBook, LibraryCategory, LibrarySubcategory, LibraryLocation, LibrarySublocation};

class LibraryBooksImport implements ToCollection, WithHeadingRow
{
    protected $categories = [];
    protected $subcategories = [];
    protected $locations = [];
    protected $sublocations = [];

    /**
     * @param Collection $collection
     */
    public function collection(Collection $collection)
    {
        // Preload categories, subcategories, etc., into arrays to minimize queries
        $this->categories = LibraryCategory::pluck('id', 'name')->mapWithKeys(function ($id, $name) {
            return [strtolower($name) => $id];
        })->toArray();

        $this->subcategories = LibrarySubcategory::pluck('id', 'name')->mapWithKeys(function ($id, $name) {
            return [strtolower($name) => $id];
        })->toArray();

        $this->locations = LibraryLocation::pluck('id', 'name')->mapWithKeys(function ($id, $name) {
            return [strtolower($name) => $id];
        })->toArray();

        $this->sublocations = LibrarySublocation::pluck('id', 'name')->mapWithKeys(function ($id, $name) {
            return [strtolower($name) => $id];
        })->toArray();
        
        $book_max = LibraryBook::max('book_no');
        $book_no = $book_max ? ($book_max+1):1000;
            
        foreach ($collection as $index => $row) {
            $date = $this->convertDate($row['date'] ?? null, $index);
                
            $category_id = $this->getIdFromCache($this->categories, $row['category'], 'category', $index);
            $subcategory_id = $this->getIdFromCache($this->subcategories, $row['sub_category'], 'sub_category', $index);
            $location_id = $this->getIdFromCache($this->locations, $row['location'], 'location', $index);
            $sublocation_id = $this->getIdFromCache($this->sublocations, $row['sub_location'], 'sub_location', $index);
                
            if(!LibraryBook::where('access_no', $row['access_no'])->exists()) {
                $created = LibraryBook::create([
                        'book_no' => $book_no,
                        'access_no' => $row['access_no'],
                        'title' => $row['title'],
                        'barcode' => rand(1000,9999).$book_no,
                        'author' => $row['author'],
                        'category_id' => $category_id,
                        'subcategory_id' => $subcategory_id,
                        'location_id' => $location_id,
                        'sublocation_id' => $sublocation_id,
                        'sub_title' => $row['sub_title'],
                        'date' => $date,
                        'language' => $row['language'],
                        'publisher' => $row['publisher'],
                        'volume' => $row['volume'],
                        'edition' => $row['edition'],
                        'year' => $row['year'],
                        'price' => $row['price'],
                        'condition' => ucwords($row['condition']),
                        'isbn' => $row['isbn'],
                        'reference' => ucwords($row['reference']),
                        'subject' => $row['subject'],
                        'awards' => $row['awards'],
                        'keywords' => $row['keywords'],
                        'writer' => $row['writer'],
                        'copies' => $row['copies'],
                    ]);
                if($created){
                    $book_no++;
                }
            }
        }
    }

    /**
     * Convert date to 'Y-m-d' format.
     */
    
    private function convertDate($date, $index)
    {
        if (!$date) return null;

        try {
            if (is_numeric($date)) {
                return \PhpOffice\PhpSpreadsheet\Shared\Date::excelToDateTimeObject($date)->format('Y-m-d');
            }
            return date('Y-m-d', strtotime($date));
        } catch (\Exception $e) {
            Log::error("Date conversion failed for row {$index}: " . $date);
            return null;
        }
    }

    /**
     * Retrieve ID from cached array, log an error if not found.
     */
    private function getIdFromCache($cache, $name, $type, $index)
    {
        if (!$name) return null;

        $name = strtolower(trim($name)); // Normalize input to lowercase and trim whitespace

        if (isset($cache[$name])) {
            return $cache[$name];
        } else {
            Log::error("Invalid data for row {$index}: {$type} - " . $name);
            return null;
        }
    }
}