<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

use DB;

class Accounting extends Model
{
    use HasFactory;
    
    public static function openingBalance($tdate, $account_id, $type=0, $id = null, $fdate = null)
    {
        // Ensure $tdate and $fdate are properly formatted
        $tdate = date('Y-m-d', strtotime($tdate));
        if ($fdate !== null) {
            $fdate = date('Y-m-d', strtotime($fdate)); // Ensure fdate is formatted correctly
        }
            
        // Start building the query
        $query = DB::table('ledgers')
            ->join('ledger_open_bal', 'ledgers.ledger_id', '=', 'ledger_open_bal.ledger_id')
            ->where('ledger_open_bal.account_id', $account_id)
            ->where('ledger_open_bal.opening_date', '<=', $tdate)
            ->whereNull('ledgers.deleted_at')
            ->whereNull('ledger_open_bal.deleted_at');
        if($id !== null){
            if($type == 0){
                $query->where('ledgers.ledger_id', $id);
            }else if($type == 1){
                $query->where('ledgers.ag_id', $id);
            }
        }
            
        // Apply start date filter if provided
        if ($fdate) {
            $query->where('ledger_open_bal.opening_date', '>=', $fdate);
        }
            
        // Select debit and credit sums
        $result = $query->selectRaw("
                        COALESCE(SUM(CASE WHEN ledgers.dc='dr' THEN ledger_open_bal.opening_bal ELSE 0 END), 0) AS dr_amount,
                        COALESCE(SUM(CASE WHEN ledgers.dc='cr' THEN ledger_open_bal.opening_bal ELSE 0 END), 0) AS cr_amount
                    ")->first(); // Get the first (and only) result
    
        // If no result is found, default to 0
        if (!$result) {
            return 0;
        }
    
        // Calculate the opening balance
        $opening_balance = abs($result->dr_amount-$result->cr_amount);
    
        return $opening_balance;
    }
    
    public static function voucherBalance($id, $tdate, $account_id, $type=0, $fdate = null)
    {
        $tdate = date('Y-m-d', strtotime($tdate));
        $fdate = $fdate ? date('Y-m-d', strtotime($fdate)) : null;
            
        // Start query builder for voucher amounts
        $query = DB::table('vouchers')
            ->join('ledgers', function ($join) use ($type, $id) {
                // Dynamic condition based on type (dr_ledger or cr_ledger)
                $join->on('vouchers.dr_ledger', '=', 'ledgers.ledger_id')
                    ->orOn('vouchers.cr_ledger', '=', 'ledgers.ledger_id');
            })
            ->whereNull('ledgers.deleted_at')
            ->whereNull('vouchers.deleted_at')
            ->where('vouchers.vdate', '<=', $tdate)
            ->where('vouchers.account_id', $account_id);
            
        // Apply account-specific filters
        if ($type == 0) {
            $query->where('ledgers.ledger_id', $id);
        } elseif ($type == 1) {
            $query->where('ledgers.ag_id', $id);
        }
            
        // Handle optional fdate filter
        if ($fdate) {
            $query->where('vouchers.vdate', '>=', $fdate);
        }
            
        // Use conditional aggregation to calculate DR and CR amounts
        $result = $query->selectRaw("
            COALESCE(SUM(CASE WHEN vouchers.dr_ledger = ledgers.ledger_id THEN vouchers.vamount ELSE 0 END), 0) AS dr_amount,
            COALESCE(SUM(CASE WHEN vouchers.cr_ledger = ledgers.ledger_id THEN vouchers.vamount ELSE 0 END), 0) AS cr_amount
        ")->first();
            
        return [
            'dr_amount' => $result->dr_amount,
            'cr_amount' => $result->cr_amount
        ];
    }
    
    public static function ledgerTotal($id, $tdate, $account_id, $fsdate = null)
    {
        $tdate = date('Y-m-d', strtotime($tdate));
        
        $query = DB::table('vouchers')
                    ->where('vdate','<=',$tdate)
                    ->where('account_id',$account_id)
                    ->whereNull('deleted_at');
            
        if($fsdate !== null){
            if($fsdate != $tdate){
                $query->where('vdate','>=',$fsdate);
            }else{
                return [
                    'dr_amount' => 0,
                    'cr_amount' => 0
                ];
            }
        }
            
        $query->where(function ($where) use ($id){
                    $where->where('cr_ledger',$id)
                        ->orWhere('dr_ledger',$id);
                });
            
        $result = $query->selectRaw("
            COALESCE(SUM(CASE WHEN dr_ledger = $id THEN vamount ELSE 0 END), 0) AS dr_amount,
            COALESCE(SUM(CASE WHEN cr_ledger = $id THEN vamount ELSE 0 END), 0) AS cr_amount
        ")->first();
            
        return [
            'dr_amount' => $result->dr_amount,
            'cr_amount' => $result->cr_amount
        ];
    }
        
    public static function getLedgers($ledger_type,$offset=NULL,$per_page=NULL){
        $query = Ledger::join('account_sub_group','ledgers.ag_id','=','account_sub_group.acsubgrp_id');
        if($ledger_type=="income"){
            $query->whereIn('account_sub_group.acmaingrp_id',[10,13]);
        }elseif($ledger_type=="expense"){
            $query->whereIn('account_sub_group.acmaingrp_id',[3,4,5,6]);
        }elseif($ledger_type=="asset"){
            $query->whereIn('account_sub_group.acmaingrp_id',[1,2]);
		}elseif($ledger_type=="liability"){
		    $query->whereIn('account_sub_group.acmaingrp_id',[7,8,9,11,12]);
		}
		if($offset!==null && $per_page!==null){
		    $query->skip($offset)->take($per_page);
		}
		
		$ledgers = $query->orderBy('ledgers.ledger_name')->get();
		
		return $ledgers;
    }
        
    public static function voucherAmount($sub_group,$account_id,$to_date,$offset,$per_page,$dc=NULL)
	{
		$to_date = date('Y-m-d', strtotime($to_date));
        $ledgers = self::getLedgers($sub_group,$offset,$per_page); 
        $vouchers = [];
		foreach($ledgers as $ledger){
            $voucher_amount = $debit_amount = $credit_amount = 0;
            $open_bal = self::openingBalance($to_date,$account_id,0,$ledger->ledger_id);
            $ledger_bal = self::ledgerTotal($ledger->ledger_id,$to_date,$account_id);
                
            if($ledger->dc=='dr'){
                $voucher_amount = $open_bal+$ledger_bal['dr_amount']-$ledger_bal['cr_amount'];
                if($voucher_amount>0){
					$debit_amount = $voucher_amount;
					$credit_amount = 0;
                }elseif($voucher_amount<0){
					$debit_amount = 0;
					$credit_amount = -$voucher_amount;
                }
            }else{
                $voucher_amount = $open_bal+$ledger_bal['cr_amount']-$ledger_bal['dr_amount'];
                if($voucher_amount>0){
					$debit_amount = 0;
					$credit_amount = $voucher_amount;
                }elseif($voucher_amount<0){
					$debit_amount = -$voucher_amount;
					$credit_amount = 0;
                }
            }
            if($debit_amount!=0 || $credit_amount!=0){
				$vouchers[$ledger->ledger_id] = ['dr_amount' => $debit_amount,'cr_amount' => $credit_amount,'total_amount' => $voucher_amount,'ledger_name' => $ledger->ledger_name,'dc' => $ledger->dc];
			}
		}
            
		return $vouchers;				
	}
	
	public static function profitLoss($ledger_type,$account_id,$start_date,$end_date=NULL,$offset=NULL,$per_page=NULL,$rtype=0,$fsdate=null)
	{
        $start_date = date('Y-m-d',strtotime($start_date));
        $ledgers = self::getLedgers($ledger_type,$offset,$per_page);
        $total_amount=0;  $vouchers=[];
        
        foreach($ledgers as $ledger){
            $voucher_amount = $debit_amount = $credit_amount=0;
            if($end_date == NULL){
				$open_bal = self::openingBalance($start_date,$account_id,0,$ledger->ledger_id);
			}else{
                $end_date = date('Y-m-d',strtotime($end_date));
				$open_bal = self::openingBalance($end_date,$account_id,0,$ledger->ledger_id,$fsdate);
			}
			if($end_date==null){
                $ledger_bal = self::ledgerTotal($ledger->ledger_id,$start_date,$account_id);
			}else{
                $ledger_bal = self::ledgerTotal($ledger->ledger_id,$end_date,$account_id,$start_date);
			}
			
			if($ledger->dc=='dr'){
                if($ledger->ledger_id == 3){
					$voucher_amount = $ledger_bal['cr_amount']-($ledger_bal['dr_amount']+$open_bal);
					if($voucher_amount > 0){
						$debit_amount = 0;
						$credit_amount = $voucher_amount;
					}elseif($voucher_amount < 0){
						$debit_amount = -$voucher_amount;
						$credit_amount = 0;
					}
				}else{
					$voucher_amount = ($open_bal+$ledger_bal['dr_amount'])-$ledger_bal['cr_amount'];
					if($voucher_amount > 0){
						$debit_amount = $voucher_amount;
						$credit_amount = 0;
					}elseif($voucher_amount < 0){
						$debit_amount = 0;
						$credit_amount = -$voucher_amount;
					}
				}
			}else{
                if($ledger->ledger_id == 5){
					$voucher_amount = $ledger_bal['dr_amount']-($ledger_bal['cr_amount']+$open_bal);
					if($voucher_amount>0){
						$debit_amount=$voucher_amount;
						$credit_amount=0;
					}elseif($voucher_amount<0){
						$debit_amount=0;
						$credit_amount=-$voucher_amount;
					}
				}else{
					$voucher_amount = ($open_bal+$ledger_bal['cr_amount'])-$ledger_bal['dr_amount'];
					if($voucher_amount>0){
						$debit_amount = 0;
						$credit_amount = $voucher_amount;
					}elseif($voucher_amount<0){
						$debit_amount = -$voucher_amount;
						$credit_amount = 0;
					}
				}
			}
			
			if($debit_amount != 0 || $credit_amount != 0){
				$total_amount += $voucher_amount;
				$vouchers[$ledger->ledger_id] = ['dr_amount' => $debit_amount, 'cr_amount' => $credit_amount, 'total_amount' => $voucher_amount, 'ledger_name' => $ledger->ledger_name, 'dc' => $ledger->dc];
			}
        }
        
        if($rtype == 0){
			return $vouchers;
        }else{
			return $total_amount;
        }
	}
	
	public static function cbLedgers()
	{
        $ledgers = Ledger::whereIn('ag_id',[13,14])->get();
        
        return $ledgers;
	}
	
	public static function rpAccount($start_date,$end_date,$account_id,$offset,$per_page)
	{
        $vouchers = [];
        $ledgers = self::getLedgers("all");
        foreach($ledgers as $ledger)
		{
            $receipt_amount = $payment_amount = 0;
            if($ledger->ag_id != 13 && $ledger->ag_id != 14)
			{
                $rp_voucher = self::voucherBalance($ledger->ledger_id,$end_date,$account_id,0,$start_date);
                $receipt_amount += $rp_voucher['cr_amount'];
                $payment_amount += $rp_voucher['dr_amount'];
			}
			
			if(!empty($receipt_amount))
			{
				$vouchers['receipt'][$ledger->ledger_id] = ['ledger_name' => $ledger->ledger_name,'amount' => $receipt_amount];
			}
			if(!empty($payment_amount))
			{
				$vouchers['payment'][$ledger->ledger_id] = ['ledger_name' => $ledger->ledger_name,'amount' => $payment_amount];
			}
		}
		
		return $vouchers;
	}
	
	public static function cbOpening($start_date,$account_id)
	{
        $start_date = date('Y-m-d',strtotime($start_date));
        $pre_date = date('Y-m-d',(strtotime($start_date)-86400));
        $ledgers = self::cbLedgers();
        $openings = [];
        foreach($ledgers as $ledger)
		{
            $ledger_open_bal = self::openingBalance($start_date,$account_id,0,$ledger->ledger_id);
            $voucher_bal = self::voucherBalance($ledger->ledger_id,$pre_date,$account_id,0);
            $voucher_open_bal = $voucher_bal['dr_amount']-$voucher_bal['cr_amount'];
            $open_bal = $ledger_open_bal+$voucher_open_bal;
            if($open_bal!=0){
                $openings[$ledger->ledger_id] = ['ledger_name' => $ledger->ledger_name,'amount' => $open_bal];
            }
		}
		
		return $openings;
	}
	
	public static function cbClosing($end_date,$account_id)
	{
        $end_date = date('Y-m-d',strtotime($end_date));
        $ledgers = self::cbLedgers();
        $closings = [];
        foreach($ledgers as $ledger)
		{
            $ledger_close_bal = self::openingBalance($end_date,$account_id,0,$ledger->ledger_id);
            $voucher_bal = self::voucherBalance($ledger->ledger_id,$end_date,$account_id,0);
            $voucher_close_bal = $voucher_bal['dr_amount']-$voucher_bal['cr_amount'];
            $close_bal = $ledger_close_bal+$voucher_close_bal;
            if($close_bal!=0){
                $closings[$ledger->ledger_id] = ['ledger_name' => $ledger->ledger_name,'amount' => $close_bal];
            }
		}
		
		return $closings;
	}
}
