<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class BusFee extends Model
{
    use HasFactory, SoftDeletes;
    protected $table='bus_fees';
    protected $primaryKey = 'busfee_id'; 
    
    protected $guarded = [];
    protected $hidden = ['busfee_id'];
    
    
    public function student()
    {
        return $this->hasOne(Student::class,'student_id','student_id');
      
    }
    public function stop()
    {
        return $this->hasOne(AddStopTrans::class,'stop_id','stop_id');
    }
    public function paymentmode()
    {
        return $this->hasOne(Paymentmode::class,'mode_id','mode_id');
    }

     public function getPaidDateFormattedAttribute(){
        return date('d/m/Y',strtotime($this->paid_date));
    }
    
    
      public function getMonthFormattedAttribute(){
        return date('F Y',strtotime($this->year.'-'.$this->month.'-01'));
    }
    
     protected $appends = ['ptype_text','paid_date_formatted','month_formatted'];
     
      public static function studentAcyear($sid){
        $acyears=array();
        $rows = Promote::where('student_id',$sid)->whereNull('deleted_at')->get();
        if(!empty($rows)){
            foreach($rows as $row){
                $acyears[$row->ac_id] = array('course'=>$row->course_id,'semester'=>$row->semester_id);
            }
        }
        return $acyears;
    }
    
       public static function busFees($sid){
        $fs_array = array();
		$acyear = self::studentAcyear($sid);
		$busfacility = BusfacilityStudents::where('student_id',$sid)->where('status',1)->first();
		if($busfacility){
    		foreach($acyear as $ac_id=>$ac_det){
    		    $month_array = BusFeeSetting::where('ac_id',$ac_id)->get();
        		foreach($month_array as $month){
        		    $edate = date('Y-m-t',strtotime($month->year.'-'.$month->month.'-01'));
        		    if($busfacility->from<=$edate){
            			$bus_fee_structure = self::busFeeStructure($sid,$busfacility->busfaci_stu_id,$month->bfeesetting_id,$month->month,$month->year);
            			if(count($bus_fee_structure) > 0){
            				$fs_array[$ac_id][$month->month_id] = array('semester'=>$ac_det['semester'],'month'=>$month->month,'year'=>$month->year,'myear'=>date('F Y',strtotime($edate)),'fee'=>$bus_fee_structure);
            			}
        		    }
        		}
    		}
		}
		return $fs_array;
    }
    
    
        public static function busFeeStructure($sid,$route,$month,$year){
        $pdate = date('Y-m-d',strtotime($year.'-'.$month.'-01'));
		$fee_array = array();
		$regular = AddStopTrans::where('route_id',$route)->where('fromdate','<=',$pdate)->orderBy('fromdate','DESC')->first();
		if(!empty($regular)){
		    if($regular->fee!=NULL && $regular->fee>0){
    		    $regular_due = self::regularDue($sid,$month,$year,$regular->fee);
    		    if($regular_due>0){
    		        $fee_array[1] = array('ptype'=>1,'fee_type'=>'Permanent','fee'=>$regular->fee,'due'=>$regular_due);
    		    }
		    }
		}

// 		$individual = UpdatedBusFeeStudent::where('route_id',$route)->orderBy('route_id','DESC')->first();
// 		if($individual){
// 		    if($individual->updated_fee!=NULL && $individual->updated_fee>0){
//     		    $individual_due = self::messDue($sid,$month,$year,$mess->amount);
//     		    if($mess_due>0){
//     		        $fee_array[2] = array('ptype'=>2,'fee_type'=>'Mess Fee','fee'=>$mess->amount,'due'=>$mess_due);
//     		    }
// 		    }
// 		}
		
		return $fee_array;
    }

    
    public static function regularDue($sid,$month,$year,$amount){
	    $due_amount=0;
	    $paid = self::where(array('student_id'=>$sid,'ptype'=>1,'month'=>$month,'year'=>$year,'status'=>1))->sum('fee_amount');
		if($paid){
		    $due_amount = abs($amount-$paid);
		}else{
		    $due_amount=$amount;
		}
		return $due_amount;
	}
    
    
    
    
    
    
    
    
    
    
    
    
}
