<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Fee extends Model
{
    use HasFactory, SoftDeletes;
    
    protected $table = 'fees';
    
    protected $primaryKey = 'fee_id'; 
    
    protected $guarded = [];
    
    protected $hidden = ['fee_id'];
    
    public function student(){
        return $this->hasOne(Student::class,'student_id','student_id');
    }
    
    public function mode(){
        return $this->hasOne(Paymentmode::class,'mode_id','mode_id');
    }
    
    public function term(){
        return $this->hasOne(FeeTerm::class,'term_id','term_id');
    }
    
    public function ftype(){
        return $this->hasOne(FeeType::class,'type_id','type_id');
    }
    
    public function semester(){
        return $this->hasOne(Semester::class,'semester_id','semester_id');
    }
     public function promote()
     {
         return $this->hasOne(Promote::class,'student_id','student_id');
     }
      public function course()
     {
         return $this->hasOne(Course::class,'course_id','course_id');
     }
    
    public function getPaidDateFormattedAttribute(){
        return date('d/m/Y',strtotime($this->paid_date));
    }
    
    protected $appends = ['paid_date_formatted'];
    
        public static function studentAcyears($sid){
        $acyear=array();
        $promotes = Promote::where('student_id',$sid)->get();
        if($promotes){
            foreach($promotes as $promote)
            {
             $acyear[$promote->ac_id][] = array('course_id' => $promote->course_id,'category_id' =>$promote->category_id,'category_name'=>$promote->category->category_name,'course_name'=>$promote->course->course_name,'semester_id' => $promote->semester_id,'semester_name'=>$promote->semester->semester_name);
   
            }
        }
       
        return $acyear;
    }

    
    
    
    public static function studentAcyear($sid){
        $acyear=array();
        $student = Student::find($sid);
        if($student){
            $acyear[$student->ac_id] = array('course' => $student->course_id,'category' => $student->category_id,'start_year' => $student->acyear->sdate,'end_year' => $student->acyear->edate);
        }
        return $acyear;
    }
    
    public static function studentTerms($sid,$acyear,$course,$sem,$category){ 
		$term_array=array();
		$results = FeeStructure::join('fee_terms','fee_structures.term_id','=','fee_terms.term_id')->where(array('fee_structures.ac_id'=>$acyear,'fee_structures.course_id'=>$course,'fee_structures.semester_id'=>$sem,'fee_structures.category_id'=>$category))->select('fee_terms.*')->get();
		if($results){
		    foreach($results as $result){
		        $term_array[$result->term_id] = $result->term_name;
		    }
		}
		return $term_array;
	}
    
    public static function studentFees($sid,$pdate){
        $fs_array = array();
		$pdate = date('Y-m-d',strtotime($pdate));
		$ac_array = self::studentAcyears($sid);
		$student=Student::find($sid);
		foreach($ac_array as $ac_id=>$ac_det)
		{
		    foreach($ac_det as $sem_det)
		    {
		    $sem_fee_structure=self::studentFeeStructure($sid,$sem_det['course_id'],$sem_det['category_id'],$ac_id,$pdate,$sem_det['semester_id']);
				if(count($sem_fee_structure) > 0){
		  $fs_array[$ac_id][$sem_det['semester_id']] = array('name'=>$sem_det['semester_name'],'fee_structure'=>$sem_fee_structure);
				}

		    }


			}



	
		return $fs_array;
    }
    
    public static function studentFeeStructure($sid,$course,$category,$acyear,$pdate,$sem){
        $pdate = date('Y-m-d',strtotime($pdate));
		$pdate_time = strtotime($pdate);
		$term_array = self::studentTerms($sid,$acyear,$course,$sem,$category);
		$fterm_array = array();
		
		foreach($term_array as $term_id => $term_name){
			$feetypes = FeeType::all();
			$ftype_array=array();
			foreach($feetypes as $feetype){
				$fee_amount=$due_amount=$fine_amount=0; $start_date=$end_date="";
				$type_id = $feetype->type_id;
				$result = FeeStructure::join('fee_structure_types','fee_structures.structure_id','=','fee_structure_types.structure_id')->where(array('fee_structures.ac_id'=>$acyear,'fee_structures.course_id'=>$course,'fee_structures.semester_id'=>$sem,'fee_structures.category_id'=>$category,'fee_structures.term_id'=>$term_id,'fee_structure_types.type_id'=>$type_id))->select('fee_structure_types.*')->get()->first();
				if($result){
				    $fee_amount = $result->amount;
					$start_date = $result->start_date;
					$end_date = $result->end_date;
				}
				if($fee_amount > 0){
					$end_date_time = strtotime($end_date);
					$due_amount = self::feeDue($sid,$acyear,$sem,$term_id,$type_id,$fee_amount);
					$paid_date=self::paidDate($sid,$acyear,$sem,$term_id,$type_id);
					if($pdate_time > $end_date_time && $due_amount > 0){
						$fine_amount = self::feefine($sid,$acyear,$sem,$term_id,$type_id,$fee_amount,$end_date,$pdate);
					}
					$ftype_array[$type_id] = array('due_amount'=>$due_amount,'ftype_name'=>$feetype->type_name,'start_date'=>$start_date,'end_date' => $end_date,'term_fee' => $fee_amount,'fine_amount'=>$fine_amount,'paid_date'=>$paid_date);
				}
			}
			if(count($ftype_array) > 0){
				$fterm_array[$term_id] = array('name'=>$term_name,'fee_type'=>$ftype_array);
			}
		}
		return $fterm_array;
    }
    
// public static function studentFeeStructure($sid, $course, $category, $acyear, $pdate, $sem) {
//     $pdate = date('Y-m-d', strtotime($pdate));
//     $pdate_time = strtotime($pdate);

//     $term_array = self::studentTerms($sid, $acyear, $course, $sem, $category);
//     $fterm_array = array();
    
//     $years = Promote::where('student_id', $sid)->pluck('ac_id')->toArray();
//     $years[] = $acyear; 

//     foreach ($years as $year) {
//         foreach ($term_array as $term_id => $term_name) {
//             $feetypes = FeeType::all();
//             $ftype_array = array();

//             foreach ($feetypes as $feetype) {
//                 $fee_amount = $due_amount = $fine_amount = 0;
//                 $start_date = $end_date = "";
//                 $type_id = $feetype->type_id;

//                 $result = FeeStructure::join('fee_structure_types', 'fee_structures.structure_id', '=', 'fee_structure_types.structure_id')
//                     ->where(array(
//                         'fee_structures.ac_id' => $year,
//                         'fee_structures.course_id' => $course,
//                         'fee_structures.semester_id' => $sem,
//                         'fee_structures.category_id' => $category,
//                         'fee_structures.term_id' => $term_id,
//                         'fee_structure_types.type_id' => $type_id
//                     ))
//                     ->select('fee_structure_types.*')
//                     ->first();

//                 if ($result) {
//                     $fee_amount = $result->amount;
//                     $start_date = $result->start_date;
//                     $end_date = $result->end_date;
//                 }

//                 if ($fee_amount > 0) {
//                     $end_date_time = strtotime($end_date);
//                     $due_amount = self::feeDue($sid, $year, $sem, $term_id, $type_id, $fee_amount);
//                     $paid_date = self::paidDate($sid, $year, $sem, $term_id, $type_id);

//                     if ($pdate_time > $end_date_time && $due_amount > 0) {
//                         $fine_amount = self::feefine($sid, $year, $sem, $term_id, $type_id, $fee_amount, $end_date, $pdate);
//                     }

//                     $ftype_array[$type_id] = array(
//                         'due_amount' => $due_amount,
//                         'ftype_name' => $feetype->type_name,
//                         'start_date' => $start_date,
//                         'end_date' => $end_date,
//                         'term_fee' => $fee_amount,
//                         'fine_amount' => $fine_amount,
//                         'paid_date' => $paid_date
//                     );
//                 }
//             }

//             if (count($ftype_array) > 0) {
//                 $fterm_array[$year][$term_id] = array(
//                     'name' => $term_name,
//                     'fee_type' => $ftype_array
//                 );
//             }
//         }
//     }

//     return $fterm_array;
// }

    
    
    
    
    
    
    
    
    
    
    public static function feeDue($sid,$acyear,$sem,$term,$type,$fee_amount){
		$paid = self::where(array('student_id'=>$sid,'ac_id'=>$acyear,'semester_id'=>$sem,'term_id'=>$term,'type_id'=>$type,'status'=>1))->sum('fee_amount');
		if($paid){
		    $due_amount = abs($fee_amount-$paid);
		}else{
		    $due_amount=$fee_amount;
		}
		return $due_amount;
	}
	    public static function paidDate($sid,$acyear,$sem,$term,$type){
	
		$paid_date = self::where(array('student_id'=>$sid,'ac_id'=>$acyear,'semester_id'=>$sem,'term_id'=>$term,'type_id'=>$type,'status'=>1))->select('paid_date')->orderBy('fee_id','desc')->get()->first();
	if($paid_date)
	{
	   	return $paid_date->paid_date; 
	}
	else
	{
	    return '--';
	}
	}

	public static function feeFine($sid,$acyear,$sem,$term,$type,$fee_amount,$end_date,$pdate){
		$fine_amount=0;
		$end_date_time=strtotime($end_date);
		$pdate_time=strtotime($pdate);
		$lastdate = self::where(array('ac_id'=>$acyear,'student_id'=>$sid,'semester_id'=>$sem,'term_id'=>$term,'type_id'=>$type,'status'=>1))->select('paid_date')->orderBy('paid_date','DESC')->first();
		if($lastdate){
		    $last_paid_date = $lastdate;
			$last_paid_date_time=strtotime($last_paid_date);
			if($last_paid_date_time > $end_date_time){
				$end_date=$last_paid_date;
				$end_date_time=strtotime($end_date);
			}
		}
		
		$days = floor(($pdate_time-$end_date_time)/86400);
		$result = FeeFine::where(array('ac_id'=>$acyear,'type_id'=>$type))->select('fine_type')->distinct()->first();
		if($result){
		    if($result->fine_type == 0){
		        if($days > 0){
		            $result1 = FeeFine::where(array('ac_id'=>$acyear,'type_id'=>$type))->where('from','<=',$days)->where('to','>=',$days)->first();
		            if($result1){
		                $fine_amount = $result1->amount;
		            }else{
		                $result2 = FeeFine::where(array('ac_id'=>$acyear,'type_id'=>$type,'to'=>'-1'))->first();
		                $fine_amount = $result2->amount;
		            }
		        }
		    }else{
		        $months = self::totalMonths($end_date,$pdate);
		        if($months > 0){
		            $result1 = FeeFine::where(array('ac_id'=>$acyear,'type_id'=>$type))->where('from','<=',$months)->where('to','>=',$months)->first();
		            if($result1){
		                $fine_amount = $result1->amount;
		            }else{
		                $result2 = FeeFine::where(array('ac_id'=>$acyear,'type_id'=>$type,'to'=>'-1'))->first();
		                $fine_amount = $result2->amount;
		            }
		        }
		    }
		}
		return $fine_amount;
	}
	
	public static function totalMonths($start_date,$end_date){
		$ts1 = strtotime($start_date);
		$ts2 = strtotime($end_date);
		$year1 = date('Y', $ts1);
		$year2 = date('Y', $ts2);
		$month1 = date('m', $ts1);
		$month2 = date('m', $ts2);
		$day=($ts2-$ts1)/86400;
		$days=cal_days_in_month(CAL_GREGORIAN,$month1,$year1);
		if($days == $day){
			$diff = (($year2 - $year1) * 12) + ($month2 - $month1);
		}else{
			$diff = ((($year2 - $year1) * 12) + ($month2 - $month1));
			if($diff > 0){
				$diff-1;
			}
		}
		return $diff;
	}
	
	public static function studentSemesters($course){
		$sem_array = array();
		$results = Semester::where('course_id',$course)->orderBy('semester_id','ASC')->get();
		if($results){
			foreach($results as $result){
				$sem_array[$result->semester_id] = $result->semester_name;
			}
		}
		return $sem_array;
	}

	
	
    // 	*/....................................*/student_fee_structure....*/
	    public static function studentTermsStudent($sid,$acyear,$course,$sem,$category){ 
		$term_array=array();
		$results = StudentFeeStru::join('student_fee_structure','student_fee_structure.term_id','=','fee_terms.term_id')->where(array('student_fee_structure.ac_id'=>$acyear,'student_fee_structure.course_id'=>$course,'student_fee_structure.semester_id'=>$sem,'student_fee_structure.category_id'=>$category,'student_fee_structure.student_id'=>$sid))->select('fee_terms.*')->get();
		if($results){
		    foreach($results as $result){
		        $term_array[$result->term_id] = $result->term_name;
		    }
		}
		return $term_array;
	}

	
	
	
	
	
	    public static function studentFeeStructureStudent($sid,$course,$category,$acyear,$pdate,$sem){
        $pdate = date('Y-m-d',strtotime($pdate));
		$pdate_time = strtotime($pdate);
		$term_array = self::studentTermsStudent($sid,$acyear,$course,$sem,$category);
		$fterm_array = array();
		
		foreach($term_array as $term_id => $term_name){
			$feetypes = FeeType::all();
			$ftype_array=array();
			foreach($feetypes as $feetype){
				$fee_amount=$due_amount=$fine_amount=0; $start_date=$end_date="";
				$type_id = $feetype->type_id;
				$result = StudentFeeStru::join('student_feestructure_types','student_fee_structure.stu_structure_id ','=','student_feestructure_types.stu_structure_id')->where(array('student_fee_structure.ac_id'=>$acyear,'student_fee_structure.course_id'=>$course,'student_fee_structure.semester_id'=>$sem,'student_fee_structure.category_id'=>$category,'student_fee_structure.term_id'=>$term_id,'student_fee_structure.student_id'=>$sid,'student_feestructure_types.type_id'=>$type_id))->select('fee_structure_types.*')->get()->first();
				if($result){
				    $fee_amount = $result->amount;
					$start_date = $result->start_date;
					$end_date = $result->end_date;
				}
				if($fee_amount > 0){
					$end_date_time = strtotime($end_date);
					$due_amount = self::feeDue($sid,$acyear,$sem,$term_id,$type_id,$fee_amount);
					$paid_date=self::paidDate($sid,$acyear,$sem,$term_id,$type_id);
					if($pdate_time > $end_date_time && $due_amount > 0){
						$fine_amount = self::feefine($sid,$acyear,$sem,$term_id,$type_id,$fee_amount,$end_date,$pdate);
					}
					$ftype_array[$type_id] = array('due_amount'=>$due_amount,'ftype_name'=>$feetype->type_name,'start_date'=>$start_date,'end_date' => $end_date,'term_fee' => $fee_amount,'fine_amount'=>$fine_amount,'paid_date'=>$paid_date);
				}
			}
			if(count($ftype_array) > 0){
				$fterm_array[$term_id] = array('name'=>$term_name,'fee_type'=>$ftype_array);
			}
		}
		return $fterm_array;
    }

	
	
	
	
	
}
