<?php

namespace App\Models\Library;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

use Carbon\Carbon;

class LibraryIssue extends Model
{
    use HasFactory, SoftDeletes;
    
    protected $guarded = [];
    
    public function membertype(){
        return $this->belongsTo(LibraryMemberType::class,'type_id')->withDefault(['name' => '']);
    }
    
    public function member(){
        return $this->belongsTo(LibraryMembership::class,'member_id')->withDefault(['name' => '']);
    }
    
    public function book(){
        return $this->belongsTo(LibraryBook::class,'book_id')->withDefault(['name' => '']);
    }
    
    public function getIssuedateFormattedAttribute(){
        if($this->issue_date){
            return date('d/m/Y',strtotime($this->issue_date));
        }
        return null;
    }
    
    public function getDuedateFormattedAttribute(){
        if($this->due_date){
            return date('d/m/Y',strtotime($this->due_date));
        }
        return null;
    }
    
    public function getReturndateFormattedAttribute(){
        if($this->return_date){
            return date('d/m/Y',strtotime($this->return_date));
        }
        return null;
    }
    
    public function getFineAmountAttribute()
    {
        // If the due date hasn't passed, no fine
        if (Carbon::now()->lte(Carbon::parse($this->due_date))) {
            return 0;
        }

        // Get the related library type
        $memberType = $this->membertype;

        if (!$memberType) {
            return 0; // Return 0 if no type is associated
        }

        $fineAmount = $memberType->fine_amount;
        $finePer = $memberType->fine_per;
        $fineDay = $memberType->fine_day;

        // Calculate days past due
        $daysPastDue = Carbon::parse($this->due_date)->diffInDays(Carbon::now());

        switch ($fineDay) {
            case 'Day':
                return ($daysPastDue/$finePer) * $fineAmount;

            case 'Month':
                $monthsPastDue = Carbon::parse($this->due_date)->diffInMonths(Carbon::now());
                return (($monthsPastDue+1)/$finePer) * $fineAmount;

            case 'To End':
                return $fineAmount;

            default:
                return 0; // Default to 0 if `fin_per` is invalid
        }
    }
    
    protected $appends = ['issue_date_formatted', 'due_date_formatted', 'return_date_formatted', 'fine_amount'];
}
