@extends('layouts.template') 
@section('title', 'Balance Sheet') 
@section('heading', 'Balance Sheet') 
@section('breadcrumb', 'Home / Account / Report / Balance Sheet') 
@section('content')
    <div class="card">
        <div class="card-body">
            <form action="{{ route('accounts.report.balancesheet') }}" method="GET">
            <div class="row">
                <div class="col-12 col-sm-3">
                    <div class="form-group">
                        <label for="fdate" class="required">From Date</label>
                        <input type="date" class="form-control" id="fdate" name="fdate" value="{{ $fdate }}" required>
                    </div>
                </div>
                <div class="col-12 col-sm-5">
                    <div class="form-group">
                        <label for="tdate" class="required">To Date</label>
                        <div class="row">
                            <div class="col-12 col-sm-7">
                                <div class="form-group">
                                    <input type="date" class="form-control" id="tdate" name="tdate" value="{{ $tdate }}" required>
                                </div>
                            </div>
                            <div class="col-12 col-sm-5">
                                <div class="form-group">
                                    <button type="submit" class="btn btn-sm btn-success">Submit</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <br>
    <div class="card">
        <div class="card-body">
            <div class="row">
                <div class="col-12">
                    <div class="form-group">
                        @if($export==1)
                            <a href="{{ route('accounts.report.balancesheet.export',['fdate'=>$fdate,'tdate'=>$tdate,'accountid'=>$accountid]) }}" class="btn btn-sm btn-danger float-right" target="_blank">Export</a>
                        @endif
                    </div>
                </div>
            </div>
            @php
                $total_expense=$total_income=0;
                foreach($expenses as $key => $value){
                    $total_expense += $value['total_amount'];
                }
                
                foreach($incomes as $key => $value){
                    $total_income += $value['total_amount'];
                }
                
                $profit_loss = $total_income-$total_expense;
            @endphp
            <div class="row">
                <div class="col-6">
                    <table class="table table-bordered mt-2">
                        <thead>
                        <tr>
                            <th width="70%">Liability</th>
                            <th width="30%">Amount</th>
                        </tr>
                        </thead>
                        <tbody>
                            @php $total_liability=0; @endphp
                            @foreach($liabilities as $key => $value)
                                @php $total_liability += $value['total_amount']; @endphp
                                <tr>
                                    <td>{{ $value['ledger_name'] }}</td>
                                    <td align="right">{{ number_format($value['total_amount'],2) }}</td>
                                </tr>
                            @endforeach
                            @if($profit_loss > 0)
                                @php $total_liability += $profit_loss; @endphp
                                <tr>
                                    <td>Profit & Loss A/c</td>
                                    <td align="right">{{ number_format($profit_loss,2) }}</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>
                </div>
                <div class="col-6">
                    <table class="table table-bordered mt-2">
                        <thead>
                        <tr>
                            <th width="70%">Asset</th>
                            <th width="30%">Amount</th>
                        </tr>
                        </thead>
                        <tbody>
                            @php $total_asset=0; @endphp
                            @foreach($assets as $key => $value)
                                @php $total_asset += $value['total_amount']; @endphp
                                <tr>
                                    <td>{{ $value['ledger_name'] }}</td>
                                    <td align="right">{{ number_format($value['total_amount'],2) }}</td>
                                </tr>
                            @endforeach
                            @if($profit_loss < 0)
                                @php $total_asset += -$profit_loss; @endphp
                                <tr>
                                    <td>Profit & Loss A/c</td>
                                    <td align="right">{{ number_format(-$profit_loss,2) }}</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>
                </div>
            </div>
            <div class="row">
                <div class="col-6">
                    <table class="table table-bordered">
                        <tbody>
                            @if($total_liability < $total_asset)
                                @php $op_bal = $total_asset-$total_liability;
                                $total_liability += $op_bal; @endphp
                                <tr>
                                    <td width="70%">Difference In Opening Balance</td>
                                    <td align="right">{{ number_format($op_bal,2) }}</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>
                </div>
                <div class="col-6">
                    <table class="table table-bordered">
                        <tbody>
                            @if($total_liability > $total_asset)
                                @php $op_bal = $total_liability-$total_asset;
                                $total_asset += $op_bal; @endphp
                                <tr>
                                    <td width="70%">Difference In Opening Balance</td>
                                    <td align="right">{{ number_format($op_bal,2) }}</td>
                                </tr>
                            @endif
                        </tbody>
                    </table>
                </div>
            </div>
            <div class="row">
                <div class="col-6">
                    <table class="table table-bordered">
                        <tbody>
                            <tr>
                                <td width="70%"><b>TOTAL</b></td>
                                <td align="right"><b>{{ number_format($total_liability,2) }}</b></td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                <div class="col-6">
                    <table class="table table-bordered">
                        <tbody>
                            <tr>
                                <td width="70%"><b>TOTAL</b></td>
                                <td align="right"><b>{{ number_format($total_asset,2) }}</b></td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
@endsection