@extends('layouts.template') 
@section('title', 'Trial Balance') 
@section('heading', 'Trial Balance') 
@section('breadcrumb', 'Home / Account / Report / Trial Balance') 
@section('content')
    <div class="card">
        <div class="card-body">
            <form action="{{ route('accounts.report.trial') }}" method="GET">
            <div class="row">
                <div class="col-12 col-sm-3">
                    <div class="form-group">
                        <label for="fdate" class="required">From Date</label>
                        <input type="date" class="form-control" id="fdate" name="fdate" value="{{ $fdate }}" required>
                    </div>
                </div>
                <div class="col-12 col-sm-5">
                    <div class="form-group">
                        <label for="tdate" class="required">To Date</label>
                        <div class="row">
                            <div class="col-12 col-sm-7">
                                <div class="form-group">
                                    <input type="date" class="form-control" id="tdate" name="tdate" value="{{ $tdate }}" required>
                                </div>
                            </div>
                            <div class="col-12 col-sm-5">
                                <div class="form-group">
                                    <button type="submit" class="btn btn-sm btn-success">Submit</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <br>
    <div class="card">
        <div class="card-body">
            <div class="row">
                <div class="col-12">
                    <div class="form-group">
                        @if($export==1)
                            <a href="{{ route('accounts.report.trial.export',['fdate'=>$fdate,'tdate'=>$tdate,'accountid'=>$accountid]) }}" class="btn btn-sm btn-danger float-right" target="_blank">Export</a>
                        @endif
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-12">
                    <table class="table table-bordered mt-2">
                        <thead>
                        <tr>
                            <th width="60%">Particulars</th>
                            <th width="20%">Debit</th>
                            <th width="20%">Credit</th>
                        </tr>
                        </thead>
                        <tbody>
                            @php $dr_total=$cr_total=0; @endphp
                            @foreach($liabilities as $liability)
                                @php $dr_total += $liability['dr_amount'];
                                $cr_total += $liability['cr_amount']; @endphp
                                <tr>
                                    <td>{{ $liability['ledger_name'] }}</td>
                                    <td align="right">{{ number_format($liability['dr_amount'],2) }}</td>
                                    <td align="right">{{ number_format($liability['cr_amount'],2) }}</td>
                                </tr>
                            @endforeach
                            @foreach($assets as $asset)
                                @php $dr_total += $asset['dr_amount'];
                                $cr_total += $asset['cr_amount']; @endphp
                                <tr>
                                    <td>{{ $asset['ledger_name'] }}</td>
                                    <td align="right">{{ number_format($asset['dr_amount'],2) }}</td>
                                    <td align="right">{{ number_format($asset['cr_amount'],2) }}</td>
                                </tr>
                            @endforeach
                            @foreach($expenses as $expense)
                                @php $dr_total += $expense['dr_amount'];
                                $cr_total += $expense['cr_amount']; @endphp
                                <tr>
                                    <td>{{ $expense['ledger_name'] }}</td>
                                    <td align="right">{{ number_format($expense['dr_amount'],2) }}</td>
                                    <td align="right">{{ number_format($expense['cr_amount'],2) }}</td>
                                </tr>
                            @endforeach
                            @foreach($incomes as $income)
                                @php $dr_total += $income['dr_amount'];
                                $cr_total += $income['cr_amount']; @endphp
                                <tr>
                                    <td>{{ $income['ledger_name'] }}</td>
                                    <td align="right">{{ number_format($income['dr_amount'],2) }}</td>
                                    <td align="right">{{ number_format($income['cr_amount'],2) }}</td>
                                </tr>
                            @endforeach
                            @php 
                            $dr_total += $profit_loss_dr; 
                            $cr_total += $profit_loss_cr;
                            $total_diff=($dr_total-$cr_total);
                            if($total_diff > 0){
                                $opening_bal_dr = 0;
                                $opening_bal_cr = $total_diff;
                            }else{
                                $opening_bal_dr = abs($total_diff);;
                                $opening_bal_cr = 0;
                            }
                            $dr_total += $opening_bal_dr;
                            $cr_total += $opening_bal_cr;
                            @endphp
                            <tr>
                                <td>SURPLUS & DEFICIT ACCOUNT</td>
                                <td align="right">{{ number_format($profit_loss_dr,2) }}</td>
                                <td align="right">{{ number_format($profit_loss_cr,2) }}</td>
                            </tr>
                            <tr>
                                <td>OPENING BALANCE</td>
                                <td align="right">{{ number_format($opening_bal_dr,2) }}</td>
                                <td align="right">{{ number_format($opening_bal_cr,2) }}</td>
                            </tr>
                            <tr>
                                <td><b>TOTAL</b></td>
                                <td align="right"><b>{{ number_format($dr_total,2) }}</b></td>
                                <td align="right"><b>{{ number_format($cr_total,2) }}</b></td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
@endsection