@extends('layouts.template')
@section('title','Account Groups')
@section('heading','Account Groups')
@section('breadcrumb','Home / Account Groups')
@section('content')
    @if($add==1)
        <div class="card card-primary">
            <div class="card-header">Add Account Group</div>
            <div class="card-body">
                <form action="{{ route('accounts.group.save') }}" method="post">
                    @csrf
                    <div class="row">
                        <div class="col-12 col-sm-4">
                            <div class="form-group">
                                <label for="main_id" class="required">Main Group</label>
                                <select class="form-control" id="main_id" name="main_id" required>
                                    @foreach($maingroups as $maingroup)
                                        <option value="{{ $maingroup->acmaingrp_id }}" {{ old('main_id')==$maingroup->acmaingrp_id ? "selected":"" }}>{{ $maingroup->main_group }}</option>
                                    @endforeach
                                </select>
                                @error('main_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-12 col-sm-8">
                            <div class="form-group">
                                <label for="subgroup" class="required">Sub Group Name</label>
                                <div class="row">
                                    <div class="col-12 col-sm-6">
                                        <div class="form-group">
                                            <input type="text" class="form-control @error('subgroup') border-danger @enderror" id="subgroup" name="subgroup" value="{{ old('subgroup') }}">
                                            @error('subgroup')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                        </div>
                                    </div>
                                    <div class="col-12 col-sm-6">
                                        <div class="form-group">
                                            <button type="submit" class="btn btn-sm btn-success">Save</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
        <br>
    @endif
    <div class="card">
        <div class="card-body">
            <table class="table table-bordered" id="groupTable" width="100%">
                <thead>
                <tr>
                    <th class="no-sort">#</th>
                    <th>Sub Group</th>
                    <th>Main Group</th>
                    <th>Dr/Cr</th>
                    <th class="no-sort">Actions</th>
                </tr>
                </thead>
                <tbody>
                </tbody>
            </table>
        </div>
    </div>
    <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
    <script>
        $(function () {
            var groupTable = $("#groupTable").DataTable({
                lengthChange: true,
                lengthMenu: [ [10, 50, 100, 500, -1], [10, 50, 100, 500, 'All'],],
                scrollX: true,
                searching: true,
                processing : true,
                serverSide : true,
                stateSave : true,
                columnDefs : [{ targets: 'no-sort', orderable: false }],
                ajax : {
                    url : '{{ route('accounts.groups.ajax') }}',
                    dataType : 'json',
                    type : 'GET',
                },
                columns : [
                    { data : 'sno' },
                    { data : 'sgroup' },
                    { data : 'mgroup' },
                    { data : 'dc' },
                    { data : 'action' },
                ]
            });
        });
    </script>
@endsection