@extends('layouts.template')

@section('title','Home')
@section('heading','Pending Requests')
@section('breadcrumb','Home/Books/Reservation/Pending Requests')
@section('content')

<div class="row">
    <div class="col-lg-12 grid-margin stretch-card">
        <div class="card">
            <div class="card-header" style="border:1px solid #DCDCDC;background-color:white">
                {{ app_button_links_v(array(573,574,575)) }}
            </div> 
        </div>
    </div>
</div>

<div class="row">
    <div class="col-lg-12 grid-margin stretch-card">
        <div class="card">
            <div class="card-header" style="background-color: #005A9C;color:white;"><b>Select the Criteria</b></div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-group">
                            <label for="from_date" class="required">From Date</label>
                            <input type="date" class="form-control" id="from_date" name="from_date" value="{{ date('Y-m-d') }}" required>
                            @error('from_date')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-group">
                            <label for="to_date" class="required">To Date</label>
                            <input type="date" class="form-control" id="to_date" name="to_date" value="{{ date('Y-m-d') }}" required>
                            @error('to_date')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-group">
                            <button type="button" class="btn btn-primary float-right" id="getData">Get Details</button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<div class="row">
    <div class="col-lg-12 grid-margin stretch-card">
        <div class="card" style="border-top:3px solid #004170">
            <div class="card-body">
                <table class="table table-bordered" id="reportTable" width="100%">
                    <thead>
                        <tr>
                            <th><b>Member Type</b></th>
                            <th><b>Date of reservation</b></th>
                            <th><b>Membership No</b></th>
                            <th><b>Member Name</b></th>
                            <th><b>Book No.</b></th>
                            <th><b>Book Name</b></th>
                            <th><b>Approve</b></th>
                            <th><b>Reject</b></th>
                            <th><b>View</b></th>
                        </tr>
                    </thead>
                    <tbody>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<!-- Modal for Approve -->
<div class="modal fade" id="approveModal" tabindex="-1" role="dialog" aria-labelledby="approveModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header" style="background-color: #004170; color: white;">
                <h5 class="modal-title" id="approveModalLabel">Approve Reservation</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" style="background-color: #f9f9f9; color: #333;">
                <p>Are you sure you want to approve this reservation?</p>
                <input type="hidden" id="approve_reservation_id" value="">

                <div class="form-group">
                    <label for="approve_return_date">Issue Date</label>
                    <input type="date" class="form-control" id="approve_return_date">
                </div>

                <div class="form-group">
                    <label for="approve_remark">Remark</label>
                    <textarea class="form-control" id="approve_remark"></textarea>
                </div>
            </div>
            <div class="modal-footer" style="background-color: #f1f1f1;">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-success" id="confirmApprove">Approve</button>
            </div>
        </div>
    </div>
</div>

<!-- Modal for Reject -->
<div class="modal fade" id="rejectModal" tabindex="-1" role="dialog" aria-labelledby="rejectModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header" style="background-color: #005A9C; color: white;">
                <h5 class="modal-title" id="rejectModalLabel">Reject Reservation</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body" style="background-color: #f9f9f9; color: #333;">
                <p>Are you sure you want to reject this reservation?</p>
                <input type="hidden" id="reject_reservation_id" value="">
            </div>
            <div class="modal-footer" style="background-color: #f1f1f1;">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                <button type="button" class="btn btn-danger" id="confirmReject">Reject</button>
            </div>
        </div>
    </div>
</div>
<script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>


<script>
    $(function () {
        var reportTable = $("#reportTable").DataTable({
            lengthChange: true,
            scrollX: true,
            searching: true,
            processing: true,
            serverSide: true,
            columnDefs: [{ targets: 'no-sort', orderable: false }],
            ajax: {
                url: '{{ route('book.reservation.pending.get') }}',
                dataType: 'json',
                type: 'GET',
                data: function(data){
                    data.from_date = $('#from_date').val();
                    data.to_date = $('#to_date').val();
                }
            },
            columns: [
                { data: 'member_type' },
                { data: 'date' },
                { data: 'membershipno' },
                { data: 'Membername' },
                { data: 'book_no' },
                { data: 'title' },
                { data: 'approve' },
                { data: 'reject' },
                { data: 'action' }
            ]
        });

        $('#getData').click(function(){
            reportTable.draw();
        });

        // Handle Approve button click
        $(document).on('click', '.approve-btn', function() {
            var reservationId = $(this).data('id'); // Get reservation ID from data-id attribute
            $('#approve_reservation_id').val(reservationId); // Set the reservation ID in the hidden input field
            $('#approveModal').modal('show'); // Open the modal
        });
        
        $('#approveModal').on('shown.bs.modal', function () {
        var today = new Date().toISOString().split('T')[0]; // Get today's date in 'YYYY-MM-DD' format
        $('#approve_return_date').val(today); // Set the value of the Issue Date input to today's date
    });

        // Handle Reject button click
        $(document).on('click', '.reject-btn', function() {
            var reservationId = $(this).data('id'); // Get reservation ID from data-id attribute
            $('#reject_reservation_id').val(reservationId); // Set the reservation ID in the hidden input field
            $('#rejectModal').modal('show'); // Open the modal
        });

        // Confirm Approve action
        $('#confirmApprove').click(function() {
            var reservationId = $('#approve_reservation_id').val();// Get the reservation ID from the hidden input
            var returnDate = $('#approve_return_date').val();
            var remark = $('#approve_remark').val();
            var url = '{{ route("book.reservation.approveup", ":id") }}';
            url = url.replace(':id', reservationId); // Replace the route placeholder with the actual reservation ID
            $.ajax({
                url: url,
                type: 'POST',
                data: {
                    _token: '{{ csrf_token() }}',
                    return_date: returnDate,
                    remark: remark
                },
                success: function(response) {
                    $('#approveModal').modal('hide');
                    reportTable.draw(); // Reload the table
                }
            });
        
        });

        // Confirm Reject action
        $('#confirmReject').click(function() {
            var reservationId = $('#reject_reservation_id').val(); // Get the reservation ID from the hidden input
            var url = '{{ route("book.reservation.rejectup", ":id") }}';
            url = url.replace(':id', reservationId); // Replace the route placeholder with the actual reservation ID
            window.location.href = url; // Redirect to the reject route
        });
    });
</script>

@endsection