@extends('layouts.template')
@section('title','Home')
@section('heading','Fee Report')
@section('breadcrumb','Home/Fees/Fee Report')
@section('content')
    <div class="row">
        <div class="col-lg-12 grid-margin stretch-card">
            <div class="card">
                <div class="card-header" style="background-color:#005A9C;color:white;"><b>Select the Criteria</b></div>
                <div class="card-body">
                    <form action="{{ route('fee.report.get') }}" method="post">
                        @csrf
                        <div class="row">
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label for="fdate">From Date</label>
                                    <input type="date" class="form-control" id="fdate" name="fdate" value="{{ $fdate ? $fdate:date('Y-m-d') }}">
                                    @error('fdate')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label for="tdate">To Date</label>
                                    <input type="date" class="form-control" id="tdate" name="tdate" value="{{ $tdate ? $tdate:date('Y-m-d') }}">
                                    @error('tdate')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label for="course">Course</label>
                                    <select class="js-example-basic-single" style="width:100%" id="course" name="course">
                                        <option value="">Select</option>
                                        @foreach($courses as $course)
                                            <option value="{{ $course->course_id }}" {{ $course_id==$course->course_id ? "selected":"" }}>{{ $course->course_name }}</option>
                                        @endforeach
                                    </select>
                                    @error('course')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                </div>
                            </div>
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label for="semester">Semester</label>
                                    <select class="js-example-basic-single" style="width:100%" id="semester" name="semester">
                                        <option value="">Select</option>
                                        @foreach($semesters as $semester)
                                            <option value="{{ $semester->course_id }}" {{ $semester_id==$semester->semester_id ? "selected":"" }}>{{ $semester->semester_name }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label for="mode">Payment Mode</label>
                                    <select class="js-example-basic-single" id="mode" name="mode" style="width:100%">
                                        <option value="">Select</option>
                                        @foreach($paymodes as $paymode)
                                            <option value="{{ $paymode->mode_id }}" {{ $mode_id == $paymode->mode_id ? "selected":"" }}>{{ $paymode->mode_name }}</option>
                                        @endforeach
                                    </select>
                                    @error('mode')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="staff">Collected By</label>
                                    <div class="row">
                                        <div class="col-md-6">
                                            <select class="js-example-basic-single" style="width:100%" id="staff" name="staff">
                                                <option value="">Select</option>
                                                @foreach($staffs as $staff)
                                                    <option value="{{ $staff->user_id }}" {{ $staff_id==$staff->user_id ? "selected":"" }}>{{ $staff->name }}</option>
                                                @endforeach
                                            </select>
                                            @error('staff')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                        </div>
                                        <div class="col-md-6">
                                            <button type="submit" class="btn btn-primary">Filter</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
    @if(!empty($fees))
        <div class="row">
             <div class="col-lg-12 grid-margin stretch-card">
                <div class="card">
                    <div class="card-header" style="background-color:#004170;color:white;"><b>Fee Report</b></div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-12">
                                <div class="scroll">
                                    <table class="table table-bordered">
                                        <thead>
                                        <tr>
                                            <th><b>#</b></th>
                                            <th><b>Receipt No</b></th>
                                            <th><b>Date</b></th>
            								<th><b>Adm No</b></th>
            								<th><b>Name</b></th>
            								<th><b>Fee Amount</b></th>
            								<th><b>Paid Amount</b></th>
            								<th><b>Discount</b></th>
            								<th><b>Fine</b></th>
            								<th><b>Payment Mode</b></th>
            								<th><b>Collected By</b></th>
            								<th><b>Actions</b></th>
                                        </tr>
                                        </thead>
                                        <tbody>
                                            @php  $paid_fee=$fee_total=$discount_sum=$i=0;
                                            foreach($fees as $fee){
                                                $famount = $fee['fee'];
                                                $discount = $fee['discount'];
                                                $fine=$fee['fine'];
                                                
                                                $discount_sum += $discount;
                                                $paidAmount = $famount - $discount+$fine;
                                                
                                              
                                                @endphp
                                                <tr>
                                                    <td align="center">{{ ++$i }}</td>
                                                    <td align="center">{{ $fee['recno'] }}</td>
                                                    <td align="center">{{ date('d/m/Y',strtotime($fee['pdate'])) }}</td>
                                                    <td align="center">{{ $fee['adno'] }}</td>
                                                    <td>{{ $fee['name'] }}</td>
                                                    <td>{{number_format($famount,2) }}</td>
                                                    <td align="right">{{ number_format($paidAmount,2) }}</td>
                                                    <td align="right">{{number_format($discount,2)}}</td>
                                                    <td align="right">{{number_format($fine,2)}}</td>
                                                    <td align="center">{{ $fee['mode'] }}</td>
                                                    <td align="center">{{ $fee['staff'] }}</td>
                                                    <td align="center">{{ app_table_links($fee['recno'],array(30,31)) }}</td>
                                                </tr>
                                            @php $fee_total +=$famount;
                                           $paid_fee +=$paidAmount;
                                            } @endphp
                                        </tbody>
                                        <tfoot>
                                        <tr>
                                            <td colspan="5" class="font-weight-bold" style="font-size:20px" align="center">Grand Total</td>
                                            <td class="font-weight-bold" align="right" style="font-size:20px">{{ number_format($fee_total,2) }}</td>
                                            <td class="font-weight-bold" align="right" style="font-size:20px">{{ number_format($paid_fee,2) }}</td>
                                            <td></td>
                                            <td></td>
                                            <td></td>
                                        </tr>
                                        </tfoot>
                                    </table>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    @else
        <div class="alert alert-danger" role="alert">No Result Found!</div>
    @endif
    
     
    <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
    <script src="{{ asset('public/js/fee.js') }}"></script>
    <style>
        
         
       
                      .dataTables_wrapper .dataTables_filter input {
   
    font-weight:bold;
    background-color: white;
    border: 1px solid black;
    border-radius: 4px;
    padding: 6px 10px;
    width: 300px; /* Adjust width as needed */
    box-shadow: inset 0 1px 2px rgba(0,0,0,0.1); /* Optional: add shadow */
}
.card-body{
            border-left:1px solid #DCDCDC;
            border-right:1px solid #DCDCDC;
            border-bottom:1px solid #DCDCDC;
          
        }

    </style>
@endsection