@extends('layouts.template')
@section('title','Books')
@section('heading','Update Book')
@section('breadcrumb','Home / Library / Books / Update')
@section('content')
    <div class="card">
        <div class="card-body">
            <form action="{{ route('library.book.update', encrypt($book->id)) }}" method="POST">
                @csrf
                @method('PUT')
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="book_no">Book No</label>
                            <input type="text" class="form-control" id="book_no" value="{{ $book->book_no }}" disabled>
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="access_no" class="required">Access No</label>
                            <input type="text" class="form-control @error('access_no') border-danger @enderror" id="access_no" name="access_no" value="{{ old('access_no') ?? $book->access_no }}" required>
                            @error('access_no')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="title" class="required">Title</label>
                            <input type="text" class="form-control @error('title') border-danger @enderror" id="title" name="title" value="{{ old('title') ?? $book->title }}" required>
                            @error('title')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="author" class="required">Author</label>
                            <input type="text" class="form-control @error('author') border-danger @enderror" id="author" name="author" value="{{ old('author') ?? $book->author }}" required>
                            @error('author')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="category" class="required">Category</label>
                            <select class="js-example-basic-single form-control @error('category_id') border-danger @enderror" id="category" name="category_id" required>
                                <option value="">Select</option>
                                @foreach($categories as $category)
                                    <option value="{{ $category->id }}" {{ (old('category_id', $book->category_id ?? '') == $category->id) ? 'selected' : '' }}>{{ $category->name }}</option>
                                @endforeach
                            </select>
                            @error('category_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="subcategory" class="required">Sub Category</label>
                            <select class="js-example-basic-single form-control @error('subcategory_id') border-danger @enderror" id="subcategory" name="subcategory_id" required>
                                <option value="">Select</option>
                                @foreach($subcategories as $subcategory)
                                    <option value="{{ $subcategory->id }}" {{ (old('subcategory_id', $book->subcategory_id ?? '') == $subcategory->id) ? 'selected' : '' }}>{{ $subcategory->name }}</option>
                                @endforeach
                            </select>
                            @error('subcategory_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="location" class="required">Location</label>
                            <select class="js-example-basic-single form-control @error('location_id') border-danger @enderror" id="location" name="location_id" required>
                                <option value="">Select</option>
                                @foreach($locations as $location)
                                    <option value="{{ $location->id }}" {{ (old('location_id', $book->location_id ?? '') == $location->id) ? 'selected' : '' }}>{{ $location->name }}</option>
                                @endforeach
                            </select>
                            @error('location_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="sublocation" class="required">Sub Location</label>
                            <select class="js-example-basic-single form-control @error('sublocation_id') border-danger @enderror" id="sublocation" name="sublocation_id" required>
                                <option value="">Select</option>
                                @foreach($sublocations as $sublocation)
                                    <option value="{{ $sublocation->id }}" {{ (old('sublocation_id', $book->sublocation_id ?? '') == $sublocation->id) ? 'selected' : '' }}>{{ $sublocation->name }}</option>
                                @endforeach
                            </select>
                            @error('sublocation_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="sub_title">Sub Title</label>
                            <input type="text" class="form-control @error('sub_title') border-danger @enderror" id="sub_title" name="sub_title" value="{{ old('sub_title') ?? $book->sub_title }}">
                            @error('sub_title')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="date">Date</label>
                            <input type="date" class="form-control @error('date') border-danger @enderror" id="date" name="date" value="{{ old('date') ?? $book->date }}">
                            @error('date')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="language">Language</label>
                            <input type="text" class="form-control @error('language') border-danger @enderror" id="language" name="language" value="{{ old('language') ?? $book->language }}">
                            @error('language')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="publisher">Publisher</label>
                            <input type="text" class="form-control @error('publisher') border-danger @enderror" id="publisher" name="publisher" value="{{ old('publisher') ?? $book->publisher }}">
                            @error('publisher')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="volume">Volume</label>
                            <input type="text" class="form-control @error('volume') border-danger @enderror" id="volume" name="volume" value="{{ old('volume') ?? $book->volume }}">
                            @error('volume')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="edition">Edition</label>
                            <input type="text" class="form-control @error('edition') border-danger @enderror" id="edition" name="edition" value="{{ old('edition') ?? $book->edition }}">
                            @error('edition')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="year">Year</label>
                            <input type="text" class="form-control @error('year') border-danger @enderror" id="year" name="year" value="{{ old('year') ?? $book->year }}">
                            @error('year')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="price">Price</label>
                            <input type="text" class="form-control @error('price') border-danger @enderror" id="price" name="price" value="{{ old('price') ?? $book->price }}">
                            @error('price')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="condition" class="required">Condition</label>
                            <select class="js-example-basic-single form-control" id="condition" name="condition" required>
                                <option value="Good" {{ (old('condition', $book->condition ?? '') == 'Good') ? 'selected' : '' }}>Good</option>
                                <option value="Damaged" {{ (old('condition', $book->condition ?? '') == 'Damaged') ? 'selected' : '' }}>Damaged</option>
                                <option value="Missing" {{ (old('condition', $book->condition ?? '') == 'Missing') ? 'selected' : '' }}>Missing</option>
                            </select>
                            @error('condition')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="isbn">ISBN</label>
                            <input type="text" class="form-control @error('isbn') border-danger @enderror" id="isbn" name="isbn" value="{{ old('isbn') ?? $book->isbn }}">
                            @error('isbn')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="reference" class="required">Reference</label>
                            <select class="js-example-basic-single form-control" id="reference" name="reference" required>
                                <option value="Available" {{ (old('reference', $book->reference ?? '') == 'Available') ? 'selected' : '' }}>Available</option>
                                <option value="Reference" {{ (old('reference', $book->reference ?? '') == 'Reference') ? 'selected' : '' }}>Reference</option>
                            </select>
                            @error('reference')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="subject">Subject</label>
                            <input type="text" class="form-control @error('subject') border-danger @enderror" id="subject" name="subject" value="{{ old('subject') ?? $book->subject }}">
                            @error('subject')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="awards">Awards</label>
                            <input type="text" class="form-control @error('awards') border-danger @enderror" id="awards" name="awards" value="{{ old('awards') ?? $book->awards }}">
                            @error('awards')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="keywords">Keywords</label>
                            <input type="text" class="form-control @error('keywords') border-danger @enderror" id="keywords" name="keywords" value="{{ old('keywords') ?? $book->keywords }}">
                            @error('keywords')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="writer">Writer</label>
                            <input type="text" class="form-control @error('writer') border-danger @enderror" id="writer" name="writer" value="{{ old('writer') ?? $book->writer }}">
                            @error('writer')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="copies" class="required">Copies</label>
                            <input type="number" class="form-control @error('copies') border-danger @enderror" id="copies" name="copies" value="{{ old('copies') ?? $book->copies }}" min="1">
                            @error('copies')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="call_no">Call No</label>
                            <input type="text" class="form-control @error('call_no') border-danger @enderror" id="call_no" name="call_no" value="{{ old('call_no') ?? $book->call_no }}">
                            @error('call_no')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="image">Image</label>
                            <input type="file" class="form-control @error('image') border-danger @enderror" id="image" name="image" accept="image/*">
                            @error('image')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="form-group">
                            <button type="submit" class="btn btn-sm btn-success float-right">Update</button>
                            <a href="{{ url()->previous() }}" class="btn btn-sm btn-danger mr-2">Cancel</a>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <script src="{{ asset('public/js/library/book.js') }}"></script>
@endsection