@extends('layouts.template')
@section('title','Books')
@section('heading','Books')
@section('breadcrumb','Home / Library / Books')
@section('content')
    <div class="row">
        <div class="col-12">
            <div class="form-group">
                {{ app_button_links(array(663,664)) }}
            </div>
        </div>
    </div>
    <div class="card">
        <div class="card-body">
            <div class="row">
                <div class="col-12 col-md-3">
                    <div class="form-group">
                        <label for="category">Category</label>
                        <select class="js-example-basic-single form-control" id="category">
                            <option value="">Select</option>
                            @foreach($categories as $category)
                                <option value="{{ $category->id }}">{{ $category->name }}</option>
                            @endforeach
                        </select>
                    </div>
                </div>
                <div class="col-12 col-md-3">
                    <div class="form-group">
                        <label for="subcategory">Sub Category</label>
                        <select class="js-example-basic-single form-control" id="subcategory">
                            <option value="">Select</option>
                        </select>
                    </div>
                </div>
                <div class="col-12 col-md-3">
                    <div class="form-group">
                        <label for="location">Location</label>
                        <select class="js-example-basic-single form-control" id="location">
                            <option value="">Select</option>
                            @foreach($locations as $location)
                                <option value="{{ $location->id }}">{{ $location->name }}</option>
                            @endforeach
                        </select>
                    </div>
                </div>
                <div class="col-12 col-md-3">
                    <div class="form-group">
                        <label for="sublocation">Sub Location</label>
                        <select class="js-example-basic-single form-control" id="sublocation">
                            <option value="">Select</option>
                        </select>
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-12 col-sm-6">
                    <div class="form-group">
                        <label for="skey">Keyword</label>
                        <input type="text" class="form-control" id="skey" placeholder="Search Key Word">
                    </div>
                </div>
            </div>
            <div class="row">
                <div class="col-12">
                    <div class="form-group">
                        <button type="button" class="btn btn-success float-right" id="filter">Filter</button>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <br>
    <div class="card">
        <div class="card-body">
            <div class="row">
                <div class="col-12">
                    <div class="form-group">
                        @if($export)
                            <button type="button" class="btn btn-sm btn-success" id="export"><i class="icon-cloud-download"></i> Export Books</button>
                        @endif
                        @if($bulk)
                            <button type="button" class="btn btn-sm btn-success" id="bulk"><i class="icon-frame"></i> Bulk Barcode</button>
                        @endif
                    </div>
                </div>
            </div>
            <table class="table table-bordered" id="booksTable" width="100%">
                <thead>
                <tr>
                    <th>Book No</th>
                    <th>Access No</th>
                    <th>Title</th>
                    <th>Author</th>
                    <th>Subject</th>
                    <th>Keyword</th>
                    <th>Category</th>
                    <th>Sub Category</th>
                    <th>Location</th>
                    <th>Sub Location</th>
                    <th>Copies</th>
                    <th class="no-sort">Available</th>
                    <th class="no-sort">Actions</th>
                </tr>
                </thead>
                <tbody>
                </tbody>
            </table>
        </div>
    </div>
    <script src="{{ asset('public/js/library/book.js') }}"></script>
    <script>
        $(function () {
            var booksTable = $("#booksTable").DataTable({
                lengthChange: true,
                lengthMenu: [ [10, 50, 100, 500, -1], [10, 50, 100, 500, 'All'],],
                scrollX: true,
                searching: true,
                processing : true,
                serverSide : true,
                stateSave : true,
                columnDefs : [
                    { targets: 'no-sort', orderable: false },
                    { targets: [0, 4, 5, 6, 7, 8], className: 'text-center' }
                ],
                ajax : {
                    url : '{{ route('library.book.ajax') }}',
                    dataType : 'json',
                    type : 'GET',
                    data: function(data){
                        data.category = $('#category').val(),
                        data.subcategory = $('#subcategory').val(),
                        data.location = $('#location').val(),
                        data.sublocation = $('#sublocation').val(),
                        data.skey = $('#skey').val();
                    }
                },
                columns : [
                    { data : 'bno' },
                    { data : 'ano' },
                    { data : 'title' },
                    { data : 'author' },
                    { data : 'subject' },
                    { data : 'keyword' },
                    { data : 'category' },
                    { data : 'subcategory' },
                    { data : 'location' },
                    { data : 'sublocation' },
                    { data : 'copies' },
                    { data : 'available' },
                    { data : 'action' },
                ]
            });
            
            $('#filter').click(function(){
                booksTable.draw();
            });
            
            $('#export').click(function(){
                var category = $('#category').val();
                var subcategory = $('#subcategory').val();
                var location = $('#location').val();
                var sublocation = $('#sublocation').val();
                var skey = $('#skey').val();
                
                window.location = '/library/book/export?category='+category+'&subcategory='+subcategory+'&location='+location+'&sublocation='+sublocation+'&skey='+skey;
            });
            
            $('#bulk').click(function(){
                var category = $('#category').val();
                var subcategory = $('#subcategory').val();
                var location = $('#location').val();
                var sublocation = $('#sublocation').val();
                var skey = $('#skey').val();
                
                window.location = '/library/book/barcode-bulk?category='+category+'&subcategory='+subcategory+'&location='+location+'&sublocation='+sublocation+'&skey='+skey;
            });
        });
    </script>
@endsection