@extends('layouts.template')
@section('title','Membership')
@section('heading','New Staff Membership')
@section('breadcrumb','Home / Library / Membership / Staff / Add')
@section('content')
    <div class="card">
        <div class="card-body">
            <div class="row">
                <div class="col-12 col-md-4">
                    <div class="form-group">
                        <label for="staff_type">Staff Type</label>
                        <select class="js-example-basic-single form-control" id="staff_type">
                            <option value="">Select</option>
                            @foreach($types as $type)
                                <option value="{{ $type->staftyp_id }}">{{ $type->type_name }}</option>
                            @endforeach
                        </select>
                    </div>
                </div>
                <div class="col-12 col-md-8">
                    <div class="form-group">
                        <label for="designation">Designation</label>
                        <div class="row">
                            <div class="col-12 col-md-6">
                                <div class="form-group">
                                    <select class="js-example-basic-single form-control" id="designation">
                                        <option value="">Select</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-md-6">
                                <div class="form-group">
                                    <button type="button" class="btn btn-sm btn-success" id="filter">Filter</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <br>
    <div class="card">
        <div class="card-body">
            <form action="{{ route('library.membership.staff.save') }}" method="post">
                @csrf
                <div class="row">
                    <div class="col-12 col-md-6">
                        <div class="form-group">
                            <label for="date">Date</label>
                            <div class="row">
                                <div class="col-12 col-md-6">
                                    <div class="form-group">
                                        <input type="date" class="form-control @error('date') border-danger @enderror" id="date" name="date" value="{{ old('date') ?? date('Y-m-d') }}" required>
                                        @error('date')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                    </div>
                                </div>
                                <div class="col-12 col-md-6">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-sm btn-success" id="filter">Save</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <table class="table table-bordered" id="staffTable" width="100%">
                    <thead>
                    <tr>
                        <th class="no-sort"><input type="checkbox" id="checkAll"></th>
                        <th>Staff Name</th>
                        <th>Type</th>
                        <th>Designation</th>
                        <th>Contact No</th>
                    </tr>
                    </thead>
                    <tbody>
                    </tbody>
                </table>
            </form>
        </div>
    </div>
    <script src="{{ asset('public/js/library/membership.js') }}"></script>
    <script>
        $(function () {
            var staffTable = $("#staffTable").DataTable({
                lengthChange: true,
                lengthMenu: [ [10, 50, 100, 500, -1], [10, 50, 100, 500, 'All'],],
                scrollX: true,
                searching: true,
                processing : true,
                serverSide : true,
                stateSave : true,
                columnDefs : [
                    { targets: 'no-sort', orderable: false },
                    { targets: [0, 2, 3, 4], className: 'text-center' }
                ],
                ajax : {
                    url : '{{ route('library.membership.staff.list') }}',
                    dataType : 'json',
                    type : 'GET',
                    data: function(data){
                        data.stype = $('#staff_type').val(),
                        data.desig = $('#designation').val();
                    }
                },
                columns : [
                    { data : 'check' },
                    { data : 'name' },
                    { data : 'type' },
                    { data : 'desig' },
                    { data : 'contact' },
                ]
            });
            
            $('#filter').click(function(){
                staffTable.draw();
            });
        });
    </script>
@endsection