@extends('layouts.template')
@section('title','Membership')
@section('heading','Student Membership')
@section('breadcrumb','Home / Library / Membership / Student')
@section('content')
    <div class="card">
        <div class="card-header">
            <div class="card-tools">
                {{ app_button_links(array(656)) }}
            </div>
        </div>
        <div class="card-body">
            <div class="row">
                <div class="col-12 col-md-3">
                    <div class="form-group">
                        <label for="course">Course</label>
                        <select class="js-example-basic-single form-control" id="course">
                            <option value="">Select</option>
                            @foreach($courses as $course)
                                <option value="{{ $course->course_id }}">{{ $course->course_name }}</option>
                            @endforeach
                        </select>
                    </div>
                </div>
                <div class="col-12 col-md-3">
                    <div class="form-group">
                        <label for="semester">Semester</label>
                        <select class="js-example-basic-single form-control" id="semester">
                            <option value="">Select</option>
                        </select>
                    </div>
                </div>
                <div class="col-12 col-md-6">
                    <div class="form-group">
                        <label for="status">Status</label>
                        <div class="row">
                            <div class="col-12 col-md-6">
                                <div class="form-group">
                                    <select class="js-example-basic-single form-control" id="status">
                                        <option value="">Select</option>
                                        <option value="Active">Active</option>
                                        <option value="Inactive">Inactive</option>
                                    </select>
                                </div>
                            </div>
                            <div class="col-12 col-md-6">
                                <div class="form-group">
                                    <button type="button" class="btn btn-sm btn-success" id="filter">Filter</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <br>
    <div class="card">
        <div class="card-body">
            <table class="table table-bordered" id="membersTable" width="100%">
                <thead>
                <tr>
                    <th>No</th>
                    <th>Member Name</th>
                    <th>Course</th>
                    <th>Semester</th>
                    <th>Date</th>
                    <th>Contact No</th>
                    <th>Status</th>
                    <th class="no-sort">Actions</th>
                </tr>
                </thead>
                <tbody>
                </tbody>
            </table>
        </div>
    </div>
    <script src="{{ asset('public/js/library/membership.js') }}"></script>
    <script>
        $(function () {
            var membersTable = $("#membersTable").DataTable({
                lengthChange: true,
                lengthMenu: [ [10, 50, 100, 500, -1], [10, 50, 100, 500, 'All'],],
                scrollX: true,
                searching: true,
                processing : true,
                serverSide : true,
                stateSave : true,
                columnDefs : [
                    { targets: 'no-sort', orderable: false },
                    { targets: [0, 2, 3, 4, 5, 6, 7], className: 'text-center' }
                ],
                ajax : {
                    url : '{{ route('library.membership.student.ajax') }}',
                    dataType : 'json',
                    type : 'GET',
                    data: function(data){
                        data.course = $('#course').val(),
                        data.semester = $('#semester').val(),
                        data.status = $('#status').val();
                    }
                },
                columns : [
                    { data : 'mno' },
                    { data : 'name' },
                    { data : 'course' },
                    { data : 'semester' },
                    { data : 'date' },
                    { data : 'contact' },
                    { data : 'status' },
                    { data : 'action' },
                ]
            });
            
            $('#filter').click(function(){
                membersTable.draw();
            });
        });
    </script>
@endsection