@extends('layouts.settings-template')
@section('title','Settings')
@section('heading','Book Sub Category')
@section('breadcrumb','Settings / Library / Book Sub Category')
@section('content')
    <div class="card card-primary">
        <div class="card-header">Add Book Sub Category</div>
        <div class="card-body">
            <form action="{{ route('library.subcategory.save') }}" method="post">
                @csrf
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="category" class="required">Category</label>
                            <select class="form-control @error('category') border-danger @enderror" id="category" name="category">
                                <option value="">Select</option>
                                @foreach($categories as $category)
                                    <option value="{{ $category->id }}"{{ old('category')==$category->id ? 'selected':'' }}>{{ $category->name }}</option>
                                @endforeach
                            </select>
                            @error('category')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="code" class="required">Sub Category Code</label>
                            <input type="text" class="form-control @error('code') border-danger @enderror" id="code" name="code" value="{{ old('code') }}">
                            @error('code')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-6">
                        <div class="form-group">
                            <label for="name" class="required">Sub Category Name</label>
                            <div class="row">
                                <div class="col-12 col-md-6">
                                    <div class="form-group">
                                        <input type="text" class="form-control @error('name') border-danger @enderror" id="name" name="name" value="{{ old('name') }}">
                                        @error('name')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                    </div>
                                </div> 
                                <div class="col-12 col-md-6">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-sm btn-success">Save</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <br>
    <div class="card">
        <div class="card-body">
            <table class="table table-bordered" id="subcategoryTable" width="100%">
                <thead>
                <tr>
                    <th>Sub Category Code</th>
                    <th>Sub Category Name</th>
                    <th>Category</th>
                    <th class="no-sort">Actions</th>
                </tr>
                </thead>
                <tbody>
                </tbody>
            </table>
        </div>
    </div>
    <script>
        $(function () {
            var subcategoryTable = $("#subcategoryTable").DataTable({
                lengthChange: true,
                lengthMenu: [ [10, 50, 100, 500, -1], [10, 50, 100, 500, 'All'],],
                scrollX: true,
                searching: true,
                processing : true,
                serverSide : true,
                stateSave : true,
                columnDefs : [{ targets: 'no-sort', orderable: false }],
                ajax : {
                    url : '{{ route('library.subcategory.ajax') }}',
                    dataType : 'json',
                    type : 'GET',
                },
                columns : [
                    { data : 'code' },
                    { data : 'name' },
                    { data : 'category' },
                    { data : 'action' },
                ]
            });
        });
    </script>
@endsection