@extends('layouts.template')
@section('title','Other Payment')
@section('heading','Other Payment')
@section('breadcrumb','Home / Otherfee / Other Payment')
@section('content')
    <div class="card card-primary">
        <div class="card-header">Other Fee Payment</div>
        <div class="card-body">
            <form action="{{ route('otherfee.save') }}" method="post">
                @csrf
                <div class="row">
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="acyear" class="required">Academic Year</label>
                            <select class="form-control" id="acyear" name="acyear" required>
                                <option value="">Select</option>
                                @foreach($acyears as $acyear)
                                    <option value="{{ $acyear->ac_id }}" {{ old('acyear')==$acyear->ac_id ? "selected":"" }}>{{ $acyear->start_date_formatted.' - '.$acyear->end_date_formatted }}</option>
                                @endforeach
                            </select>
                            @error('acyear')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="date" class="required">Date</label>
                            <input type="date" class="form-control @error('date') border-danger @enderror" id="date" name="date" value="{{ \Carbon\Carbon::now()->format('Y-m-d')  }}">
                            @error('date')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="receipt_number" class="required">Receipt Number</label>
                            <input type="text" class="form-control @error('receipt_number') border-danger @enderror" id="receipt_number" name="receipt_number" value="{{ $rec_no}}" readonly>
                            @error('receipt_number')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="student_name" class="required">Student Name</label>
                            <input type="text" class="form-control @error('student_name') border-danger @enderror" id="student_name" name="student_name" value="{{ old('student_name')  }}" autocomplete="off">
                            @error('student_name')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="address">Address</label>
                            <textarea name="address" id="address" class="form-control" rows="3">{{ old('address')  }}</textarea>
                            @error('address')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="payment_mode" class="required">Payment Mode</label>
                            <select class="js-example-basic-single" id="payment_mode" name="payment_mode" style="width:100%">
                                <option value="">Select</option>
                                @foreach($paymentmode as $payment)
                                    <option value="{{ $payment->mode_id }}" {{ old('payment_mode') == $payment->mode_id ? "selected":"" }}>{{ $payment->mode_name }}</option>
                                @endforeach
                            </select>
                            @error('payment_mode')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-sm-6">
                        <table class="table table-bordered">
                            <thead>
                            <tr>
                                <th>Fee Type</th>
                                <th>Amount</th>
                            </tr>
                            </thead>
                            <tbody>
                                @foreach($feetype as $type)
                                    <tr>
                                        <input type="hidden" name="types[]" value="{{ $type->type_id }}">
                                        <td>{{ $type->type_name }}</td>
                                        <td><input type="text" class="form-control amount" name="amounts[]" placeholder="0.00"></td>
                                    </tr>
                                @endforeach
                                <tr>
                                    <td><b>Total Amount</b></td>
                                    <td><b><span id="total-amt">0.00</span></b></td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
                <br>
                <div class="row">
                    <div class="col-12 col-sm-6">
                        <div class="form-group">
                            <label for="remarks">Remarks</label>
                            <textarea name="remarks" id="remarks" class="form-control" rows="3">{{ old('remarks')  }}</textarea>
                            @error('remarks')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="form-group">
                            <button type="submit" class="btn btn-primary float-right" name="btn_save">Save</button>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
    <script>
        $(document).ready(function(){
            $(".amount").on('keyup', function(){
                var amount = $(this).val();
                if(isNaN(amount) || amount===null){
                    amount=0; 
                    $(this).val(amount);
                }
                getTotalAmt();
            });
        });
        
        function getTotalAmt(){
            var total = 0;
            $('.amount').each(function() {
                var value = parseFloat($(this).val()) || 0;
                total += value;
            });
            $('#total-amt').text(total.toFixed(2));
        }
    </script>
@endsection