@extends('layouts.template')
@section('title','Home')
@section('heading','Facility')
@section('breadcrumb','Home/Hostel/Facility')
@section('content')



    <div class="row">
        <div class="col-lg-12 grid-margin stretch-card">
            <div class="card">
                <div class="card-header" style="background-color:#005A9C;color:white"><b>Select the Criteria</b></div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-3">
                            <div class="form-group">
                                <label for="course"><b>Course</b></label>
                                <select class="js-example-basic-single" style="width:100%" id="course" name="course">
                                    <option value="">Select</option>
                                    @foreach($courses as $course)
                                        <option value="{{ $course->course_id }}" {{ old('course')==$course->course_id ? "selected":"" }}>{{ $course->course_name }}</option>
                                    @endforeach
                                </select>
                                @error('course')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="semester"><b>Semester</b></label>
                                <div class="row">
                                    <div class="col-md-6">
                                        <select class="js-example-basic-single" style="width:100%" id="semester" name="semester">
                                            <option value="">Select</option>
                                        </select>
                                    </div>
                                    <div class="col-md-6">
                                        <button type="button" class="btn btn-primary" id="getData">Filter</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <form action="{{ route('hostelfacility.save') }}" method="post">
        @csrf
        <div class="row">
            <div class="col-lg-12 grid-margin stretch-card">
                <div class="card">
                    <div class="card-header" style="background-color:#004170;color:white"><b>Choose Hostel</b></div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-3">
                                <div class="form-group">
                                    <label class="required" for="hostel"><b>Hostel</b></label>
                                    <select class="js-example-basic-single" style="width:100%" id="hostel" name="hostel">
                                        <option value="">Select</option>
                                        @foreach($hostels as $hostel)
                                            <option value="{{ $hostel->hostel_id }}">{{ $hostel->hostel_name }}</option>
                                        @endforeach
                                    </select>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label class="required" for="from"><b>Valid From</b></label>
                                    <div class="row">
                                        <div class="col-md-6">
                                            <input type="date" class="form-control" id="from" name="from" value="{{ old('from') ? old('from'):date('Y-m-d') }}">
                                        </div>
                                        <div class="col-md-6">
                                            <button type="submit" class="btn btn-primary">Save</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12 grid-margin stretch-card">
                <div class="card" style="border-top:2px solid #004170">
                    <div class="card-body">
                        <table class="table table-bordered"  id="hostelTable" width="100%">
                            <thead>
                            <tr>
                                <th class="no-sort">
                                    <div class="form-check form-check-success">
                                        <label class="form-check-label"><input type="checkbox" class="form-check-input" id="checkAll"></label> 
                                    </div>
                                </th>
                                <th><b>Adm No</b></th>
                                <th><b>Name</b></th>
                                <th><b>Course</b></th>
                                <th><b>Semester</b></th>
                                <th class="no-sort"><b>Hostel</b></th>
                                <th class="no-sort"><b>Action</b></th>
                            </tr>
                            </thead>
                            <tbody>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </form>
    
           
    <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
    <script src="{{ asset('public/js/fee.js') }}"></script>
    <script>
        $(function () {
            var hostelTable = $("#hostelTable").DataTable({
                lengthChange: true,
                scrollX: true,
                searching: true,
                processing : true,
                serverSide : true,
                order : [],
                columnDefs : [{ targets: 'no-sort', orderable: false }],
                ajax : {
                    url : '{{ route('hostelfacility.ajax') }}',
                    dataType : 'json',
                    type : 'GET',
                    data: function(data){
                        data.course = $('#course').val();
                        data.semester = $('#semester').val();
                    }
                },
                columns : [
                    { data : 'check' },
                    { data : 'adno' },
                    { data : 'name' },
                    { data : 'course' },
                    { data : 'semester' },
                    { data : 'hostel' },
                    { data : 'action' },
                ]
            });
            $('#getData').click(function(){
                hostelTable.draw();
            });
        });
        $("#checkAll").on('click',function () {
            if($(this).is(':checked')){
                $('.checkSub').each(function(){
                    this.checked = true;
                });
            }else{
                $('.checkSub').each(function(){
                    this.checked = false;
                });
            }
        });
    </script>
    <style>
         .card-body{
            border-left:1px solid #DCDCDC;
            border-right:1px solid #DCDCDC;
            border-bottom:1px solid #DCDCDC;
             
          
        }
        
        
        .form-control{
            border:1px solid #E8E8E8;
        }
        table.table-bordered tr:hover {background-color: #B9D9EB;cursor:pointer;}
    </style>
@endsection