@extends('layouts.student-template')
@section('title','Reservation')
@section('heading','Book Reservation')
@section('breadcrumb','Home / Book Reservation')
@section('content')
    @if($membership)
        <div class="row">
            <div class="col-12">
                <div class="form-group">
                    <a class="btn btn-sm btn-danger" href="{{ url()->previous() }}">Cancel</a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="category">Category</label>
                            <select class="js-example-basic-single form-control" id="category">
                                <option value="">Select</option>
                                @foreach($categories as $category)
                                    <option value="{{ $category->id }}">{{ $category->name }}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="subcategory">Sub Category</label>
                            <select class="js-example-basic-single form-control" id="subcategory">
                                <option value="">Select</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-6">
                        <div class="form-group">
                            <label for="skey">Keyword</label>
                            <div class="row">
                                <div class="col-12 col-md-8">
                                    <div class="form-group">
                                        <input type="text" class="form-control" id="skey" placeholder="Search Key Word">
                                    </div>
                                </div>
                                <div class="col-12 col-md-4">
                                    <div class="form-group">
                                        <button type="button" class="btn btn-sm btn-success" id="filter">Filter</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <br>
        <div class="card">
            <div class="card-body">
                <table class="table table-bordered" id="booksTable" width="100%">
                    <thead>
                    <tr>
                        <th>Access No</th>
                        <th>Book Title</th>
                        <th>Author</th>
                        <th>Category</th>
                        <th>Sub Category</th>
                        <th>Availability</th>
                        <th class="no-sort">Reserve</th>
                    </tr>
                    </thead>
                    <tbody>
                    </tbody>
                </table>
            </div>
        </div>
        <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
        <script src="{{ asset('public/js/library/book.js') }}"></script>
        <script>
            $(function () {
                var booksTable = $("#booksTable").DataTable({
                    lengthChange: true,
                    lengthMenu: [ [10, 50, 100, 500, -1], [10, 50, 100, 500, 'All'],],
                    scrollX: true,
                    searching: true,
                    processing : true,
                    serverSide : true,
                    stateSave : true,
                    columnDefs : [
                        { targets: 'no-sort', orderable: false },
                        { targets: [0, 2, 3, 4, 5, 6], className: 'text-center' }
                    ],
                    ajax : {
                        url : '{{ route('student.reservation.books') }}',
                        dataType : 'json',
                        type : 'GET',
                        data: function(data){
                            data.category = $('#category').val(),
                            data.subcategory = $('#subcategory').val(),
                            data.skey = $('#skey').val();
                        }
                    },
                    columns : [
                        { data : 'ano' },
                        { data : 'book' },
                        { data : 'author' },
                        { data : 'category' },
                        { data : 'subcategory' },
                        { data : 'available' },
                        { data : 'action' },
                    ]
                });
                
                $('#filter').click(function(){
                    booksTable.draw();
                });
            });
        </script>
    @else
        <div class="row">
            <div class="col-12">
                <div class="alert alert-danger">Library Membership not Found !</div>
            </div>
        </div>
    @endif
@endsection