@extends('layouts.student-template')
@section('title','Reservation')
@section('heading','Book Reservation')
@section('breadcrumb','Home / Book Reservation')
@section('content')
    @if($membership)
        <div class="row">
            <div class="col-12">
                <div class="form-group">
                    <a class="btn btn-sm btn-danger" href="{{ route('student.reservation.add') }}">
                        <i class=" mdi icon-plus mr-1"></i>
                        New Reservation
                    </a>
                </div>
            </div>
        </div>
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="fdate">From Date</label>
                            <input type="date" class="form-control" id="fdate">
                        </div>
                    </div>
                    <div class="col-12 col-md-6">
                        <div class="form-group">
                            <label for="tdate">To Date</label>
                            <div class="row">
                                <div class="col-12 col-md-6">
                                    <div class="form-group">
                                        <input type="date" class="form-control" id="tdate">
                                    </div>
                                </div>
                                <div class="col-12 col-md-6">
                                    <div class="form-group">
                                        <button type="button" class="btn btn-sm btn-success" id="filter">Filter</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <br>
        <div class="card">
            <div class="card-body">
                <table class="table table-bordered" id="reservationTable" width="100%">
                    <thead>
                    <tr>
                        <th>Access No</th>
                        <th>Book Title</th>
                        <th>Author</th>
                        <th>Date</th>
                        <th>Status</th>
                        <th class="no-sort">Actions</th>
                    </tr>
                    </thead>
                    <tbody>
                    </tbody>
                </table>
            </div>
        </div>
        <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
        <script>
            $(function () {
                var reservationTable = $("#reservationTable").DataTable({
                    lengthChange: true,
                    lengthMenu: [ [10, 50, 100, 500, -1], [10, 50, 100, 500, 'All'],],
                    scrollX: true,
                    searching: true,
                    processing : true,
                    serverSide : true,
                    stateSave : true,
                    columnDefs : [
                        { targets: 'no-sort', orderable: false },
                        { targets: [0, 2, 3, 4, 5], className: 'text-center' }
                    ],
                    ajax : {
                        url : '{{ route('student.reservation.ajax') }}',
                        dataType : 'json',
                        type : 'GET',
                        data: function(data){
                            data.fdate = $('#fdate').val();
                            data.tdate = $('#tdate').val();
                        }
                    },
                    columns : [
                        { data : 'ano' },
                        { data : 'book' },
                        { data : 'author' },
                        { data : 'date' },
                        { data : 'status' },
                        { data : 'action' },
                    ]
                });
                
                $('#filter').click(function(){
                    reservationTable.draw();
                });
            });
        </script>
    @else
        <div class="row">
            <div class="col-12">
                <div class="alert alert-danger">Library Membership not Found !</div>
            </div>
        </div>
    @endif
@endsection